   * ******************************************************************** *
   *                                                                      *
   *          IMPROVED MULTIDIMENSIONNAL POVERTY MEASUREMENT IN NIGERIA   *
   *                		MASTER DO_FILE                                *
   *                                                                      *
   * ******************************************************************** *
   * ******************************************************************** *

       /*
       ** PURPOSE:      Write intro to project here

       ** OUTLINE:      PART 1: Set globals for dynamic file paths 
                        PART 2: Standardize settings and install packages
                        PART 3: Set globals for constants and varlist
                               used across the project. Install all user-contributed
                               commands needed.
                        PART 4: Call the task-specific do-files

       ** WRITTEN BY:  Kike Yra Fonton, kyrafonton@gmail.com / kfonton@worldbank.org
	   
	   ** Date of creation :   October 2022

       ** Last date modified:  September 2023
       */


	
   * ******************************************************************** *
   *
   *       PART 1:  PREPARING FOLDER PATH GLOBALS
   *
   *           - Set the global box to point to the project folder
   *            on each collaborator's computer.
   *           - Set other locals that point to other folders of interest.
   *
   * ******************************************************************** *
	cls
	clear 		all
	set more 	off
	set maxvar 	30000
	
	version 	16.0   
	
	
	* Users
   * -----------

   * Kike                     1    // 
   * Others             	  2    // 

   *Set this value to the user currently using this file
   global user  2
   set varabbrev on

   * Root folder globals
   * ---------------------
	
   if $user == 1 {
       global projectfolder "C:/Users/wb553527/OneDrive - WBG/Desktop/MPM/MPM/MPM_ReproducibilityPackage"
   }

   if $user == 2 {
       global projectfolder "C:\Users\wb573577\Desktop\mpm-nigeria\files submitted\MPM_ReproducibilityPackage"  // Enter the file path to the project folder
   }


   * Project folder globals
   * ---------------------

   global data 					"$projectfolder/Data" 
   global output               	"$projectfolder/Output" 
   global programs          	"$projectfolder/Programs" 
   
   cap cd 						"C:/Program Files/R"
   if _rc {
		di in red "Please, install R software to be able to perform all anaysis"
		sleep 5000
   }
   
   local RFolder 	: dir "C:/Program Files/R" dirs "*", respectcase 
   local Rsoftw 	: word 1 of `RFolder''
   
   global Rterm_path 			`"C:/Program Files/R/`Rsoftw'/bin/x64/Rterm.exe"'
   global Rterm_options 		`"--vanilla"'

   
   * ******************************************************************** *
   *
   *       PART 2:  INSTALL PACKAGES 
   * ******************************************************************** *
   sysdir set PLUS "$programs/AdoFolder"
//    local user_commands 
//    foreach command of local user_commands {
//        cap which `command'
//        if _rc == 111 {
//            ssc install `command'
//        }
//    }

   
   
   * ******************************************************************** *
   *
   *       PART 3:  SET UP STANDARDIZATION GLOBALS AND OTHER CONSTANTS
   * ******************************************************************** *
   global zref 			=  137430 
   global zfood 		= 81767
   global relativPov 	= 2/3
   
//    	global sc "" // To be filled accordingly: 
					/* st --> standard 
					er --> education removed ,
					m1 --> monetary mortality 1 ,
					m2 --> monetary mortality 2 ,
					bl --> baseline ,
					p1 --> prefered1 ,
					p2 --> prefered2 ,
					p3 --> prefered3 ,
					p4 --> prefered4 ,
*/
      
   
   * ******************************************************************** *
   *
   *       PART 4: - RUN DOFILES CALLED BY THIS MASTER DOFILE
   *
   * ******************************************************************** *
   //*
	include "$programs/1_1_DataConstruction_DHS_NLSS.do"
	include "$programs/1_2_DataConstruction_Thresolds.do"
	include "$programs/2_1_DataAnalysis_Preliminary.do"
	include "$programs/2_2_DataAnalysis_Commands.do"	
// 	include "$programs/2_3_DataAnalysis_Charts.do"	// run this only if you want others results than for "bl" and "p4" scenarios (after filling global sc)
	
	foreach sc in "bl" "p4" {
		global sc `sc'
		include "$programs/2_3_DataAnalysis_Charts.do"	
	}
	
	include "$programs/2_4_DataAnalysis_Tables.do"	
	
	
	
