   * ******************************************************************** *
   *                                                                      *
   *          IMPROVED MULTIDIMENSIONNAL POVERTY MEASUREMENT IN NIGERIA   *
   *                	DHS & NLSS DATA CONSTRUCTION              	      *
   *                                                                      *
   * ******************************************************************** *
   * ******************************************************************** *

       /*
       ** PURPOSE:      Data conctruction and modeling from DHS & NLSS

       ** OUTLINE:      
				PART 1: DHS DATA PREPARATION
						SECT 0: CHECK CONSISTENCY IN CHILDREN BIOMARKER DATA
						SECT 1: DATA ON DISABILITIES
                        SECT 2: DATA ON CHILDREN STUNTING
                        SECT 3: DATA ON CHILDREN VACCINATION
                        SECT 4: DATA ON ADULTS NUTRITION
						SECT 5: MODELING NUTRITION STATUS
						
				PART 2: NLSS DATA PREPARATION
						SECT 1: NLSS COVARIATES
						SECT 2: BMI CATEGORIES IMPUTATION
                        SECT 3: STUNTING CATEGORIES IMPUTATION
       */
	   
	
	
   * ******************************************************************** *
   
   *       PART 1: DHS DATA PREPARATION
   * ******************************************************************** *
	   
/*
   * ******************************************************************** *
   *       SECT 0: CHECK CONSISTENCY IN CHILDREN BIOMARKER DATA
   * ******************************************************************** *

	use "$data/NG_2018_DHS_10242022_1813_173263/Household/NGHR7BFL.DTA", clear

	keep hhid hv001 hv002 hc0_* hc1_* hc2_* hc3_*
	isid hv001 hv002
	isid hhid	
	
	foreach var of varlist hc*_0* {
		ren `var' `=substr("`var'", 1, 4) + substr("`var'", -1, 1)'
	}
	
	reshape long hc0_ hc1_ hc2_ hc3_, i(hhid hv001 hv002) j(line_nb)

	keep if ! missing(hc0_)
	isid hv001 hv002 hc0_
	
	tempfile biomarker_hhdata
	save `biomarker_hhdata'
	
	
	*******************************************************************************************************
	use "$data/NG_2018_DHS_10242022_1813_173263/Individual/NGIR7BFL.DTA", clear
	
	keep caseid v001 v002 v003 bidx_* b16_*
	
	foreach var of varlist bidx_0* b16_0* {
		ren `var' `=substr("`var'", 1, length("`var'")-2) + substr("`var'", -1, 1)'
	}
	
	reshape long bidx_ b16_, i(caseid v001 v002 v003) j(line_nb)
	
	keep if !missing(bidx_)
	
	isid v001 v002 v003 bidx_
	
	drop if missing(b16_) | b16_ ==0 // not listed in househol roster
	
	isid v001 v002 b16_ //good
	cap isid v001 v002 bidx_ //good
	isid v001 v002 v003 bidx_ //good
	rename bidx_ hwidx_
	
	tempfile birth_key
	save `birth_key'
	
	*******************************************************************************************************
	use "$data/NG_2018_DHS_10242022_1813_173263/Individual/NGIR7BFL.DTA", clear
	
	isid caseid 
	isid v001 v002 v003
	
	keep caseid v001 v002 v003 hwidx_* hw1_* hw2_* hw3_*

	reshape long hwidx_ hw1_ hw2_ hw3_, i(caseid v001 v002 v003) j(line_nb)
	 
	 keep if !missing(hwidx_)
	 isid v001 v002 v003 hwidx_ 
	 
	 merge 1:1 v001 v002 v003 hwidx_ using `birth_key'
	 drop if _m == 2 // keep only master data
	 drop _m
	
// 	preserve
		keep if !missing(b16_)
		isid v001 v002 b16_  //ok
		ren (v001 v002 b16_ ) (hv001 hv002 hc0_)
		
		merge 1:1 hv001 hv002 hc0_ using `biomarker_hhdata'
		keep if _m ==3
// 	restore
	

*/	
	
	
   * ******************************************************************** *
   *       SECT 1: DISABILITIES
   * ******************************************************************** *
	
	use "$data/NG_2018_DHS_10242022_1813_173263/Household/NGHR7BFL.DTA", clear

	isid hv001 hv002
	isid hhid	
	
	keep hhid hv001 hv002 hv005 idxdis_* hdis*
	
	foreach var of varlist idxdis_0* hdis*_0* {
		ren `var' `=substr("`var'", 1, length("`var'")-2) + substr("`var'", -1, 1)'
	}
	reshape long idxdis_ hdis1_ hdis2_ hdis3_ hdis4_ hdis5_ hdis6_ hdis7_ hdis8_ hdis9_ , i(hhid hv001 hv002 hv005) j(line_nb)
	drop line_nb
	keep if ! missing(idxdis_)
	isid hv001 hv002 idxdis_
	count // 188 010 ok
	
	*| Other data clearing
	lab var 	idxdis_ 	"Index to Household Schedule"
	lab var 	hdis1_		"Wear glasses or contact lenses"
	lab var 	hdis2_		"Have difficulty seeing"
	lab var 	hdis3_		"Wear a hearing aid"
	lab var 	hdis4_		"Have difficulty hearing"
	lab var 	hdis5_		"Have difficulty communicating using usual language"
	lab var 	hdis6_		"Have difficulty remembering or concentrating"
	lab var 	hdis7_		"Have difficulty walking or climbing steps"
	lab var 	hdis8_		"Have difficulty washing all over or dressing"
	lab var 	hdis9_		"Highest degree of difficulty for any of the impairments"
	
	tab1 hdis2_ hdis4_ hdis5_ hdis6_ hdis7_ hdis8_ // poids
	
	save "$output/Data/DHS_Disabilities.dta", replace
	
	
   * ******************************************************************** *
   *       SECT 2: INDICATOR 1: CHILDREN STUNTING
   * ******************************************************************** *
/* 
	Stunting is defined as low height-for-age. It is the result of chronic or recurrent undernutrition, usually associated with poverty, poor maternal health and nutrition, frequent illness and/or inappropriate feeding and care in early life. Stunting prevents children from reaching their physical and cognitive potential. (WHO)
	
	Stunting child if HAZ < -2 (WHO)
	
	A Height-for-Age Z Score (HAZ) should be understood as the number of standard deviations of the actual height of a child from the median height of the children of his/her age as determined from the standard sample. This is prefixed by a positive sign (+) or a negative sign (-) depending on whether the child's actual height is more than the median height or less than the median weight.
	
	HAZ already calculated in data: The measures above were calculated using the CDC Standard Deviation-derived Growth
Reference Curves derived from the NCHS/FELS/CDC Reference Population.  (P97 DHS recode manual)
*/   
   
	use "$data/NG_2018_DHS_10242022_1813_173263/Household/NGHR7BFL.DTA", clear

	isid hv001 hv002
	isid hhid	
	
	
	*| Keeping age, weight and height measures
	keep hhid hv001 hv002 hv005 hc0_* hc1_* hc2_* hc3_* hc5_*
	
	*| Reshaping data to have chilren database
	foreach var of varlist hc*_0* {
		ren `var' `=substr("`var'", 1, 4) + substr("`var'", -1, 1)'
	}
	reshape long hc0_ hc1_ hc2_ hc3_ hc5_, i(hhid hv001 hv002 hv005) j(line_nb)
	drop line_nb
	keep if ! missing(hc0_)
	isid hv001 hv002 hc0_
	count // 12 867
	
	
	*| Other data clearing
	ren 		hc0_ idind
	lab var 	idind 	"Index to Household Schedule"
	lab var 	hc1_	"Child's age in months"
	lab var 	hc2_	"Child's weight in kilograms (1 decimal)"
	lab var 	hc3_	"Child's height in centimeters (1 decimal)"
	lab var 	hc5_	"Height/Age standard deviation"
		
	
	*| Interest variables construction
	clonevar 	HAZ = hc5_
	recode 		HAZ (9998 = .a) // flagged cases
	replace 	HAZ = HAZ/100	// see P97 recode manual
	count if 	!missing(HAZ) // 12349 vs 12 590 in report P 33
	
	gen 		stunting_cat = 0 if  HAZ >= -2 & !missing(HAZ)
	replace 	stunting_cat = 1 if  HAZ < -2 & HAZ >= -3 
	replace 	stunting_cat = 2 if  HAZ < -3
	lab def 	stunting_cat 0 "Normal" 1 "Stunted" 2 "Severely stunted"
	lab val 	stunting_cat stunting_cat
	
	gen 		stuntedChild = (HAZ < -2) if !missing(HAZ)
	tab 		stuntedChild [aw = hv005 / 1000000] //report says 36.8 --> ask or review
	
	save "$output/Data/ChildrenStunting.dta", replace
	
	
   * ******************************************************************** *
   *       SECT 3: INDICATOR 2: CHILDREN DPT3 VACCINATION
   * ******************************************************************** *
  /*
	The health history is relating to children born in the last three years ONLY  
  */
  
	use "$data/NG_2018_DHS_10242022_1813_173263/Individual/NGIR7BFL.DTA", clear
  
  
	*| Keeping DPT3 vacinnation data
	keep 			v001 v002 v003 v005 hidx_* h8_*

	
	*| Reshaping data to have chilren database
	reshape long 	hidx_ h8_ , i(v001 v002 v003 v005) j(line_no)
	drop 			line_no
	keep if 		!missing(hidx_) // No children recorded
	isid 			v001 v002 v003 hidx_ 
	count			// 19842
	
	tempfile tmp
	save `tmp'
	
	
	*| Adding schedule index variable 
	use "$data/NG_2018_DHS_10242022_1813_173263/Individual/NGIR7BFL.DTA", clear
	
	keep v001 v002 v003 bidx_* b16_*
	
	foreach var of varlist bidx_0* b16_0* {
		ren `var' `=substr("`var'", 1, length("`var'")-2) + substr("`var'", -1, 1)'
	}
	reshape long bidx_ b16_, i(v001 v002 v003) j(line_nb)
	drop 		line_nb
	keep if 	!missing(bidx_)
	isid 		v001 v002 v003 bidx_
	rename 		bidx_ hidx_
	
	merge 1:1 v001 v002 v003 hidx_ using `tmp'  // good
	drop if _m==1
	drop _m
	
	cap isid 	v001 v002 b16_ //due to missing/0 --> not in hh roster

	
	*| Other data clearing
	lab var 		hidx_ 	"Index to Birth History"
	lab var 		h8_		"Received POLIO 3"
	
	
	*| Interest variables construction
	recode		h8_ (1/3 = 1) (8 = .), gen(DPT3Vaccination)
	count if 	!missing(DPT3Vaccination) // 18 284
	
	save "$output/Data/ChildrenDPT3.dta", replace

	
	
   * ******************************************************************** *
   *       SECT 4: INDICATOR 3: ADULTS UNDERNOURISHED/OBESE
   * ******************************************************************** *
/* 
	We will take into account all adults interviwed during survey: women 15-49 and men 15-59
	BMI < 18.5 = body mass index below 18.5 (underweight);
*/	

	* WOMEN 15 - 49
	*----------------------------------------------------------------------------*
	
	use "$data/NG_2018_DHS_10242022_1813_173263/Household/NGHR7BFL.DTA", clear

	*| Keeping DPT3
	keep hhid hv001 hv002 hv005 ha0_* ha1_* ha40_*
	isid hv001 hv002
	isid hhid	
	
	*| Reshaping data to have women database
	foreach var of varlist ha*_0* {
		ren `var' `=substr("`var'", 1, length("`var'")-2) + substr("`var'", -1, 1)'
	}
	
	reshape long 	ha0_ ha1_ ha40_, i(hhid hv001 hv002 hv005) j(line_nb)
	drop 			line_nb
	keep if 		!missing(ha0_)
	isid 			hv001 hv002 ha0_
	
	
	*| Other data clearing
	count  // 15 452 women vs 12728 in Table 11.12 Report
	*Excludes pregnant women and women with a birth in the preceding 2 months
	
	ren 		ha0_ 	idind
	lab var 	idind 	"Index to Household Schedule"
	lab var 	ha1_	"Woman's age in years"
	lab var 	ha40_		"Body Mass Index"
		
	
	*| Interest variables construction
	recode		ha40_ (9998 = .a), gen(BMI)
	replace 	BMI = BMI/ 100
	count if	!missing(BMI) //14966
	
	gen 		bmi_cat			= 1 if BMI < 18.5		//underweighted
	replace 	bmi_cat			= 0 if BMI >= 18.5 & BMI < 30 //normal
	replace 	bmi_cat			= 2 if BMI > 30 & !missing(BMI) //obese
	lab def 	bmi_cat 0 "Normal" 1 "Undernourished" 2 "Obese"
	lab val 	bmi_cat bmi_cat
	
	gen			underweighted 	= (BMI < 18.5) if ! missing(BMI)
	gen 		obese		  	=	 (BMI >= 30)  if ! missing(BMI)
	
	tab 		underweighted [aw = hv005 / 1000000] //report says 12.1
	tab 		obese [aw = hv005 / 1000000] // report says 9.9
	
	save "$output/Data/WomenBMI.dta", replace
	
	* MEN 15 - 49
	*----------------------------------------------------------------------------*
	
	// Could not find Men measurement data
	
// 	use "$data/NG_2018_DHS_10242022_1813_173263/Household/NGHR7BFL.DTA", clear
	
// 	*| Keeping BMI
// 	keep hhid hv001 hv002 hv005 hb0_* hb1_* hb40_*
// 	isid hv001 hv002
// 	isid hhid	
//	
// 	*| Reshbping data to hbve women database
// 	foreach var of varlist hb*_0* {
// 		ren `var' `=substr("`var'", 1, length("`var'")-2) + substr("`var'", -1, 1)'
// 	}
//	
// 	reshbpe long hb0_ hb1_ hb40_, i(hhid hv001 hv002 hv005) j(line_nb)
//
// 	keep if ! missing(hb0_)
// 	isid hv001 hv002 hb0_
//	
//	
// 	*| Other data clearing
// 	count  // 15 452 women vs 12728 in Table 11.12 Report
// 	*Excludes pregnant women and women with a birth in the preceding 2 months
//	
// // 	lab var 	hidx_ 	"Index to Birth History"
// // 	lab var 	hw1_	"Child's age in months"
// // 	lab var 	h8_		"Received POLIO 3"
// //		
//	
// 	*| Interest variables construction
// 	gen 		weight = hv005 / 1000000
//	
// 	recode		hb40_ (9998 = .a), gen(BMI)
// 	replace 	BMI = BMI/ 100
// 	count if	!missing(BMI) //14966
//	
// 	gen			underweighted = (BMI < 18.5) if ! missing(BMI)
// 	gen 		obese		  = (BMI >= 30)  if ! missing(BMI)
//	
// 	tab 		underweighted [aw = weight] //report says 12.1
// 	tab 		obese [aw = weight] // report says 9.9
//	save "$output/Data/men.dta", replace

	
	
	
   * ******************************************************************** *
   *       SECT 5: MODELING NUTRITION STATUS
   * ******************************************************************** *
	
	* Covariates Data Preparation
	*----------------------------------------------------------------------------*
	*----------------------------------------------------------------------------*
	use "$data/NG_2018_DHS_10242022_1813_173263/Household/NGHR7BFL.DTA", clear

	isid hv001 hv002
	isid hhid	
	
	**** Asset index construction
	*---------------------------------------------------------------------------*
	* | Dwelling characteristics
	
	gen 		impdrinkwater 	= inlist(hv201,10, 11, 12, 13, 14, 20, 21, 31, 41, 51) if !missing(hv201)
	gen			imptoilet 		= inlist(hv205,10, 11, 12, 21, 23, 41) & hv225 == 0 if !missing(hv205) | !missing(hv205)
	gen 		impcookfuel 	= inlist(hv226,1 2, 3, 4) if !missing(hv226) //electricity, gas,
	gen			impfloor		= inlist(hv213,30, 31, 32, 33, 34, 35) if !missing(hv213)
	gen			impwall			= inlist(hv214,30, 31, 32, 33, 34, 35) if !missing(hv214)
	gen			improof			= inlist(hv215,30, 31, 32, 33, 34, 35, 36) if !missing(hv215)
	clonevar	electricity		= hv206 
	
	* | Real estate assets
	clonevar 	ownland			= hv244 
	
	* | Movable assets
	clonevar	radio			= hv207
	clonevar	tv				= hv208 
	clonevar	refrigerator	= hv209 
	clonevar	bicycle			= hv210 
	clonevar	motorcycle		= hv211 
// 	clonevar	phone_land		= hv221 
	clonevar	phone_mobile	= hv243a 
// 	clonevar	watch			= hv243b
// 	clonevar	animal_drawn	= hv243c 
// 	clonevar	boat 			= hv243d 
	clonevar	computer		= hv243e 
// 	clonevar	bank_account	= hv247
	clonevar	table			= sh121g
	clonevar 	chair			= sh121h
	clonevar 	bed				= sh121i 
	clonevar 	sofa			= sh121j
// 	clonevar 	cupboard		= sh121k
	clonevar 	air_conditioner	= sh121l
	clonevar 	iron			= sh121m
	clonevar 	generator		= sh121n
	clonevar 	fan				= sh121o
// 	clonevar 	canoe			= sh122h
// 	clonevar 	keke_napep		= sh122i 
	
	recode 	hv246a hv246c hv246d hv246e hv246f hv246g hv246h (0 = 0) (nonmissing =1)
	rename	(hv246a hv246c hv246d hv246e hv246f hv246g hv246h) ///
			(cattle horses goats sheep chicken pigs camel) // cows removed
			
	global pca_var impdrinkwater imptoilet impcookfuel impfloor impwall improof electricity ///
					ownland radio tv refrigerator bicycle motorcycle computer table chair bed ///
					sofa air_conditioner iron generator fan
	
	* | PCA model
	codebook $pca_var,c // ok
	mca $pca_var
	
	* Only the first axe (89%)
	mat 	coord 		= e(A)[1...,1]
	local 	nbvar 		: word count $pca_var
	global 	eig1		= e(Ev)[1,1]
	local 	i 			= 0
	
	foreach var of varlist  $pca_var {
		cap drop use_`var'
		gen use_`var' = (`var'==0) * coord[2*`i'-1,1] + (`var'==1) * coord[2*`i',1]
		local i = `i' + 1
	}
	cap drop 	mymissing
	egen 		mymissing	= rownonmiss($pca_var)
	
	cap drop 	assetindex
	egen 		assetindex 	= rowtotal (use_*),mi
	replace 	assetindex	= assetindex/(sqrt($eig1) * `nbvar')
	replace 	assetindex 	=. if mymissing < `nbvar'
	sum 		assetindex

	* Normalization
	global asset_min = r(min)
	global asset_max = r(max) 
	
	replace assetindex = (assetindex-$asset_min)/($asset_max-$asset_min)
	sum 	assetindex
	
	* Ordering: the higher, the best condition
	bysort electricity: 	sum assetindex
	bysort air_conditioner: sum assetindex
	replace assetindex = 1 - assetindex
	
	keep 		hhid $pca_var assetindex
	tempfile 	assetind
	save 		`assetind'
	
	
	**** Others covariates
	*---------------------------------------------------------------------------*
	*| Data preparation	
	use "$data/NG_2018_DHS_10242022_1813_173263/Household/NGHR7BFL.DTA", clear

	keep hhid hv001 hv002 hv005 hvidx_* hv101_* hv102_* hv104_* hv105_* hv106_* hv107_* hv109_* hv115_* hv116_* hv025 hv024
	
	*| Reshaping data to have member database
	foreach var of varlist hvidx_0* hv1*_0* {
		ren `var' `=substr("`var'", 1, length("`var'")-2) + substr("`var'", -1, 1)'
	}
	reshape long hvidx_ hv101_ hv102_ hv104_ hv105_ hv106_ hv107_ hv109_ hv115_ hv116_ , i(hhid hv001 hv002 hv005 hv024 hv025) j(line_nb)
	drop line_nb
	keep if ! missing(hvidx_)
	isid hv001 hv002 hvidx_
	count // 188 010	
	
	tempfile tmp
	save `tmp'
	
	
	*| Variables construction
	clonevar hhweight = hv005
	
	clonevar zone = hv024
	
	recode hv025 (2=0), gen(urban)
	lab def urban 1 "Urban" 0 "Rural"
	lab val urban urban
	
	gen one = 1
	bysort hhid: egen hhsize = total(one)
	
	keep if hv101_ ==1
	
	recode hv104_ (2=0), gen(hsex)
	lab def hsex 1 "Male" 0 "Female"
	lab val hsex hsex
	
	recode hv105_ (98 = .), gen(hage)
	
	clonevar heduc = hv109_
	recode heduc (8 = .)
	
	recode hv116_ (2 = 0), gen(hmarried)
	lab def hmarried 1 " Married" 0 "Non married"
	lab val hmarried hmarried
	
	keep hhid hhweight zone urban hhsize hsex hage hmarried heduc
	merge 1:1 hhid using `assetind', nogen
	tempfile covariates
	save `covariates'
	
	use `tmp', clear
	
	recode hv105_ (98 = .), gen(age)
	
	clonevar educ = hv109_
	recode educ (8 = .)
	
	recode hv104_ (2=0), gen(sex)
	lab def sex 1 "Male" 0 "Female"
	lab val sex sex
	
	keep hhid hvidx_ age educ sex
	ren hvidx_ idind
	
	merge m:1 hhid using `covariates', nogen
	save "$output/Data/DHS_BMICovariates.dta", replace
	
	global bmi_covariates hhsize assetindex i.urban i.hsex hage i.hmarried i.heduc age i.educ
	global stunt_covariates hhsize assetindex i.urban i.hsex hage i.hmarried i.heduc age i.sex
	
	
	* MODELS CONSTRUCTION 
	*----------------------------------------------------------------------------*
	*----------------------------------------------------------------------------*
	
	**** BMI model
	*---------------------------------------------------------------------------*
	merge 1:1 hhid idind using "$output/Data/WomenBMI.dta"
	keep if _m ==3
	drop _m
	
	*| Some tabulations
	tab bmi_cat [iw = hhweight], matcell(dhs_wbmi)
	mat dhs_wbmi =  dhs_wbmi/r(N)
	
	elabel list (zone)
 	local zlabel `r(values)'
	
	foreach z of local zlabel { 
	    tab bmi_cat [iw = hhweight] if zone == `z', matcell(zone`z'dhs_wbmi)
		mat zone`z'dhs_wbmi =  zone`z'dhs_wbmi/r(N)
	}
	
		
	*| General model
	stepwise, pr(.15) pe(.05) forward lockterm1:  ///
	mlogit bmi_cat $bmi_covariates i.zone [iw = hhweight], b(0) r
	
// 	_estimates clear
// 	_estimates hold bmi_global
	estimates save	"$output/Models/bmi_global", replace
	
	
	*| Per zone model
	foreach z of local zlabel {
		di "Zone `z'"
		di "******************************************"
		
		stepwise, pr(.15) pe(.05) forward lockterm1: ///
		mlogit bmi_cat $bmi_covariates[iw = hhweight] if zone == `z', b(0) r
			
// 		_estimates hold bmi_zone_`z'
		estimates save	"$output/Models/bmi_zone_`z'", replace
	}
	
	
	
	**** Stunting model
	*---------------------------------------------------------------------------*
	use "$output/Data/DHS_BMICovariates.dta", clear
	merge 1:1 hhid idind using "$output/Data/ChildrenStunting.dta"
	keep if _m ==3
	drop _m
	
	*| Some tabulations
	tab stunting_cat [iw = hhweight], matcell(dhs_stunt)
	mat dhs_stunt =  dhs_stunt/r(N)
	
	elabel list (zone)
 	local zlabel `r(values)'
	
	foreach z of local zlabel { 
	    tab stunting_cat [iw = hhweight] if zone == `z', matcell(zone`z'dhs_stunt)
		mat zone`z'dhs_stunt =  zone`z'dhs_stunt/r(N)
	}
	
		
	*| General model
	stepwise, pr(.15) pe(.05) forward lockterm1:  ///
	mlogit stunting_cat $stunt_covariates i.zone [iw = hhweight], b(0) r
	
// 	_estimates hold stunt_global
	estimates save	"$output/Models/stunt_global", replace
	
	
	*| Per zone model
	foreach z of local zlabel {
		di "Zone `z'"
		di "******************************************"
		
		stepwise, pr(.15) pe(.05) forward lockterm1: ///
		mlogit stunting_cat $stunt_covariates[iw = hhweight] if zone == `z', b(0) r
			
// 		_estimates hold stunt_zone_`z'
		estimates save	"$output/Models/stunt_zone_`z'", replace
	}
	
	
	
   * ******************************************************************** *
   
   *       PART 2: NLSS DATA PREPARATION
   * ******************************************************************** *
	
   * ******************************************************************** *
   *       SECT 1 : NLSS COVARIATES PREPARATION
   * ******************************************************************** *
	
	**** Asset index construction
	*---------------------------------------------------------------------------*
	* | Dwelling characteristics
	use "$data/NGA_2018_LSS_v01_M_Stata/Household/sect14_housing.dta", clear
	count
	isid hhid
	
	clonevar	impdrinkwater = s14q32
	replace  	impdrinkwater = s14q27 if s14q31 == 2
	replace 	impdrinkwater = inlist(impdrinkwater,1, 2, 3, 4, 5, 6, 8, 10) if !missing(impdrinkwater)
	
	gen			imptoilet 		= inlist(s14q40 , 1, 2, 3, 5, 6, 7, 9) & s14q44 == 2 if !missing(s14q40 ) | !missing(s14q44)
	
	gen 		impcookfuel 	= inlist(s14q16_1, 12, 13, 14, 15, 16) if !missing(s14q16_1) //electricity, gas
	
	gen			impfloor		= inlist(s14q11 ,3, 4, 5, 6, 7, 8) if !missing(s14q11)
	gen			impwall			= !inlist(s14q09, 1, 6, 8) if !missing(s14q09)
	gen			improof			= !inlist(s14q10, 1, 7) 	if !missing(s14q10)
	recode 		s14q19 (2=0), gen(electricity)
	
	tempfile tmp
	save `tmp'
	

	* | Real estate assets
	use "$data/NGA_2018_LSS_v01_M_Stata/Household/sect19a_land.dta", clear
	recode 		s19q00 (2=0), gen(ownland)
	
	merge 1:1 hhid using `tmp', nogen
	tempfile tmp
	save `tmp'
	
	
	* | Movable assets
	use "$data/NGA_2018_LSS_v01_M_Stata/Household/sect10_assets.dta", clear
	isid hhid asset_cd

	keep hhid asset_cd s10q01
	recode s10q01 (2=0)
	rename s10q01 s10q01__
	reshape wide s10q01__, i(hhid) j(asset_cd) 
	
	rename 		(s10q01__322 s10q01__327 s10q01__312 s10q01__317 s10q01__318 s10q01__328 s10q01__303 ///
				s10q01__302 s10q01__305 s10q01__301 s10q01__314  s10q01__326 s10q01__320 s10q01__321) ///
				(radio tv refrigerator bicycle motorcycle computer table chair bed sofa air_conditioner iron generator fan )
	
	gen phone_mobile = (s10q01__3321 == 1 | s10q01__3322 == 1) if !missing(s10q01__3321) | !missing(s10q01__3322)
	
	merge 1:1 hhid using `tmp', nogen
	tempfile tmp
	save `tmp'
	
	// Livestocks
	use "$data/NGA_2018_LSS_v01_M_Stata/Household/sect18_agriculture.dta", clear
	isid hhid
	
	rename	(s18q14__1 s18q14__2 s18q14__3 s18q14__4 s18q14__5 s18q14__8) ///
			(cattle horses goats sheep pigs camel)
	
	gen 	chicken = (s18q14__6==1 | s18q14__7 == 1) if !missing(s18q14__6) | !missing(s18q14__7)

	foreach var of varlist cattle horses goats sheep pigs camel chicken {
		replace `var' = 0  if s18q13 ==2
	}

	merge 1:1 hhid using `tmp', nogen
	
	global pca_var impdrinkwater imptoilet impcookfuel impfloor impwall improof electricity ///
					ownland radio tv refrigerator bicycle motorcycle computer table chair bed ///
					sofa air_conditioner iron generator fan
	keep hhid $pca_var

	
	* | PCA model application: following the same model than DHS (to have comparable indicators)
	local 	nbvar 		: word count $pca_var
	local 	i 			= 0
	
	foreach var of varlist  $pca_var {
		cap drop use_`var'
		gen use_`var' = (`var'==0) * coord[2*`i'-1,1] + (`var'==1) * coord[2*`i',1]
		local i = `i' + 1
	}
	cap drop 	mymissing
	egen 		mymissing	= rownonmiss($pca_var)
	
	cap drop 	assetindex
	egen 		assetindex 	= rowtotal (use_*),mi
	replace 	assetindex	= assetindex/(sqrt($eig1) * `nbvar')
	replace 	assetindex 	=. if mymissing < `nbvar'
	sum 		assetindex

	* Normalization
	replace assetindex = (assetindex-$asset_min)/($asset_max-$asset_min)
	replace assetindex = 1 - assetindex
	sum 		assetindex
	
	keep 		hhid $pca_var assetindex
	tempfile 	assetind
	save 		`assetind'

	
	**** Others covariates
	*---------------------------------------------------------------------------*
	use "$data/NGA_2018_LSS_v01_M_Stata/Household/sect1_roster.dta", clear
	merge 1:1 hhid indiv using "$data/NGA_2018_LSS_v01_M_Stata/Household/sect2_education.dta", nogen
	merge m:1 hhid using "$data/NGA_2018_LSS_v01_M_Stata/Household/totcons.dta", keepusing(wt_final popw)
	isid hhid indiv

	gen one = 1
	bysort hhid: egen hhsize = total(one) 
		
	recode sector (2=0), gen(urban)
	lab def urban 1 "Urban" 0 "Rural"
	lab val urban urban
	
	recode s01q02  (2=0), gen(sex)
	lab def sex 1 "Male" 0 "Female"
	lab val sex sex
	
	clonevar age = s01q04a
	
	bysort s01q07: sum s01q04a // ok under age 12 not asked
	recode s01q07 (1 2 3 =1 ) (nonmiss = 0) (miss = 0 ), gen(married)
	lab def married 1 " Married" 0 "Non married"
	lab val married married
	
	recode s02q07 (0/3 51 52 61 = 0) (11/15 = 1) (16 =2) (21/27 = 3) (28 321 = 4) (31/43 322/424 = 5), gen(educ)
	replace educ = 0 if s02q05 == 2
	lab def educ 0 "no education" 1 "incomplete primary" 2 "complete primary" 3 "incomplete secondary" 4 "complete secondary" 5 "higher"
	lab val educ educ
	tab educ // a revoir

	keep hhid indiv wt_final popw zone urban hhsize sex age married educ s01q03
	tempfile tmp
	save `tmp'
	
	keep if s01q03 == 1
	ren (sex age married educ) (hsex hage hmarried heduc)
	keep hhid hsex hage hmarried heduc
	
	merge 1:1 hhid using `assetind', nogen
	merge 1:m hhid using `tmp', nogen 
	drop if missing(indiv)
	isid hhid indiv
	
	global bmi_covariates hhsize assetindex i.urban i.hsex hage i.hmarried i.heduc age i.educ
	global stunt_covariates hhsize assetindex i.urban i.hsex hage i.hmarried i.heduc age i.sex
	save "$output/Data/NLSS_BMICovariates.dta", replace
	

	
   * ******************************************************************** *
   *       SECT 2 : BMI CATEGORIES IMPUTATION
   * ******************************************************************** *
   
	**** Probabilities estimates 
	*---------------------------------------------------------------------------*
   *| Global
// 	_estimates unhold bmi_global
	estimates use	"$output/Models/bmi_global"
	
	cap drop prob_bmi*
	predict prob_bmi0 prob_bmi1 prob_bmi2 , pr
	
	gen probc_bmi1 = prob_bmi1/(prob_bmi1 + prob_bmi2) // proba conditionelles
	gen probc_bmi2 = prob_bmi2/(prob_bmi1 + prob_bmi2)
	sum prob*_bmi*
	
	
	*| Per zone
	forval z = 1/6 { //zone labels
// 		_estimates unhold bmi_zone_`z'
		estimates use	"$output/Models/bmi_zone_`z'"
		
		cap drop zone`z'_prob_bmi*
		predict zone`z'_prob_bmi0 zone`z'_prob_bmi1 zone`z'_prob_bmi2, pr
		
		gen zone`z'_probc_bmi1 = zone`z'_prob_bmi1/(zone`z'_prob_bmi1 + zone`z'_prob_bmi2) // proba conditionelles
		gen zone`z'_probc_bmi2 = zone`z'_prob_bmi2/(zone`z'_prob_bmi1 + zone`z'_prob_bmi2)
		sum zone`z'_prob*_bmi*
	}
	save "$output/Data/NLSS_BMICovariates.dta", replace
	
	
	**** Classification into BMI groups: WOMEN 15-49
	*---------------------------------------------------------------------------*
	/* 
	The idea here is to choose probabilities thresholds such that we have a similar shring of BMI categories as in DHS data per zone.
	The approach used is a sequential approach:...
	*/
   keep if sex == 0 & age >=15 & age <=49 // Women
   
   local eps = 0.005
   local pas = 0.001 // pas de 0.1%
   
   forval z = 1/6 {
   	preserve
		keep if zone == `z'
		tempvar one
		gen `one' = 1
		
		//Threshold 1 : Classify individuals as normal
		qui: sum zone`z'_prob_bmi0
		local zone`z'_thres1 = r(max)
		
		cap total `one'[iw = wt_final] if zone`z'_prob_bmi0 > `zone`z'_thres1' & !missing(zone`z'_prob_bmi0)
		if _rc == 0 local num = e(b)[1,1]
		else 		local num = 0 //no obs
		qui total `one'[iw = wt_final] if !missing(zone`z'_prob_bmi0)
		local pct_bmi0 = `num'/e(b)[1,1]
		
		while abs(`pct_bmi0' - zone`z'dhs_wbmi[1,1]) > `eps' {
			local zone`z'_thres1 = `zone`z'_thres1' - `pas' 
			cap total `one'[iw = wt_final] if zone`z'_prob_bmi0 > `zone`z'_thres1' & !missing(zone`z'_prob_bmi0)
			if _rc == 0 local num = e(b)[1,1]
			else 		local num = 0 //no obs
			qui total `one'[iw = wt_final] if !missing(zone`z'_prob_bmi0)
			local pct_bmi0 = `num'/e(b)[1,1]
		}
		
		//Threshold 2 : Classify individuals as undernourished knowing that they are not normal
		qui: sum zone`z'_probc_bmi1
		local zone`z'_thres2 = r(max)
		
		cap total `one'[iw = wt_final] if zone`z'_prob_bmi0 < `zone`z'_thres1' & zone`z'_probc_bmi1 > `zone`z'_thres2' & !missing(zone`z'_probc_bmi1)
		if _rc == 0 local num = e(b)[1,1]
		else 		local num = 0 //no obs
		qui total `one'[iw = wt_final] if !missing(zone`z'_prob_bmi0)
		local pct_bmi1 = `num'/e(b)[1,1]
		
		while abs(`pct_bmi1' - zone`z'dhs_wbmi[2,1]) > `eps' {
			local zone`z'_thres2 = `zone`z'_thres2' - `pas' 
			cap total `one'[iw = wt_final] if zone`z'_prob_bmi0 < `zone`z'_thres1' & zone`z'_probc_bmi1 > `zone`z'_thres2' & !missing(zone`z'_probc_bmi1)
			if _rc == 0 local num = e(b)[1,1]
			else 		local num = 0 //no obs
			qui total `one'[iw = wt_final] if !missing(zone`z'_prob_bmi0)
			local pct_bmi1 = `num'/e(b)[1,1]
		}
		
		gen 	bmi_cat = .
		replace bmi_cat = 0 if zone`z'_prob_bmi0 > `zone`z'_thres1' & !missing(zone`z'_prob_bmi0)
		replace bmi_cat = 1 if zone`z'_prob_bmi0 < `zone`z'_thres1' & zone`z'_probc_bmi1 > `zone`z'_thres2' & !missing(zone`z'_probc_bmi1)
		replace bmi_cat = 2 if zone`z'_prob_bmi0 < `zone`z'_thres1' & zone`z'_probc_bmi1 < `zone`z'_thres2' 
		
		
		// Display and save results
		di "Zone `z'"
		di "******************************************"
		di "Threshold 1: `zone`z'_thres1'"
		di "Threshold 2: `zone`z'_thres2'"
		tab bmi_cat[iw = wt_final]
		mat list zone`z'dhs_wbmi
		
		if `z' ==1 {
			tempfile tmp
			save `tmp'
		}
		else {
			append using `tmp'
			tempfile tmp
			save `tmp'
		}
		
	restore
   }
   
   *| Summary
	merge 1:1 hhid indiv using `tmp', nogen
	tab bmi_cat[iw = wt_final] // good
	mat list dhs_wbmi 
	
	tempfile women
	save `women'
   
	
	
	**** Classification into BMI groups: MEN 15-49
	*---------------------------------------------------------------------------*
	/* 
	Same idea than women: only target percentages of undernourished/obese change according to assumptions made
	2 time more obese women than men, no undernourished men (best scenario for poverty)
	*/
	
	use "$output/Data/NLSS_BMICovariates.dta", clear
	keep if sex == 1 & age >=15 & age <=49 // Men

   local eps = 0.005
   local pas = 0.001 // pas de 0.1%
   
   forval z = 1/6 {
   	preserve
		keep if zone == `z'
		tempvar one
		gen `one' = 1
		
		// Update target matrix for men
		mat zone`z'dhs_mbmi 	 = zone`z'dhs_wbmi
		mat zone`z'dhs_mbmi[3,1] = zone`z'dhs_wbmi[3,1]/2
		mat zone`z'dhs_mbmi[2,1] = 0
		mat zone`z'dhs_mbmi[1,1] = 1 - zone`z'dhs_mbmi[2,1] - zone`z'dhs_mbmi[3,1]
		
		
		//Threshold 1 : Classify individuals as normal
		qui: sum zone`z'_prob_bmi0
		local zone`z'_thres1 = r(max)
		
		cap total `one'[iw = wt_final] if zone`z'_prob_bmi0 > `zone`z'_thres1' & !missing(zone`z'_prob_bmi0)
		if _rc == 0 local num = e(b)[1,1]
		else 		local num = 0 //no obs
		qui total `one'[iw = wt_final] if !missing(zone`z'_prob_bmi0)
		local pct_bmi0 = `num'/e(b)[1,1]
		
		while abs(`pct_bmi0' - zone`z'dhs_mbmi[1,1]) > `eps' {
			local zone`z'_thres1 = `zone`z'_thres1' - `pas' 
			cap total `one'[iw = wt_final] if zone`z'_prob_bmi0 > `zone`z'_thres1' & !missing(zone`z'_prob_bmi0)
			if _rc == 0 local num = e(b)[1,1]
			else 		local num = 0 //no obs
			qui total `one'[iw = wt_final] if !missing(zone`z'_prob_bmi0)
			local pct_bmi0 = `num'/e(b)[1,1]
		}
		
		//Threshold 2 : Classify individuals as undernourished knowing that they are not normal
		qui: sum zone`z'_probc_bmi1
		local zone`z'_thres2 = r(max)
		
		cap total `one'[iw = wt_final] if zone`z'_prob_bmi0 < `zone`z'_thres1' & zone`z'_probc_bmi1 > `zone`z'_thres2' & !missing(zone`z'_probc_bmi1)
		if _rc == 0 local num = e(b)[1,1]
		else 		local num = 0 //no obs
		qui total `one'[iw = wt_final] if !missing(zone`z'_prob_bmi0)
		local pct_bmi1 = `num'/e(b)[1,1]
		
		while abs(`pct_bmi1' - zone`z'dhs_mbmi[2,1]) > `eps' {
			local zone`z'_thres2 = `zone`z'_thres2' - `pas' 
			cap total `one'[iw = wt_final] if zone`z'_prob_bmi0 < `zone`z'_thres1' & zone`z'_probc_bmi1 > `zone`z'_thres2' & !missing(zone`z'_probc_bmi1)
			if _rc == 0 local num = e(b)[1,1]
			else 		local num = 0 //no obs
			qui total `one'[iw = wt_final] if !missing(zone`z'_prob_bmi0)
			local pct_bmi1 = `num'/e(b)[1,1]
		}
		
		gen 	bmi_cat = .
		replace bmi_cat = 0 if zone`z'_prob_bmi0 > `zone`z'_thres1' & !missing(zone`z'_prob_bmi0)
		replace bmi_cat = 1 if zone`z'_prob_bmi0 < `zone`z'_thres1' & zone`z'_probc_bmi1 > `zone`z'_thres2' & !missing(zone`z'_probc_bmi1)
		replace bmi_cat = 2 if zone`z'_prob_bmi0 < `zone`z'_thres1' & zone`z'_probc_bmi1 < `zone`z'_thres2' 
		
		
		// Display and save results
		di "Zone `z'"
		di "******************************************"
		di "Threshold 1: `zone`z'_thres1'"
		di "Threshold 2: `zone`z'_thres2'"
		tab bmi_cat[iw = wt_final]
		mat list zone`z'dhs_wbmi
		
		if `z' ==1 {
			tempfile tmp
			save `tmp'
		}
		else {
			append using `tmp'
			tempfile tmp
			save `tmp'
		}
		
	restore
   }
   
   *| Summary
	merge 1:1 hhid indiv using `tmp', nogen
	tab bmi_cat[iw = wt_final] // good
	
	mat dhs_mbmi 	 = dhs_wbmi
	mat dhs_mbmi[3,1] = dhs_wbmi[3,1]/2
	mat dhs_mbmi[2,1] = 0
	mat dhs_mbmi[1,1] = 1 - dhs_mbmi[2,1] - dhs_mbmi[3,1]
	mat list dhs_mbmi 
	
	append using `women'
	tempfile bmi
	save `bmi'

	
	**** Classification into BMI groups: 5-14 & 49+
	*---------------------------------------------------------------------------*
	/*
	Assumption made that every one in this group is mormal (best scenario for poverty)
	*/
	use "$output/Data/NLSS_BMICovariates.dta", clear
	keep if (age > 5 & age <15) | (age > 49 & !missing(age)) // Men

	gen bmi_cat = 0
	
	append using `bmi'
	tempfile bmi
	save `bmi'
	
	
	
   * ******************************************************************** *
   *       SECT 3 : STUNTING CATEGORIES IMPUTATION
   * ******************************************************************** *
   
	**** Probabilities estimates 
	*---------------------------------------------------------------------------*
	use "$output/Data/NLSS_BMICovariates.dta", clear

   *| Global
// 	_estimates unhold stunt_global
	estimates use "$output/Models/stunt_global"
	
	cap drop prob_stunt*
	predict prob_stunt0 prob_stunt1 prob_stunt2 , pr
	
	gen probc_stunt1 = prob_stunt1/(prob_stunt1 + prob_stunt2) // proba conditionelles
	gen probc_stunt2 = prob_stunt2/(prob_stunt1 + prob_stunt2)
	sum prob*_stunt*
	
	
	*| Per zone
	forval z = 1/6 { //zone labels
// 		_estimates unhold stunt_zone_`z'
		estimates use "$output/Models/stunt_zone_`z'"

		
		cap drop zone`z'_prob_stunt*
		predict zone`z'_prob_stunt0 zone`z'_prob_stunt1 zone`z'_prob_stunt2, pr
		
		gen zone`z'_probc_stunt1 = zone`z'_prob_stunt1/(zone`z'_prob_stunt1 + zone`z'_prob_stunt2) // proba conditionelles
		gen zone`z'_probc_stunt2 = zone`z'_prob_stunt2/(zone`z'_prob_stunt1 + zone`z'_prob_stunt2)
		sum zone`z'_prob*_stunt*
	}
	save "$output/Data/NLSS_BMICovariates.dta", replace

	
	**** Classification into Stunting groups: 0 -5 years
	*---------------------------------------------------------------------------*
	
   keep if age <= 5 // Children
   
   local eps = 0.005
   local pas = 0.001 // pas de 0.1%
   
   forval z = 1/6 {
   	preserve
		keep if zone == `z'
		tempvar one
		gen `one' = 1
		
		//Threshold 1 : Classify individuals as normal
		qui: sum zone`z'_prob_stunt0
		local zone`z'_thres1 = r(max)
		
		cap total `one'[iw = wt_final] if zone`z'_prob_stunt0 > `zone`z'_thres1' & !missing(zone`z'_prob_stunt0)
		if _rc == 0 local num = e(b)[1,1]
		else 		local num = 0 //no obs
		qui total `one'[iw = wt_final] if !missing(zone`z'_prob_stunt0)
		local pct_stunt0 = `num'/e(b)[1,1]
		
		while abs(`pct_stunt0' - zone`z'dhs_stunt[1,1]) > `eps' {
			local zone`z'_thres1 = `zone`z'_thres1' - `pas' 
			cap total `one'[iw = wt_final] if zone`z'_prob_stunt0 > `zone`z'_thres1' & !missing(zone`z'_prob_stunt0)
			if _rc == 0 local num = e(b)[1,1]
			else 		local num = 0 //no obs
			qui total `one'[iw = wt_final] if !missing(zone`z'_prob_stunt0)
			local pct_stunt0 = `num'/e(b)[1,1]
		}
		
		//Threshold 2 : Classify individuals as undernourished knowing that they are not normal
		qui: sum zone`z'_probc_stunt1
		local zone`z'_thres2 = r(max)
		
		cap total `one'[iw = wt_final] if zone`z'_prob_stunt0 < `zone`z'_thres1' & zone`z'_probc_stunt1 > `zone`z'_thres2' & !missing(zone`z'_probc_stunt1)
		if _rc == 0 local num = e(b)[1,1]
		else 		local num = 0 //no obs
		qui total `one'[iw = wt_final] if !missing(zone`z'_prob_stunt0)
		local pct_stunt1 = `num'/e(b)[1,1]
		
		while abs(`pct_stunt1' - zone`z'dhs_stunt[2,1]) > `eps' {
			local zone`z'_thres2 = `zone`z'_thres2' - `pas' 
			cap total `one'[iw = wt_final] if zone`z'_prob_stunt0 < `zone`z'_thres1' & zone`z'_probc_stunt1 > `zone`z'_thres2' & !missing(zone`z'_probc_stunt1)
			if _rc == 0 local num = e(b)[1,1]
			else 		local num = 0 //no obs
			qui total `one'[iw = wt_final] if !missing(zone`z'_prob_stunt0)
			local pct_stunt1 = `num'/e(b)[1,1]
		}
		
		gen 	stunting_cat = .
		replace stunting_cat = 0 if zone`z'_prob_stunt0 > `zone`z'_thres1' & !missing(zone`z'_prob_stunt0)
		replace stunting_cat = 1 if zone`z'_prob_stunt0 < `zone`z'_thres1' & zone`z'_probc_stunt1 > `zone`z'_thres2' & !missing(zone`z'_probc_stunt1)
		replace stunting_cat = 2 if zone`z'_prob_stunt0 < `zone`z'_thres1' & zone`z'_probc_stunt1 < `zone`z'_thres2' 
		
		
		// Display and save results
		di "Zone `z'"
		di "******************************************"
		di "Threshold 1: `zone`z'_thres1'"
		di "Threshold 2: `zone`z'_thres2'"
		tab stunting_cat[iw = wt_final]
		mat list zone`z'dhs_stunt
		
		if `z' ==1 {
			tempfile tmp
			save `tmp'
		}
		else {
			append using `tmp'
			tempfile tmp
			save `tmp'
		}
		
	restore
   }
   
   *| Summary
	merge 1:1 hhid indiv using `tmp', nogen
	tab stunting_cat[iw = wt_final] // good
	mat list dhs_stunt 
	
	append using `bmi'
	
	lab def 	bmi_cat 0 "Normal" 1 "Undernourished" 2 "Obese"
	lab val 	bmi_cat bmi_cat
	
	lab def 	stunting_cat 0 "Normal" 1 "Stunted" 2 "Severely stunted"
	lab val 	stunting_cat stunting_cat

	save "$output/Data/NLSS_BMICovariates.dta", replace
	