   * ******************************************************************** *
   *                                                                      *
   *          IMPROVED MULTIDIMENSIONNAL POVERTY MEASUREMENT IN NIGERIA   *
   *                		THRESHOLD SET UP                              *
   *                                                                      *
   * ******************************************************************** *
   * ******************************************************************** *

       /*
       ** PURPOSE:     SET UP THRESHOLDS PER EACH POVERTY DIMENSION

       ** OUTLINE:      SECT 1: DIMENSION 1: CONSUMPTION 
                        SECT 2: DIMENSION 2: HEALTH
                        SECT 3: DIMENSION 3: EDUCATION 
                        SECT 4: DIMENSION 4: BASIC INFRASTRUCTURE  
                        SECT 5: DIMENSION 5: SECURITY 
       */

	 
// 	include	"$programs/1_1_DataConstruction_DHS_NLSS.do"
	 
	 
   * ******************************************************************** *
   *       SECT 1: DIMENSION 1: CONSUMPTION 
   * ******************************************************************** *
   use		"$data/NGA_2018_LSS_v01_M_Stata/Household/totcons.dta", clear
   
   count
   isid hhid
   
   // Quick checking of official number
   sepov 				totcons_adj [pw = popw] , povline($zref) // 40.1 ok
   sepov 				totcons_adj [pw = popw] , povline($zref) by(sector) //ok
   
   
   // Case 1: 	* Extreme 	= Under national poverty threshold
				* Moderate 	= Ignored
	* Extreme
	gen Monetary1Ext 	= (totcons_adj < $zref) if !missing(totcons_adj)
	gen Monetary1Mod		= 0
	tab Monetary1*
	
	
   // Case 2: 	* Extreme 	= Under national poverty threshold
				* Moderate 	= Over national poverty threshold but beyond state societal poverty line (WBG)
	/* 
	Benoit says: 
	 ligne sociétale (= 1 + 0.5 * median consumption in state, exprimé en $ par jour par personne)
	 ligne nationale (1.93$ par jour par personne) 
	*/
	gen Monetary2Ext 	= (totcons_adj < $zref) if !missing(totcons_adj)

	gen conso_day_pc_dollar = (totcons_adj * 1.93)/(($zref/365) * 365)
	gen Monetary2Mod 		= .
	forval i =1/37 {
		_pctile 		conso_day_pc_dollar [pw = popw] if state == `i', nq(2)
		local 			modthres 	= 1 + 0.5 * r(r1)
		replace 		Monetary2Mod = (conso_day_pc_dollar < `modthres' & totcons_adj >= ${zref} & !missing(totcons_adj))  if state == `i'
		replace 		Monetary2Mod = 0 			if state == `i' & Monetary2Ext == 1 // (`modthres' < $zref)
	}  
   
	tab Monetary2*
	
	preserve
		keep 			hhid wt_final Monetary2*
		save 			"$output/Data/BasicIndicators.dta", replace
	restore
	
	keep 				hhid sector zone state lga ea month_of_interview year_of_interview wt_final popw totcons_adj Monetary*
	save 				"$output/Data/hh_thresholds.dta", replace
   
   
   * ******************************************************************** *
   *       SECT 2: DIMENSION 2: HEALTH 
   * ******************************************************************** *
   //Create criteria variables : 	* Have a moderate or extreme disability
									* Have a moderate or severe bad nutrition status (BMI for adults, Stunting for children)
   
   use "$data/NGA_2018_LSS_v01_M_Stata/Household/sect3_health.dta", clear
   
   count
   isid hhid indiv
   
   *| Disability status
   gen Disability_Ext 		= 0
   gen Disability_Mod 		= 0
   
   foreach var of varlist s03q22- s03q27 {
       replace Disability_Ext = 1 if inlist(`var', 3, 4)
   }
   
   foreach var of varlist s03q22- s03q27 {
   	   replace Disability_Mod = 1 if `var' == 2 & Disability_Ext == 0
   }
   
   cap drop test
   egen test			= rownonmiss(s03q22- s03q27)
   replace Disability_Ext 	= . if test == 0
   replace Disability_Mod 	= . if test == 0
   
   tempfile tmp
   save `tmp'
   
   
   *| Nutrition status
   use "$output/Data/NLSS_BMICovariates.dta", clear
   merge 1:1 hhid indiv using `tmp'
   
   
   // Generating moderate and extreme health poverty  : HH level 
		*Case 1:	*Extreme = Ind has at least one disability causing a lot of difficulties or Extreme bad nutritional status
					* Moderate = Ind has a moderate disability and/or moderate nutrition status
   
	gen Health1Ext =  (Disability_Ext == 1 | stunting_cat == 2) if !missing(Disability_Ext) | !missing(stunting_cat)
	gen Health1Mod =  (Disability_Mod == 1 | inlist(bmi_cat,1,2) | stunting_cat == 1) & Health1Ext == 0 ///
																if !missing(Disability_Ext) | !missing(stunting_cat) | !missing(bmi_cat)
   tab Health1*
   
   gen 		Health1Detailed = 0 if Health1Ext == 0 & Health1Mod == 0
   replace	Health1Detailed = 1 if Health1Ext == 1 & Disability_Ext == 1 & stunting_cat != 2
   replace	Health1Detailed = 2 if Health1Ext == 1 & Disability_Ext != 1 & stunting_cat == 2
   replace	Health1Detailed = 3 if Health1Ext == 1 & Disability_Ext == 1 & stunting_cat == 2
   replace	Health1Detailed = 4 if Health1Mod == 1 & Disability_Mod == 1 & !inlist(bmi_cat,1,2) & stunting_cat != 1
   replace	Health1Detailed = 5 if Health1Mod == 1 & Disability_Mod != 1 & bmi_cat == 1 & stunting_cat != 1
   replace	Health1Detailed = 6 if Health1Mod == 1 & Disability_Mod != 1 & bmi_cat == 2 & stunting_cat != 1
   replace	Health1Detailed = 7 if Health1Mod == 1 & Disability_Mod != 1 & !inlist(bmi_cat,1,2) & stunting_cat == 1
   replace	Health1Detailed = 8 if Health1Mod == 1 & missing(Health1Detailed)
   
   lab def Health1Detailed 0 "Non deprived" 1 "Extreme deprived - Disabled only"  2 "Extreme deprived - Severe stunted only" ///
		3 "Extreme deprived - Cumulators" 4 "Moderate deprived - Disabled only"  5 "Moderate deprived - Undernourished only" ///
		6 "Moderate deprived - Obese only" 7 "Moderate deprived - Moderate stunted only" 8 "Moderate deprived - Cumulators"
	lab val Health1Detailed 
	
	preserve
		keep 			hhid indiv age sex Disability_* stunting_cat bmi_cat*
		merge 			m:1 hhid using "$output/Data/BasicIndicators.dta", nogen
		save 			"$output/Data/BasicIndicators.dta", replace
	restore
	
	keep 				hhid indiv wt_final Health*
	save 				"$output/Data/ind_thresholds.dta", replace
   
   tab Health1Detailed, gen(Health1Detailed__)
   foreach var of varlist Health1Detailed__* {
		replace `var' = 100 * `var'
   }
   gen one = 1 
   cap drop __0*
   collapse (mean) Health1Detailed__* [aw =wt_final] , by(one)
   
	gen need = "Health1"
	graph hbar (asis) Health1Detailed__* ///
		, ///
		stack over(need) nofill ///
		legend(order(	1 "Non deprived" ///
						2 "Extreme deprived - Disabled only"  ///
						3 "Extreme deprived - Severe stunted only" ///
						4 "Extreme deprived - Cumulators" ///
						5 "Moderate deprived - Disabled only"  ///
						6 "Moderate deprived - Undernourished only" ///
						7 "Moderate deprived - Obese only" ///
						8 "Moderate deprived - Moderate stunted only" ///
						9 "Moderate deprived - Cumulators") ///
			   c(1) pos(3) ///
			   symxsize(small) symysize(small) size(small)) /// 
		blabel(bar, pos(center) format(%9.0f)) ///
		title("Health1 deprivation", color(black)) ///
        graphregion(color(white)) bgcolor(white) 
	graph export "$output/Graphics/Health1Detailed.png", as(png) name("Graph")	replace   
   
   
	*Case 2:	*Extreme = Ind has at least one disability causing a lot of difficulties or stunting child or undernourished women
				*Moderate = Ind has a moderate disability and/or obese nutrition status
				
	use "$output/Data/NLSS_BMICovariates.dta", clear
	merge 1:1 hhid indiv using `tmp'
   
	gen Health2Ext =  [Disability_Ext == 1 | inlist(stunting_cat,1,2) | bmi_cat == 1] /// 
																	if !missing(Disability_Ext) | !missing(stunting_cat) | !missing(bmi_cat)
	gen Health2Mod =  (Disability_Mod == 1 | bmi_cat == 2) & Health2Ext == 0 if !missing(Disability_Mod) | !missing(bmi_cat)
	tab Health2*
	
   gen 		Health2Detailed = 0 if Health2Ext == 0 & Health2Mod == 0 
   replace	Health2Detailed = 1 if Health2Ext == 1 & Disability_Ext == 1 & !inlist(stunting_cat,1,2) & bmi_cat != 1
   replace	Health2Detailed = 2 if Health2Ext == 1 & Disability_Ext != 1 & stunting_cat == 1 & bmi_cat != 1
   replace	Health2Detailed = 3 if Health2Ext == 1 & Disability_Ext != 1 & stunting_cat == 2 & bmi_cat != 1
   replace	Health2Detailed = 4 if Health2Ext == 1 & Disability_Ext != 1 & !inlist(stunting_cat,1,2) & bmi_cat == 1
   replace	Health2Detailed = 5 if Health2Ext == 1 & missing(Health2Detailed)
   replace	Health2Detailed = 6 if Health2Mod == 1 & Disability_Mod == 1 & bmi_cat != 2
   replace	Health2Detailed = 7 if Health2Mod == 1 & Disability_Mod != 1 & bmi_cat == 2
   replace	Health2Detailed = 8 if Health2Mod == 1 & missing(Health2Detailed)
   
   lab def Health2Detailed 0 "Non deprived" 1 "Extreme deprived - Disabled only"  2 "Extreme deprived - Moderate stunted only" ///
		3 "Extreme deprived - Severe stunted only" 4 "Extreme deprived - Undernourished only" 5 "Extreme deprived - Cumulators" ///
		6 "Moderate deprived - Disabled only"  7 "Moderate deprived - Obese only"  8 "Moderate deprived - Cumulators"
	lab val Health2Detailed Health2Detailed
	
	keep 				hhid indiv wt_final Health*
	merge 1:1 hhid indiv using "$output/Data/ind_thresholds.dta", nogen
	save 				"$output/Data/ind_thresholds.dta", replace
   
	tab Health2Detailed, gen(Health2Detailed__)
	foreach var of varlist Health2Detailed__* {
		replace `var' = 100 * `var'
	}
	gen one = 1 
	cap drop __0*
	collapse (mean) Health2Detailed__* [aw =wt_final] , by(one)

	cap drop need
	gen need = "Health2"
	graph hbar (asis) Health2Detailed__* ///
		, ///
		stack over(need) nofill ///
		legend(order(	1 "Non deprived" ///
						2 "Extreme deprived - Disabled only" ///
						3 "Extreme deprived - Moderate stunted only" ///
						4 "Extreme deprived - Severe stunted only" ///
						5 "Extreme deprived - Undernourished only" ///
						6 "Extreme deprived - Cumulators" ///
						7 "Moderate deprived - Disabled only" /// 
						8 "Moderate deprived - Obese only"  ///
						9 "Moderate deprived - Cumulators") ///
			   c(1) pos(3) ///
			   symxsize(small) symysize(small) size(small)) /// 
		blabel(bar, pos(center) format(%9.0f)) ///
		title("Health2 deprivation", color(black)) ///
        graphregion(color(white)) bgcolor(white) 
	graph export "$output/Graphics/Health2Detailed.png", as(png) name("Graph")	replace   

	
   // PALE -  approach : Nb of days stopping activity because of injury or sickness
   
	use "$output/Data/NLSS_BMICovariates.dta", clear
	merge 1:1 hhid indiv using `tmp'

	clonevar 	daysout	= s03q09
	replace 	daysout = 0 if s03q05 == 2 | s03q08 == 2
   
	keep 				hhid indiv sex age daysout
	merge 1:1 hhid indiv using "$output/Data/ind_thresholds.dta", nogen
	save 				"$output/Data/ind_thresholds.dta", replace
	
	

   * ******************************************************************** *
   *       SECT 3: DIMENSION 3: EDUCATION 
   * ******************************************************************** *
   use "$data/NGA_2018_LSS_v01_M_Stata/Household/sect1_roster.dta", clear
   
   count
   isid hhid indiv
   
   keep hhid indiv s01q04a
   merge 1:1 hhid indiv using "$data/NGA_2018_LSS_v01_M_Stata/Household/sect2_education.dta"
   
   
   // Case 1
   *Create criteria variables : 	* At least one school-age child up to the age of grade 8 is not enrolled in school
									* No adult in the household (age of grade 9 or above) has completed primary education
									* No adult (age of grade 9 or above) in the household can read or write
									
   /* 
   Some useful information (wikipedia) 
   https://en.wikipedia.org/wiki/Eighth_grade#:~:text=Eighth%20grade%20(or%20grade%20eight,and%20comes%20after%207th%20grade.
   In Nigeria, Grade 8 (JSS2) is the second to last year of Junior high, as there are no middle schools in the Nigerian education system, elementary school (primary school) ends in grade 6. Pupils are between the ages of 13 and 14.
   */
   
   clonevar age 			= s01q04a
   clonevar attdschool 		= s02q05
   clonevar highestlevel 	= s02q07
   clonevar wreng			= s02q04
   clonevar wroth			= s02q04b
   
   bysort attdschool: sum age
   bysort attdschool: sum highestlevel   
   
   gen childnotenrolled 	= age <= 14 & attdschool == 2 						if !missing(age) | !missing(attdschool)
   gen adultprimary			= age >  14 & attdschool == 1 & highestlevel >= 16 	if !missing(age) | !missing(attdschool) | !missing(highestlevel) 
   gen adultwr   			= age >  14 & (wreng ==1 | wroth==1) 				if !missing(age) | !missing(wreng) | !missing(wroth) 
   
   bysort hhid: egen nb_childnotenrolled 	= total(childnotenrolled), mi
   bysort hhid: egen nb_adultprimary		= total(adultprimary), mi
   bysort hhid: egen nb_adultwr				= total(adultwr), mi
   
   
   // Generating moderate and extreme education poverty  : HH level 
		* Extreme  : deprivation relative to all indicators
		* Moderate : deprivation relative to two indicators
		
	gen Education1Ext 		= [ nb_childnotenrolled > 0 & !missing(nb_childnotenrolled) ] & [ nb_adultprimary == 0 ] & [ nb_adultwr == 0 ]
	gen Education1Mod 		= [ nb_childnotenrolled > 0 & !missing(nb_childnotenrolled) ] + [ nb_adultprimary == 0 ] + [ nb_adultwr == 0 ] == 2
	
	preserve
		keep 			hhid indiv childnotenrolled adultprimary adultwr
		merge 			1:1 hhid indiv using "$output/Data/BasicIndicators.dta", nogen
		save 			"$output/Data/BasicIndicators.dta", replace
	restore
	
	preserve
		duplicates drop hhid, force
		keep hhid Education1Ext Education1Mod
		
		merge 1:1 hhid using "$output/Data/hh_thresholds.dta", nogen
		save 				 "$output/Data/hh_thresholds.dta", replace
	restore
	
	
   // Case 2:
   /*
	o	Un enfant est extremely deprived en éducation si cet enfant n'est pas school enrolled cette année.
	o	Un ménage est moderately deprived en education (tous ses membres) si aucun adulte ne sait lire-écrire OU si aucun adulte n'a son diplôme de primaire
	*/
	
	gen 	Education2Ext		= (childnotenrolled == 1) if !missing(childnotenrolled)
	gen 	Education2Mod 		= (nb_adultprimary == 0 | nb_adultwr == 0) if !missing(nb_adultprimary) | !missing(nb_adultwr)
	replace Education2Mod 		= 0 if Education2Ext ==1
	
	
   // Case 3:
   /*
	o	Un enfant est extremely deprived en éducation si cet enfant n'est pas school enrolled cette année.
	o	Un ménage est moderately deprived en education (tous ses membres) si aucun adulte ne sait lire-écrire ET si aucun adulte n'a son diplôme de primaire
	*/
	
	gen 	Education3Ext		= (childnotenrolled == 1) if !missing(childnotenrolled)
	gen 	Education3Mod 		= (nb_adultprimary == 0 & nb_adultwr == 0) if !missing(nb_adultprimary) | !missing(nb_adultwr)
	replace Education3Mod 		= 0 if Education3Ext ==1
	
	
	keep hhid indiv Education2Ext Education2Mod Education3Ext Education3Mod
	
	merge 1:1 hhid indiv using "$output/Data/ind_thresholds.dta", nogen
	save 				"$output/Data/ind_thresholds.dta", replace
	
									
									
   * ******************************************************************** *
   *       SECT 4: DIMENSION 4: BASIC INFRASTRUCTURE 
   * ******************************************************************** *
   use "$data/NGA_2018_LSS_v01_M_Stata/Household/sect14_housing.dta", clear
   
   count
   isid hhid   
   
   // Case 1: Crietria used: * The household lacks access to limited-standard drinking water
							 * The household lacks access to limited-standard sanitation
							 * The household has no access to electricity
			 * Extreme deprivation : deprived in 3 indicators
			 * Moderate deprivation: deprived in 2 indicators
   
   /* 
   Some useful information
   "Limited-standard" drinking water is drinking water that comes from an improved source (for example, piped, borehole, protected dug well, rainwater, or delivered water). "Limited-standard" sanitation means using improved sanitation facilities (for example, flush/pour flush to piped sewer system, septic tank, or a composting latrine). (PSPR 2018)
   
	Improved drinking-water sources are defined as those that are likely to be protected from outside contamination, and from faecal matter in particular. Improved water sources include household connections, public standpipes, boreholes, protected dug wells, protected springs and rainwater collection. Unimproved water sources include unprotected wells, unprotected springs, surface water (e.g. river, dam or lake), vendor-provided water, bottled water (unless water for other uses is available from an improved source) and tanker truck-provided water.   (WHO)
	
	We used dring water source in the dry season
	
	Improved sanitation facilities are defined as those that hygienically separate human waste from human contact. Improved sanitation includes flush or pour-flush to piped sewer system, septic tank pit latrines, ventilated-improved pit latrines, or pit latrines with slab or composting toilets. Shared or public-use sanitation facilities are not considered to be improved. Also, flush or pour-flush to elsewhere, pit latrines without slabs or open pits, bucket latrines, hanging latrines or open defecation are not considered to be improved sanitation (WHO)
   */
   
   clonevar drydrinkwatersource = s14q32
   replace  drydrinkwatersource = s14q27 if s14q31 == 2
   clonevar sanitfacilities     = s14q40
   
   gen l_impwater 				= inlist(drydrinkwatersource, 1, 2, 3, 4, 5, 6, 8, 10) if !missing(drydrinkwatersource)
   gen l_impsanitation			= inlist(sanitfacilities, 1, 2, 3, 5, 6, 7, 9) if !missing(sanitfacilities)
//    replace impsanitation        = 0 if s14q44 == 1 																		//shared facilities
   
   recode s14q19 (2=0), gen(electricity)
   
   
   * Generating moderate and extreme education poverty  : HH level 
   gen Housing1Ext				= l_impwater + l_impsanitation + electricity == 0 if !missing(l_impwater + l_impsanitation + electricity)
   gen Housing1Mod				= l_impwater + l_impsanitation + electricity == 1 if !missing(l_impwater + l_impsanitation + electricity)
   
   tab Housing1Ext Housing1Mod
   
   
   // Case 2: Crietria used: * The household lacks access to basic-standard drinking water
							 * The household lacks access to basic-standard sanitation
							 * The household has no access to electricity
			 * Extreme deprivation : deprived in 3 indicators
			 * Moderate deprivation: deprived in 2 indicators
   
   /* 
   Some useful information
	Basic- standard drinking-water = "limited-standard" with an added criterion of the source being within a round trip time of 30 minutes

	Basic-standard sanitation = "limited-standard" with an added criterion of the facility for the exclusive use of the household)
   */
   
   gen 		timerainy			= s14q30a
   replace 	timerainy			= s14q30a * 60 	if s14q30b == 2 								//in minutes
   replace 	timerainy			= timerainy * 2													//roundtrip
   replace  timerainy			= 0 			if inlist(s14q27,1,2) |  inlist(s14q29,1, 2) 	//own dwelling or yard
   
   gen 		timedry				= s14q34a
   replace 	timedry				= s14q34a * 60  if s14q34b == 2 								//in minutes
   replace 	timedry				= timedry * 2													//roundtrip
   replace  timedry				= 0 			if inlist(s14q32,1,2) |  inlist(s14q33a,1, 2) 	//own dwelling or yard
   replace 	timedry				= timerainy		if s14q31 == 2 & !missing(timerainy)
   
   clonevar b_impwater			= l_impwater
   replace 	b_impwater			= 0 if timedry >30  & !missing(timedry)
   clonevar b_impsanitation		= l_impsanitation
   replace 	b_impsanitation        = 0 if s14q44 == 1 																		//shared facilities
   
   
   * Generating moderate and extreme housing poverty  : HH level 
   gen Housing2Ext				= b_impwater + b_impsanitation + electricity == 0 if !missing(b_impwater + b_impsanitation + electricity)
   gen Housing2Mod 				= b_impwater + b_impsanitation + electricity == 1 if !missing(b_impwater + b_impsanitation + electricity)
   
   tab Housing2Ext Housing2Mod
   
   
   // Case 3: Crietria used: * The household lacks access to basic-standard drinking water
							 * The household lacks access to basic-standard sanitation
							 * The household has no access to electricity
							 * The household has inadequate housing
			 * Extreme deprivation : deprived in 4 indicators
			 * Moderate deprivation: deprived in 2-3 indicators
   
   /* 
   Some useful information
	https://hdr.undp.org/mpi-2021-faqs
	Housing: a household is deprived if it has inadequate housing in at least one of the three: the floor is of natural materials or the roof or the walls are of rudimentary materials. (UNDP)
	
	We categorize housing material to be adequate if durable or finished materials such as burnt bricks, tiles, shingles, iron sheets, or polished wood are used. Unfinished, rudimentary, or natural materials include cane, straw, grass, or bamboo. WBG Policy research paper 9830 p.14  
	*/
   
   clonevar wall 				= s14q09
   clonevar roof				= s14q10
   clonevar floor				= s14q11
   
   gen rudimentaryWall     		= inlist(wall, 1, 6, 8) if !missing(wall)
   gen rudimentaryRoof    		= inlist(roof, 1, 7) 	if !missing(roof)
   gen rudimentaryFloor    		= inlist(floor, 1, 2) 	if !missing(floor)
   
   gen goodHousing				= (rudimentaryWall + rudimentaryRoof + rudimentaryFloor) == 0 ///
													if !missing(rudimentaryWall + rudimentaryRoof + rudimentaryFloor) 
   
   
   * Generating moderate and extreme housing poverty  : HH level 
   gen Housing3Ext				= b_impwater + b_impsanitation + electricity +  goodHousing == 0 ///
												if !missing(b_impwater + b_impsanitation + electricity + goodHousing)
   gen Housing3Mod 				= inlist(b_impwater + b_impsanitation + electricity + goodHousing, 1, 2) ///
												if !missing(b_impwater + b_impsanitation + electricity + goodHousing)
   
   tab Housing3Ext Housing3Mod
   
   
   // Case 4: Crietria used: * The household lacks access to limited-standard drinking water
							 * The household lacks access to limited-standard sanitation
							 * The household has no access to electricity
							 * The household has inadequate housing
			 * Extreme deprivation : deprived in 4 indicators
			 * Moderate deprivation: deprived in 2-3 indicators
			 
   * Generating moderate and extreme housing poverty  : HH level 
   gen  Housing4Ext				= l_impwater + l_impsanitation + electricity +  goodHousing == 0 ///
												if !missing(l_impwater + l_impsanitation + electricity + goodHousing)
   gen  Housing4Mod 			= inlist(l_impwater + l_impsanitation + electricity + goodHousing, 1, 2) ///
												if !missing(l_impwater + l_impsanitation + electricity + goodHousing)
   
   tab  Housing4Ext  Housing4Mod
			 
   // Case 5: Crietria used: * The household lacks access to limited-standard drinking water
							 * The household lacks access to limited-standard sanitation
							 * The household has no access to electricity
							 * The household has inadequate housing
			 * Extreme deprivation : deprived in 4 indicators
			 * Moderate deprivation: deprived in 3 indicators

   * Generating moderate and extreme housing poverty  : HH level 
   gen   Housing5Ext				= l_impwater + l_impsanitation + electricity +  goodHousing == 0 ///
												if !missing(l_impwater + l_impsanitation + electricity + goodHousing)
   gen   Housing5Mod 			= inlist(l_impwater + l_impsanitation + electricity + goodHousing, 1) ///
												if !missing(l_impwater + l_impsanitation + electricity + goodHousing)
   
   tab   Housing5Ext   Housing5Mod
   
	preserve
		keep 			hhid l_impwater l_impsanitation b_impwater b_impsanitation electricity goodHousing
		merge 			1:m hhid using "$output/Data/BasicIndicators.dta", nogen
		save 			"$output/Data/BasicIndicators.dta", replace
	restore
			 
   keep 				 hhid Housing*
   merge 1:1 hhid using  "$output/Data/hh_thresholds.dta", nogen
   save 				 "$output/Data/hh_thresholds.dta", replace

	
   * ******************************************************************** *
   *       SECT 5: DIMENSION 5: SECURITY 
   * ******************************************************************** *
   //Criteria used: 
			 * Extreme deprivation : The household has been subject to crime/violence with extreme consequences over the last 12 months 
			 * Moderate deprivation: The household has been subject to crime/violence with moderate consequences over the last 12 months 
   
   *| Crime / Violence
   use "$data/NGA_2018_LSS_v01_M_Stata/Household/sect17_crime_security.dta", clear
   merge m:1 hhid using "$data/NGA_2018_LSS_v01_M_Stata/Household/totcons.dta", keepusing(wt_final) nogen
   
   count
   isid hhid event_cd   
   
   gen crime_shocked2018_19				= s17q01==1 & (s17q02__2 ==1 | s17q02__3 ==1 | s17q02__4 ==1) if !missing(s17q01) //survey took place 2018-2019
   bysort hhid: egen crimeExt 			= total(crime_shocked2018_19 * inlist(event_cd, 1, 2, 4, 6 ,7)) , mi
   bysort hhid: egen crimeMod 			= total(crime_shocked2018_19 * !inlist(event_cd, 1, 2, 4, 6 ,7)) , mi
   replace crimeExt						= 1 if crimeExt > 1 & !missing(crimeExt)
   replace crimeMod						= 1 if crimeMod > 1 & !missing(crimeMod)
   
   duplicates drop hhid, force
   
	preserve
		keep 			hhid crimeMod crimeExt
		merge 			1:m hhid using "$output/Data/BasicIndicators.dta", nogen
		save 			"$output/Data/BasicIndicators.dta", replace
	restore
   
   * We expand the security poverty to the lga level (instead of state to keep a certain heterogeneity). 
   * As security is community issue, household security is status is assigned taking into account others households 
   * crime shocks, given a certain threshold
     
   tabstat crimeExt[aw = wt_final], stat(mean) by(lga) save 
   sum crimeExt
   local m = r(mean)
   local sd = r(sd)
   
   local k = 0
   foreach thres in 0.33 0.25 {
		local k = `k' + 1

		preserve
		   bysort lga: egen lga_crimeExt		= mean(crimeExt)
		   replace 			lga_crimeExt		= 0 if lga_crimeExt < `thres'
		   replace 			lga_crimeExt		= 1 if lga_crimeExt >=  `thres'    & !missing(lga_crimeExt)
		   replace 			lga_crimeExt 		= 1 if crimeExt == 1 //A household itself subjected to crime is security poor
		   
		   tabstat crimeMod[aw = wt_final], stat(mean) by(lga) save 
		   sum crimeMod
		   local m = r(mean)
		   local sd = r(sd)
		   bysort lga: egen lga_crimeMod		= mean(crimeMod)
		   replace 			lga_crimeMod		= 0 if lga_crimeMod < `thres' 
		   replace 			lga_crimeMod		= 1 if lga_crimeMod >= `thres'    & !missing(lga_crimeMod)
		   replace 			lga_crimeMod		= 1 if crimeMod == 1 //A household itself subjected to crime is security poor
		   replace 			lga_crimeMod		= 0 if lga_crimeExt == 1
		   
			tab lga_crimeExt lga_crimeMod //
			tab crimeExt crimeMod   

			ren (lga_crimeExt lga_crimeMod) (Security`k'Ext Security`k'Mod)
			
			keep hhid Security*
			merge 1:1 hhid using  "$output/Data/hh_thresholds.dta", nogen
			save 				 "$output/Data/hh_thresholds.dta", replace
		restore
	}
	
