   * ******************************************************************** *
   *                                                                      *
   *          IMPROVED MULTIDIMENSIONNAL POVERTY MEASUREMENT IN NIGERIA   *
   *                		PRELIMINARY DATA ANALYSIS                     *
   *                                                                      *
   * ******************************************************************** *
   * ******************************************************************** *

       /*
       ** PURPOSE:      COMPUTE PRELIMINARY ANALYSIS

       ** OUTLINE:      SECT 0: SET UP DATA
						SECT 1: MISSING DATA ANALYSIS
                        SECT 2: BALANCED DATA CHECKING
                        SECT 3: ZOOM ON HEALTH DIMENSION: Days out of activity
                        SECT 4: ZOOM ON MORTALITY DIMENSION: Life expectancy at birth
						SECT 5: OVERVIEW OF MAIN DIMENSION'S INDICATORS
       */
	   
	   
// 	include		"$programs/1_1_DataConstruction_DHS_NLSS.do"
// 	include 	"$programs/1_2_DataConstruction_Thresolds.do"
	   

   * ******************************************************************** *
   *       SECT 0: SET UP DATA
   * ******************************************************************** *

   * | Individual (Health data)
   use "$output/Data/ind_thresholds.dta", clear

   foreach var of varlist *Ext {
		local name =  "`name'" + " " + subinstr("`var'","Ext","",1) 
	}
	di "`name'"
	global dimensions_ind "`name'"   

	
	* | Household level data
   use "$output/Data/hh_thresholds.dta", clear

   local name ""
	foreach var of varlist *Ext {
		local name =  "`name'" + " " + subinstr("`var'","Ext","",1) 
	}
	di "`name'"
	global dimensions_hh "`name'"  
	
	
	* | Merged data (Individual level)
	merge 1:m hhid using "$output/Data/ind_thresholds.dta", nogen
	save "$output/Data/ind_all_thresholds.dta", replace
	
	global dimensions: list global(dimensions_ind) | global(dimensions_hh)
	  
	set scheme white_tableau //, perm
	graph set window fontface "Arial Narrow"

	
   * ******************************************************************** *
   *       SECT 1: MISSING DATA ANALYSIS
   * ******************************************************************** *
	 
	// Preparing graph data 
	
	mat missing = .
	local name 	= ""
	
	use "$output/Data/ind_all_thresholds.dta", clear
	
	count
	local den = r(N)
	
	foreach var of varlist *Ext {
		count if missing(`var')
		mat missing = missing, 100* r(N)/`den'
	}	
	
	mat missing = missing[1,2...]
	mat missing = missing'
	
	clear
	svmat missing
	
	gen Dimension = ""
	local x = wordcount("$dimensions")
	forval i = 1/ `x' {
	    replace Dimension = "`: word `i' of $dimensions'" if _n == `i'
	}
		
   // Graph
   
   global graph_opts1 ///
	   bgcolor(white) ///
	   graphregion(color(white)) ///
	   legend(region(lc(none) fc(none))) ///
	   ylab(,angle(0) nogrid) ///
	   title(, justification(left) color(black) span pos(11)) ///
	   subtitle(, justification(left) color(black))
    global pct `" 0 "0%" .25 "25%" .5 "50%" .75 "75%" 1 "100%" "'
	   
	graph hbar (asis) missing1 ///
		, ///
		  over(Dimension) ///
		  asc ///
		  bargap(15) ///
		  nofill ///
		  blabel(bar, format(%9.2f)) ///
		  ${graph_opts1} ///
		  bar(1 , lc(black) lw(thin) fi(100)) ///
		  ytit("Percentage of missing values", ///
				   placement(bottom) ///
				   justification(center) ///
				   size(small)) ///
			graphregion(color(white)) bgcolor(white)
	graph export "$output/Graphics/MissingData.png", as(png) name("Graph")	replace
	
	
   * ******************************************************************** *
   *       SECT 2: BALANCED DATA CHECKING
   * ******************************************************************** *
   
   **** National level
   *----------------------------------------------------------------------*
   
	// Preparing graph data
	
   use "$output/Data/ind_all_thresholds.dta", clear
	
	lab def poor 1 "Extreme poors" 2 "Moderate poors" 3 "Non-poors"

	foreach dim of global dimensions {
	    gen 	Pov_`dim' = 1 if `= "`dim'" + "Ext"' == 1
		replace Pov_`dim' = 2 if `= "`dim'" + "Mod"' == 1
		replace Pov_`dim' = 3 if `= "`dim'" + "Ext"' == 0 & `= "`dim'" + "Mod"' == 0
		lab val Pov_`dim' poor
	}
	
	keep hhid indiv Pov*
	reshape long Pov_, i(hhid indiv) j(Dimension) string
	tab Pov_, gen(Pov__)
	
	merge m:1  hhid indiv using "$output/Data/ind_all_thresholds.dta", keepusing(wt_final state zone) // adding sample weights

		
   // Graph
	graph hbar Pov__* [pw = wt_final] ///
		, ///
		stack over(Dimension) nofill ///
		ylab(${pct}) ///
		legend(order(1 "Extremely deprived" ///
					 2 "Moderately deprived" ///
					 3 "Not deprived") ///
			   c(1) pos(3) ///
			   symxsize(small) symysize(small) size(small)) /// 
		blabel(bar, format(%9.2f) pos(center) size(vsmall)) ///
		${graph_opts1} ///
		bar(1,lw(thin) lc(black)) bar(2,lw(thin) lc(black)) ///
		bar(3,lw(thin) lc(black)) ///
		subtitle("Deprivation headcount per dimension", color(black))
	
	graph export "$output/Graphics/BalancedData.png", as(png) name("Graph")	replace
   
   
   **** Subational level
   *----------------------------------------------------------------------*   
   
   *| By state
// 	qui: elabel list (state)
// 	local label "`r(labels)'"  
//			
//    forval i = 1/37 {
// 		graph hbar Pov__* [pw = wt_final] ///
// 			if state == `i' ///
// 			, ///
// 			stack over(Dimension) nofill ///
// 			ylab(${pct}) ///
// 			legend(order(1 "Extremely deprived" ///
// 						 2 "Moderately deprived" ///
// 						 3 "Not deprived") ///
// 				   c(1) pos(3) ///
// 				   symxsize(small) symysize(small) size(small)) /// 
// 			blabel(bar, format(%9.1f)) ///
// 			${graph_opts1} ///
// 			bar(1,lw(thin) lc(black)) bar(2,lw(thin) lc(black)) ///
// 			bar(3,lw(thin) lc(black)) ///
// 			subtitle("`: word `i' of `label''", color(black)) ///
// 			name(g`i', replace) nodraw
// 		local graphs "`graphs' g`i'"
// 	}
//	
// 	graph combine `graphs', col(3) xsize(10) ysize(20) iscale(*0.8) xcom ycom
//	
// 	graph export "$output/Graphics/BalancedData_ByState.png", as(png) height(16000) name("Graph")	replace

   
   *| By zone
	qui: elabel list (zone)
	local label "`r(labels)'"  
   
   local graphs = "" 
   
   forval i = 1/6 {
		graph hbar Pov__* [pw = wt_final] ///
			if zone == `i' ///
			, ///
			stack over(Dimension) nofill ///
			ylab(${pct}) ///
			legend(order(1 "Extremely deprived" ///
						 2 "ly deprived" ///
						 3 "Not deprived") ///
				   c(1) pos(3) ///
				   symxsize(small) symysize(small) size(small)) /// 
			blabel(bar, format(%9.1f)) ///
			${graph_opts1} ///
			bar(1,lw(thin) lc(black)) bar(2,lw(thin) lc(black)) ///
			bar(3,lw(thin) lc(black)) ///
			subtitle("`: word `i' of `label''", color(black)) ///
			name(g`i', replace) nodraw
		local graphs "`graphs' g`i'"
	}
	
	graph combine `graphs', col(2) xsize(10) ysize(20) iscale(*0.8) xcom ycom
	
	graph export "$output/Graphics/BalancedData_ByZone.png", as(png) height(3000) name("Graph") replace
   
   
   
   * ******************************************************************** *
   *       SECT 3: ZOOM ON HEALTH DIMENSION: 
   
   *    Days out of activity due to health conditions					  *
   * ******************************************************************** *
   
	use "$output/Data/ind_all_thresholds.dta", clear

	// Average days out of activity due to injury or health condition by state and zone
	
	mean daysout [pw = wt_final] 
	local nat = e(b)[1,1]

	* | Zone/State level 
	foreach level in zone state {
// 		local level "state"
		preserve
			elabel list (`level')
			local x = r(max) 
			local label "`r(labels)'"
			
			mat daysout = `nat'

			forval i = 1/`x' {
				qui: mean daysout [pw = wt_final] if `level' == `i'
				mat daysout = daysout\ e(b)[1,1]
			}

			clear
			svmat daysout

			gen `level' = "National" if _n == 1
			forval i = 1/ `x' {
				replace `level' = "`: word `i' of `label' '" if _n == `i'+1
			}
		   
			separate daysout1, by(`level' == "National")
			graph bar (asis) daysout10 daysout11  ///
				, ///
				  over(`level', sort(1) lab(labsize(vsmall) angle(vertical))) ///
				  bargap(15) ///
				  nofill ///
				  blabel(bar, format(%9.1f) size(vsmall) orientation(vertical)) ///
				  legend(order(1 2) label(1 "Subnational") label(2 "National")) /// 
				  ${graph_opts1} ///
				  bar(1 , lc(black) lw(thin) fi(100)) ///
				  bar(2 , lc(black) lw(thin) fi(100) color(eltgreen )) ///
				  ytit("Average days out of activity due to health conditions last 30 days", ///
					   placement(bottom) ///
					   justification(center) ///
					   size(small)) 
			graph export "$output/Graphics/Daysout_By`level'.png", as(png) height(800) name("Graph")	replace
		restore
}
	
	
	// Potential monthly saisonality in average days out of activity due to health conditions
	
	gen 	month 		= month_of_interview + 3
	recode 	month 		(13=1) (14=2) (15=3)		
	lab def month 		1 "Oct18" 2 "Nov18" 3 "Dec18" 4 "Jan19" 5 "Feb19" 6 "Mar19" 7 "Apr19" 8 "May19" 9 "Jun19" 10 "Jul19" 11 "Aug19" 12 "Sep19"
	lab val month month
	tempfile monthlabel
	lab save month using `monthlabel', replace
	
	mean daysout [pw = wt_final] , over(month)
	mat daysout = r(table)[1, 1...]
	
	* | By Zone 
	elabel list (zone)
	local x = r(max) 
	local label "`r(labels)'"
	di `label'
			
	forval i = 1/6 {
		qui: mean daysout [pw = wt_final] if  zone == `i', over(month)
		mat daysout = daysout\ r(table)[1, 1...]
	}	
	mat daysout = daysout'
	
	clear
	svmat daysout
	
	gen Month = .
	forval i = 1/ 12 {
		replace Month = `i' if _n == `i'
	}
	do `monthlabel'
	lab val Month month
	
	reshape long daysout , i( Month ) j(Level)
		
	lab def Level 1 "National" 2 "North central" 3 "North east" 4 "Nort west" 5 "South east" 6 "South south" 7 "South west"
	lab val Level Level
	
	* | Graph
	twoway (connected daysout Month) ///
		, ///
		xlabel(#12, labels valuelabel) ///
		by(Level) ///
		${graph_opts1} ///
		xlabel(.,labsize(vsmall) angle(vertical)) ////
		ytit("Average days out of activity due to health conditions last 30 days", ///
			   placement(bottom) ///
			   justification(center) ///
			   size(small)) 

	graph export "$output/Graphics/Daysout_Saisonality.png", as(png) height(1000) name("Graph")	replace
	
	

   * ******************************************************************** *
   *       SECT 4: ZOOM ON MORTALITY DIMENSION: 
   
   *             Life expectancy at birth				  				  *
   * ******************************************************************** *
   
   **** Spatial differences in LEB & Monetary poverty
  *----------------------------------------------------------------------*   

   * | Poverty data
   use "$data/NGA_2018_LSS_v01_M_Stata/Household/totcons.dta", clear
   
   * Recoding state to match shape file order
	forval i = 1/23 {
		local x = 38 - `i'
		replace state = `x'+1 if state == `x'
	}
	replace state = 15 if state == 38
   
   * Poverty by state
   sepov totcons_adj [pw = popw] , povline($zref) by( state )
   mat Poverty = e(b)[1, 1..37]
   mat Poverty = Poverty'
   
   clear
   svmat Poverty
   
   gen state = .
   forval i = 1/37 {
		replace state = `i' if _n == `i'
   }
   
   tempfile tmp
   save `tmp'
   
   
  * | LEB data
	clear all
	input state LEB_all LEB_male LEB_female
	1 52 49 53
	2 43 42 44
	3 51 49 51
	4 48 47 50
	5 45 45 49
	6 50 47 53
	7 47 46 50
	8 43 42 48
	9 54 51 56 
	10 49 48 50
	11 48 47 52
	12 50 46 48
	13 53 48 53
	14 52 49 53
	15 52 50 55
	16 48 45 49
	17 53 50 52
	18 47 44 48
	19 45 43 48 
	20 47 46 49
	21 49 47 51
	22 52 48 50
	23 46 45 48
	24 52 48 53
	25 49 48 51
	26 50 45 51
	27 50 47 53  
	28 53 50 53
	29 52 50 52
	30 52 52 55
	31 51 51 55
	32 46 43 47
	33 47 46 49
	34 50 48 51
	35 47 48 51
	36 44 42 46
	37 50 47 50
	end
   
	merge 1:1 state using `tmp', nogen
	ren state _ID
	save "$output/Data/LEB_ByState.dta", replace
   
   
   * | Maps 
   * Setting up...
// 	set scheme white_tableau //, perm
// 	graph set window fontface "Arial Narrow"

	cd "$data/nga_adm_osgof_20190417"
	spshape2dta "nga_admbnda_adm1_osgof_20190417.shp", replace saving(NGAAdm1)
	
	
	* Merging shp file with mapping data
	use NGAAdm1, clear 
// 	keep _ID ADM1_EN _CX _CY 
	merge 1:1 _ID using "$output/Data/LEB_ByState.dta", nogen
	save "$output/Data/LEB_ByState.dta", replace
	
	* Creating map labels
	ren ADM1_EN state
	keep state _CX _CY 
	gen labtyp = 1 //names
	save "spmaplabels.dta", replace
	
// 	use "$output/Data/LEB_ByState.dta", clear
// 	drop state
// 	gen state = string(LEB_all, "%8.2f")
// 	replace labtyp = 2 //figures
// 	keep state _CX _CY labtyp
// 	append using `spmaplabels'
//	
// 	save "spmaplabels.dta", replace

	* Creating maps
	use NGAAdm1, clear 
	spmap using NGAAdm1_shp, ///
		id(_ID) ocolor(gs10 ..) osize(0.04 ..) ///
		polygon(data("NGAAdm1_shp") ocolor(black) osize(0.08) legenda(on) legl("States")) ///		
		point(data("$output/Data/LEB_ByState.dta") x(_CX) y(_CY) proportional(LEB_all) psize(relative) prange(42 54) fcolor(red%40) ocolor(black) osize(vthin) size(*1))   /// 
		label(data(spmaplabels) x(_CX) y(_CY) lab(state) size(small) pos(12 0)) ///
		legend(pos(11) size(1.5) symx(2.5) symy(1.5)) legtitle("% share") legstyle(2) ///
		title("{fontface Arial Bold: Life expectancy at birth}", size(medsmall)) ///
		note("Data source: STATISTICAL REPORT ON WOMEN AND MEN IN NIGERIA 2018", size(1.5))   ///
		name(g1, replace)
		
		
	use NGAAdm1, clear 
	spmap using NGAAdm1_shp, ///
		id(_ID) ocolor(gs10 ..) osize(0.04 ..) ///
		polygon(data("NGAAdm1_shp") ocolor(black) osize(0.08) legenda(on) legl("States")) ///		
		point(data("$output/Data/LEB_ByState.dta") x(_CX) y(_CY) proportional(LEB_male) psize(relative) prange(41 52) fcolor(purple%40) ocolor(black) osize(vthin) size(*1))   /// 
		label(data(spmaplabels) x(_CX) y(_CY) lab(state) size(small) pos(12 0)) ///
		legend(pos(11) size(1.5) symx(2.5) symy(1.5)) legtitle("% share") legstyle(2) ///
		title("{fontface Arial Bold: Life expectancy at birth(Male)}", size(medsmall)) ///
		note("Data source: STATISTICAL REPORT ON WOMEN AND MEN IN NIGERIA 2018", size(1.5))  ///  
		name(g2, replace) 
   
	use NGAAdm1, clear 
	spmap using NGAAdm1_shp, ///
		id(_ID) ocolor(gs10 ..) osize(0.04 ..) ///
		polygon(data("NGAAdm1_shp") ocolor(black) osize(0.08) legenda(on) legl("States")) ///		
		point(data("$output/Data/LEB_ByState.dta") x(_CX) y(_CY) proportional(LEB_female) psize(relative) prange(43 56) fcolor(green%40) ocolor(black) osize(vthin) size(*1))   /// 
		label(data(spmaplabels) x(_CX) y(_CY) lab(state) size(small) pos(12 0)) ///
		legend(pos(11) size(1.5) symx(2.5) symy(1.5)) legtitle("% share") legstyle(2) ///
		title("{fontface Arial Bold: Life expectancy at birth(Female)}", size(medsmall)) ///
		note("Data source: STATISTICAL REPORT ON WOMEN AND MEN IN NIGERIA 2018", size(1.5)) ///
		name(g3, replace) 
		
		
	colorpalette hcl, viridis n(10) nograph reverse 
	local colors `r(p)'	

	use "$output/Data/LEB_ByState.dta", clear
	format Poverty1* %9.1f
	spmap Poverty1 using NGAAdm1_shp, ///
		id(_ID) cln(5)  fcolor("`colors'") ///
		ocolor(gs10 ..) osize(0.04 ..) ///
		polygon(data("NGAAdm1_shp") ocolor(black) osize(0.08) legenda(on) legl("States")) ///		
		label(data(spmaplabels) x(_CX) y(_CY) lab(state) size(small) pos(12 0)) ///
		legend(pos(5) size(1.5) symx(2.5) symy(1.5)) legtitle("% Poverty rate") legstyle(2) ///
		title("{fontface Arial Bold: Monetary poverty rate}", size(medsmall)) ///
		name(g4, replace) 
   
   
	graph combine g1 g2 g3 g4, col(2) xsize(10) ysize(5) iscale(*1)   
	graph export "$output/Graphics/Mortality_ByState.png", as(png) height(1000) name("Graph") replace
   	
	
   **** Computing LGE using NGA 2016 mortality data
  *----------------------------------------------------------------------*   
	clear
	input x n midYearPop Deaths nmx qx px dx lx Lx Tx ex
	0 1 2953143 305165 0.1033 0.0982 0.9018 98176 1000000 931276.86 48971277.93 48.97
	1 1 2907385 254299 0.0875 0.0838 0.9162 75528 901824 848954.39 48040001.07 53.27
	2 1 8025251 115542 0.0144 0.0143 0.9857 11811 826296 818028.13 47191046.67 57.11
	3 1 6506133 18203 0.0028 0.0028 0.9972 2276 814485 812891.85 46373018.54 56.94
	4 1 7333442 10143 0.0014 0.0014 0.9986 1123 812209 811423.38 45560126.68 56.09
	5 1 6584198 10485 0.0016 0.0016 0.9984 1291 811087 810183.19 44748703.30 55.17
	6 1 7249441 15271 0.0021 0.0021 0.9979 1704 809796 808603.20 43938520.11 54.26
	7 1 6300307 27343 0.0043 0.0043 0.9957 3499 808092 805642.39 43129916.91 53.37
	8 1 7145841 10706 0.0015 0.0015 0.9985 1205 804593 803749.41 42324274.52 52.6
	9 1 5024520 14126 0.0028 0.0028 0.9972 2256 803388 801809.20 41520525.11 51.68
	10 1 6995135 17198 0.0025 0.0025 0.9975 1967 801133 799755.50 40718715.91 50.83
	11 1 2777403 19017 0.0068 0.0068 0.9932 5453 799165 795347.98 39918960.41 49.95
	12 1 5487665 8653 0.0016 0.0016 0.9984 1251 793712 792836.56 39123612.43 49.29
	13 1 3797048 14128 0.0037 0.0037 0.9963 2943 792461 790401.18 38330775.87 48.37
	14 1 4028550 8651 0.0021 0.0021 0.9979 1694 789518 788332.67 37540374.70 47.55
	15 1 4837901 5568 0.0012 0.0012 0.9988 906 787825 787190.20 36752042.03 46.65
	16 1 3171398 3736 0.0012 0.0012 0.9988 927 786918 786269.74 35964851.83 45.7
	17 1 2718231 7049 0.0026 0.0026 0.9974 2036 785992 784566.79 35178582.09 44.76
	18 1 4434568 3859 0.0009 0.0009 0.9991 682 783956 783478.68 34394015.31 43.87	
	20 2 7347391 25388 0.0035 0.0069 0.9931 5394 783274 779498.08 33610536.62 42.91	
	21 1 1522971 3850 0.0025 0.0025 0.9975 1964 777880 776504.93 32831038.54 42.21
	22 1 2597783 7115 0.0027 0.0027 0.9973 2122 775916 774430.17 32054533.62 41.31
	24 2 3635024 3953 0.0011 0.0022 0.9978 1681 773794 772616.77 31280103.45 40.42
	25 1 5274815 17165 0.0033 0.0032 0.9968 2509 772112 770356.50 30507486.68 39.51
	27 2 4000880 3973 0.001 0.002 0.998 1527 769604 768534.98 29737130.19 38.64
	28 1 2896484 6551 0.0023 0.0023 0.9977 1735 768077 766862.25 28968595.21 37.72
	29 1 1238109 1831 0.0015 0.0015 0.9985 1132 766342 765549.07 28201732.95 36.8
	30 1 6556471 8670 0.0013 0.0013 0.9987 1011 765209 764501.54 27436183.88 35.85
	33 3 4002987 1586 0.0004 0.0012 0.9988 908 764198 763562.87 26671682.34 34.9
	34 1 892274 3110 0.0035 0.0035 0.9965 2656 763291 761431.69 25908119.46 33.94
	35 1 5057560 15345 0.003 0.003 0.997 2304 760635 759022.02 25146687.78 33.06	
	36 1 1272403 7299 0.0057 0.0057 0.9943 4338 758331 755294.20 24387665.75 32.16	
	40 4 10051145 3859 0.0004 0.0015 0.9985 1157 753993 753182.78 23632371.56 31.34	
	41 1 565322 1010 0.0018 0.0018 0.9982 1344 752836 751894.72 22879188.78 30.39
	42 1 1629530 6957 0.0043 0.0043 0.9957 3201 751491 749250.43 22127294.06 29.44
	43 1 837954 6082 0.0073 0.0072 0.9928 5412 748290 744501.86 21378043.63 28.57
	44 1 487847 1987 0.0041 0.0041 0.9959 3019 742878 740765.03 20633541.77 27.78
	45 1 3680203 8963 0.0024 0.0024 0.9976 1800 739859 738599.49 19892776.74 26.89
	47 2 1454203 895 0.0006 0.0012 0.9988 908 738060 737423.75 19154177.25 25.95
	49 2 2026480 17421 0.0086 0.017 0.983 12565 737151 728355.45 18416753.50 24.98
	50 1 4166352 8057 0.0019 0.0019 0.9981 1400 724586 723605.86 17688398.05 24.41
	52 2 1387303 897 0.0006 0.0013 0.9987 935 723186 722531.34 16964792.20 23.46
	53 1 430336 1008 0.0023 0.0023 0.9977 1690 722251 721067.74 16242260.85 22.49
	54 1 546568 6093 0.0111 0.0111 0.9889 7988 720561 714968.77 15521193.12 21.54
	55 1 1715118 803 0.0005 0.0005 0.9995 334 712572 712338.73 14806224.34 20.78
	56 1 629649 577 0.0009 0.0009 0.9991 653 712239 711781.64 14093885.62 19.79
	58 2 1041570 14249 0.0137 0.027 0.973 19206 711586 698141.71 13382103.97 18.81
	59 1 205036 2595 0.0127 0.0126 0.9874 8707 692380 686284.82 12683962.26 18.32 
	60 1 2855288 18414 0.0064 0.0064 0.9936 4395 683673 680596.14 11997677.44 17.55 
	61 1 199019 778 0.0039 0.0039 0.9961 2652 679278 677421.38 11317081.30 16.66
	62 1 539974 1126 0.0021 0.0021 0.9979 1410 676626 675639.06 10639659.92 15.72
	63 1 304120 3973 0.0131 0.013 0.987 8764 675216 669081.11 9964020.86 14.76
	64 1 215930 3086 0.0143 0.0142 0.9858 9457 666452 659831.60 9294939.75 13.95
	65 1 1335731 2856 0.0021 0.0021 0.9979 1403 656994 656011.95 8635108.15 13.14
	66 1 184973 2742 0.0148 0.0147 0.9853 9645 655591 648839.36 7979096.20 12.17
	68 2 686846 337 0.0005 0.001 0.999 634 645946 645501.77 7330256.84 11.35 
	70 2 1669653 13204 0.0079 0.0157 0.9843 10126 645311 638223.02 6684755.07 10.36 
	71 1 101547 7051 0.0694 0.0671 0.9329 42610 635185 605358.04 6046532.05 9.52
	72 1 366466 3074 0.0084 0.0084 0.9916 4950 592575 589110.28 5441174.00 9.18
	73 1 189769 4086 0.0215 0.0213 0.9787 12518 587625 578863.03 4852063.72 8.26
	74 1 101271 1121 0.0111 0.011 0.989 6331 575108 570675.96 4273200.70 7.43
	75 1 499257 4199 0.0084 0.0084 0.9916 4764 568777 565442.11 3702524.73 6.51
	78 3 322143 4087 0.0127 0.0373 0.9627 21064 564013 549268.02 3137082.62 5.56 
	80 2 622480 15159 0.0244 0.0475 0.9525 25811 542949 524881.22 2587814.60 4.77
	83 3 143531 2948 0.0205 0.0598 0.9402 30900 517138 495508.23 2062933.38 3.99
	84 1 52413 917 0.0175 0.0173 0.9827 8432 486238 480335.68 1567425.15 3.22
	85 1 138692 1122 0.0081 0.0081 0.9919 3850 477806 475111.00 1087089.47 2.28
	86 1 117264 1035 0.0088 0.0088 0.9912 4164 473956 471040.97 611978.47 1.29 
	90 4 228228 15245 0.0668 0.2345 0.7655 110154 469792 140937.50 140937.50 0.3	
	end
	
	replace nmx = Deaths/midYearPop // not rounded
	mkmat nmx, mat(NGA_mu_2016) rown(x)
	
	cap prog drop LGE
	prog def LGE, rclass
	 
		syntax anything(name = nmx id = "mortality rates matrix"), AHAT(integer)
		
			local all_age: rowvarlist `nmx'
			local LGE_ahat = 0
			
			forval a = 0/`=`ahat'-1' {
							
				*Test if a age present 
				local alist "`a'"
				local test: list alist in all_age
				
				if `test' == 1 {
				
					* Product term 
					local prod = 1
					if `a' >0 {
						forval k = 0/`=`a'-1' {
							* Test if k age present
							local klist "`k'"
							local test: list klist in all_age
							
							if `test' == 1  { 
								local prod = `prod' * (1- `nmx'[rownumb(`nmx', "`k'"),1])
							}
						}
					}	
					local LGE_ahat = `LGE_ahat' + (`ahat' - (`a' + 1)) * `nmx'[rownumb(`nmx', "`a'"),1] * `prod'
				}
			}
			return local LGE_ahat `LGE_ahat'
	end

	//Check if programs works well
	LGE NGA_mu_2016, ahat(50)
	return list // good
	
	//Compute LGE_ahat for NGA, ages 50, 60, 70, 80
	mat NGA_LGE_ahat = J(5,1,.)
	mat rownames NGA_LGE_ahat = 50 60 65 70 80
	
	forval i = 1/ `=rowsof(NGA_LGE_ahat)' {
	    LGE NGA_mu_2016, ahat(`:word `i' of `:rownames NGA_LGE_ahat  '')
		mat NGA_LGE_ahat[`i',1] = `r(LGE_ahat)'
	}
	mat list NGA_LGE_ahat
	
	
	
	
	**** Computing LGE by state 
	*----------------------------------------------------------------------*   
	
	/* 
	Step 1: Compute algo to estimate LEB using  age- specific mortality rates 
	Step 2: Algo de choix de alpha facteur multiplicatif des age- specific mortality rates  par Etat
	Step 3: Apply the previous algo to find optimal alpha and compute LGE_ahat matrix for each state
	
	*/
	* |Step 1
	cap prog drop LEB
	prog define LEB
		syntax anything(name = nmx id = "mortality rates matrix") 
	
		// Set up matrix
		cap mat drop summary
		mat summary 			= J(rowsof(`nmx'), 13, .)
		mat colnames summary 	= x n midYearPop Deaths nmx nkx qx px dx Ix Lx Tx ex
		
		//Fill in col x, Pop Deaths 
		foreach col in x n midYearPop Deaths {
		    forval i = 1/`=rowsof(`nmx')' {
			    mat summary[`i', colnumb(summary, "`col'")] = `nmx'[`i', colnumb(summary, "`col'")]
			}
		}
		
		// Fill in n, nmx, qx, px --> I noticed some issue with the n in the initial data
		forval i =1 / `=rowsof(`nmx')'{
// 		    if `i'< `=rowsof(`nmx')' {
// 				mat summary[`i', colnumb(summary, "n")] 	= summary[`i'+1, colnumb(summary, "x")] - summary[`i', colnumb(summary, "x")]
// 				mat summary[`i', colnumb(summary, "nkx")] 	= summary[`i', colnumb(summary, "n")] / 2
// 			}
			mat summary[`i', colnumb(summary, "nkx")]	= 0.3
			
		    mat summary[`i', colnumb(summary, "nmx")] 	= summary[`i', colnumb(summary, "Deaths")] / summary[`i', colnumb(summary, "midYearPop")]
		    mat summary[`i', colnumb(summary, "qx")] 	= 1 - exp(-summary[`i', colnumb(summary, "n")] * summary[`i', colnumb(summary, "nmx")])
			mat summary[`i', colnumb(summary, "px")] 	= 1 - summary[`i', colnumb(summary, "qx")]
		}
// 		mat summary[`=rowsof(`nmx')', colnumb(summary, "nkx")] 	= 1/ summary[`=rowsof(`nmx')', colnumb(summary, "nmx")]

		
		// Fill in dx, Ix, Lx
		mat summary[1, colnumb(summary, "Ix")] = 1000000
		
		forval i = 1 / `=rowsof(`nmx')'{
		    mat summary[`i', colnumb(summary, "dx")] 	= summary[`i', colnumb(summary, "Ix")] * summary[`i', colnumb(summary, "qx")]
			if `i'< `=rowsof(`nmx')' {
			    mat summary[`i'+1, colnumb(summary, "Ix")]	= summary[`i', colnumb(summary, "Ix")] - summary[`i', colnumb(summary, "dx")]
// 				mat summary[`i', colnumb(summary, "Lx")] 	= summary[`i', colnumb(summary, "n")] * summary[`i'+1, colnumb(summary, "Ix")] + ///
// 															  summary[`i', colnumb(summary, "nkx")] * summary[`i', colnumb(summary, "dx")]	
				mat summary[`i', colnumb(summary, "Lx")] 	= summary[`i'+1, colnumb(summary, "Ix")] + ///
															  summary[`i', colnumb(summary, "nkx")] * summary[`i', colnumb(summary, "dx")]	
			}
			else mat summary[`i', colnumb(summary, "Lx")] 	= summary[`i', colnumb(summary, "nkx")] * summary[`i', colnumb(summary, "dx")]
		}
		
		// Fill in Tx, ex
		mat summary[`=rowsof(`nmx')', colnumb(summary, "Tx")] = summary[`=rowsof(`nmx')', colnumb(summary, "Lx")]
		mat summary[`=rowsof(`nmx')', colnumb(summary, "ex")] = summary[`=rowsof(`nmx')', colnumb(summary, "Tx")] / summary[`=rowsof(`nmx')', colnumb(summary, "Ix")]
		
		forval i = `=rowsof(`nmx')-1'(-1)1 {
		    mat summary[`i', colnumb(summary, "Tx")] = summary[`i'+1, colnumb(summary, "Tx")] + summary[`i', colnumb(summary, "Lx")] 
			mat summary[`i', colnumb(summary, "ex")] = summary[`i', colnumb(summary, "Tx")] / summary[`i', colnumb(summary, "Ix")]
		}
	end
	
	// Check if program works well
	mkmat x n midYearPop Deaths, mat(NGADeaths_2016)
	LEB NGADeaths_2016
	
	
	* |Step 2
	cap prog drop optimalAlpha
	prog define optimalAlpha, rclass
		
		syntax 	anything(name = nmx_NGA id  = "national mortality rates"), EOSTATE(integer) STEP(real)
				
		// Set up matrix
		cap mat drop mortality_rate
		mat mortality_rate 					= J(rowsof(`nmx_NGA'), 4, .)
		mat colnames mortality_rate 		= x n midYearPop Deaths
		
		//Fill in columns x n midYearPop Deaths	
		forval i = 1/`=rowsof(`nmx_NGA')' {
			foreach col in x n midYearPop {
			    mat mortality_rate[`i', colnumb(summary, "`col'")] = `nmx_NGA'[`i', colnumb(summary, "`col'")]
			}
		}
		
		// Optimal alpha finding
		cap mat drop opt_res
		local occ = 0 
		
		forval alpha = `step'(`step')5 {
		    
		    local occ = `occ' +1  
		    
		    forval i = 1/`=rowsof(`nmx_NGA')' {
				mat mortality_rate[`i', colnumb(summary, "Deaths")] = `alpha' * `nmx_NGA'[`i', colnumb(summary, "Deaths")] 
			}
			
			LEB mortality_rate
			if `occ' == 1  	mat opt_res = (`alpha', round(summary[1,colnumb(summary, "ex")]))
			else 			mat opt_res = opt_res \ (`alpha', round(summary[1,colnumb(summary, "ex")]))
			
			if round(summary[1,colnumb(summary, "ex")]) == `eostate'{
			    return local alphaOpt  `alpha'
				continue, break
			} 	
		}
		
	end
	
	// Check if programs works well
	optimalAlpha NGADeaths_2016 , eostate(49) step(0.05)  // National LEB
	return list // alpha =1 very good 
	
	
	* |Step 3
	use "$output/Data/LEB_ByState.dta", clear
	
	keep _ID ADM1_EN LEB_all
	
	local ahat 50 60 65 70 80
	foreach j of local ahat {
		gen LGE_ahat_`j' = .
	}
	
	forval i = 1/`=_N' {
	    
	    //State name
		local stateName = ADM1_EN[`i']
	    
	    // Find optimal alpha and mortality rates
		optimalAlpha NGADeaths_2016 , eostate(`=LEB_all[`i']') step(0.05) 
		local alpha = `r(alphaOpt)'
		mat mu = `alpha' * NGA_mu_2016
		
		//Compute LGE_ahat for State, ages 50, 60, 70, 80
		foreach j of local ahat {
			LGE mu, ahat(`j')
			replace LGE_ahat_`j' =  `r(LGE_ahat)' if _n == `i'
		}
	}
	
	save "$output/Data/LGE_ByState.dta", replace
	

   * ******************************************************************** *
   *       SECT 5: OVERVIEW OF MAIN DIMENSION'S INDICATORS
   
   * ******************************************************************** *

   
   * | INDICATORS COMPUTATION
   *----------------------------------------------------------------------*
   use "$output/Data/BasicIndicators.dta", clear
   
   **** Data preparation
	gen 		childstunted = (stunting_cat ==1 | stunting_cat ==2) if age <= 5

	gen 		wundern			= (bmi_cat ==1) if sex == 0 & age >=15 & age <=49
	gen 		mundern			= (bmi_cat ==1) if sex == 1 & age >=15 & age <=49

	gen 		wobese			= (bmi_cat ==2) if sex == 0 & age >=15 & age <=49
	gen 		mobese			= (bmi_cat ==2) if sex == 1 & age >=15 & age <=49

	replace 	childnotenrolled = . if age > 14

	replace 	adultprimary  	 = . if age <= 14
	replace 	adultprimary  	 = 1 - adultprimary
	
	replace 	adultwr  	 = . if age <= 14
	replace 	adultwr  	 = 1 - adultwr
	
	foreach var of varlist b_impwater b_impsanitation electricity goodHousing {
		replace `var' = 1 - `var'
	}
   

   **** Calculations
   local i = 0
   local varlist 	Monetary2Ext Monetary2Mod Disability_Ext Disability_Mod childstunted wundern mundern wobese mobese ///
					childnotenrolled adultprimary adultwr b_impwater b_impsanitation electricity goodHousing crimeExt crimeMod
					
   foreach var of varlist `varlist' {
		recode `var' (1 = 100)
		local i = `i' + 1
		sum `var'[iw = wt_final]
		local mean_`i' = r(mean)						
	}
   
   
   * | TABLE SET UP (EXCEL)
   *----------------------------------------------------------------------*
   	putexcel set "${output}/Tables/Indicators.xlsx", modify

	forval i = 1/`:word count `varlist'' {
		putexcel D`=2 + `i'' = `mean_`i''
	}
   
   
   * | TABLE SET UP (LATEX)
   *----------------------------------------------------------------------*
	
// % Please add the following required packages to your document preamble:
// % \usepackage{multirow}
// % \usepackage[table,xcdraw]{xcolor}
// % If you use beamer only pass "xcolor=table" option, i.e. \documentclass[xcolor=table]{beamer}

cap file close fh
file open fh using "${output}/Tables/Indicators.tex", write replace

file write fh "\begin{table}[]" _n
file write fh "\centering" _n
file write fh "\begin{adjustbox}{width=1\textwidth}" _n
file write fh "\begin{tabular}{llc}" _n
file write fh "\hline" _n
file write fh "\rowcolor[HTML]{E7E6E6}" _n

file write fh ///
"\textbf{Dimensions}                & \textbf{Indicators}                                                      & \textbf{\% of Individuals} \\ \hline" _n

file write fh ///
"                                   & Household annual   consumption per capita is below national poverty line &" %14.1fc (`mean_1') ///
"                          \\ \cline{2-3}" _n

file write fh ///
"\multirow{-2}{*}{\textbf{Monetary}}  & Household annual consumption per capita is above national   poverty line but below state societal poverty line &" %14.1fc (`mean_2') "\\ \hline" _n

file write fh ///
"                                   & Individual   suffers from at least one severe disability                 &" %14.1fc (`mean_3') ///
"                          \\ \cline{2-3}" _n
file write fh	///							
"                                   & Individual suffers from at least one mild disability                     &" %14.1fc (`mean_4') ///
"                          \\ \cline{2-3}" _n
file write fh	///							   
"                                   & Children suffers from stunting                                           &" %14.1fc (`mean_5') ///
"                          \\ \cline{2-3}" _n
file write fh	///							   
"                                   & Undernourished women 15-49                                               &" %14.1fc (`mean_6') ///
"                          \\ \cline{2-3}" _n
file write fh	///							   
"                                   & Undernourished men 15-49                                                 &" %14.1fc (`mean_7') ///
"                          \\ \cline{2-3}" _n
file write fh	///							   
"                                   & Obese women 15-49                                                        &" %14.1fc (`mean_8') ///
"                          \\ \cline{2-3}" _n
file write fh	///							   
"\multirow{-7}{*}{\textbf{Health}}  & Obese men 15-49                                                          &" %14.1fc (`mean_9') ///
"                          \\ \hline" _n

file write fh ///
"                                   & School-age child   up to the age of grade 8 not enrolled in school       &" %14.1fc (`mean_10') ///
"                          \\ \cline{2-3}" _n 
file write fh ///							   
"                                   & Adults -age of grade 9 or above has not completed primary   education    &" %14.1fc (`mean_11') ///
"                          \\ \cline{2-3}" _n 
file write fh ///								   
"\multirow{-3}{*}{\textbf{Education}} & Adults -age of grade 9 or above can read or write                       &" %14.1fc (`mean_12') "\\ \hline" _n

file write fh ///
"                                   & Household lacks access to basic-standard drinking water                  &" %14.1fc (`mean_13') ///
"                          \\ \cline{2-3}" _n 
file write fh ///								   
"                                   & Household lacks access to basic-standard sanitation                      &" %14.1fc (`mean_14') ///
"                          \\ \cline{2-3}" _n
file write fh ///								   
"                                   & Household has no access to electricity                                   &" %14.1fc (`mean_15') ///
"                          \\ \cline{2-3}" _n 
file write fh ///
"\multirow{-4}{*}{\textbf{Housing}} & Household has inadequate housing                                         &" %14.1fc (`mean_16') ///
"                          \\ \hline" _n

file write fh ///
"                                   & Individual   belongs to a household, subjected the last 12 months to an extreme insecurity   event             &" %14.1fc (`mean_17') "\\ \cline{2-3}" _n 
								   
file write fh ///								   								   
"\multirow{-2}{*}{\textbf{Security}}  & Individual belongs to a household, subjected the last 12 months   to a moderate insecurity event               &" %14.1fc (`mean_18') "\\ \hline" _n

file write fh "\end{tabular}" _n
file write fh "\end{adjustbox}" _n
file write fh "\end{table}" _n
file close fh

