
   * ******************************************************************** *
   *                                                                      *
   *          IMPROVED MULTIDIMENSIONNAL POVERTY MEASUREMENT IN NIGERIA   *
   *                		USER - DEFINED PROGRAMS                        *
   *                                                                      *
   * ******************************************************************** *
   * ******************************************************************** *

       /*
       ** PURPOSE:      DEFINE OUR SPECIFIC COMMANDS 

       ** OUTLINE:      SECT 1: DATA PREPARATION
                        SECT 2: PROGRAM DEFINITION
       */


   * ******************************************************************** *
   *       SECT 1: DATA PREPARATION
   * ******************************************************************** *
     
  *| Computing LE and LGE per zone
  /* 
  We agree to compute it as weighted average of state level data, state population used as weights.
  Weights used are 2020 population from https://data.humdata.org/dataset/cod-ps-nga 
  */
	import excel "$data/nga_adm_osgof_20190417/nga_admpop_2020.xlsx", sheet("nga_admpop_adm1_2020") cellrange(A1:G38) firstrow clear

	gen 		ADM1_EN = substr(ADM1_NAME, 1, 1)+ lower(substr(ADM1_NAME, 2, .))
	replace 	ADM1_EN = "Akwa Ibom" if ADM1_EN == "Akwa ibom"
	replace 	ADM1_EN = "Cross River" if ADM1_EN == "Cross river"
	replace 	ADM1_EN = "Federal Capital Territory" if ADM1_EN == "Federal capital territory"

	keep 	ADM1_EN T_TL
	ren 	T_TL Population
	merge 1:1 ADM1_EN using "$projectfolder/output/Data/LGE_ByState.dta", nogen
	
	cap drop zone
	gen 	 zone = 1 if inlist(ADM1_EN, "Benue", "Kogi", "Kwara", "Nasarawa", "Niger", "Plateau", "Federal Capital Territory")
	replace	 zone = 2 if inlist(ADM1_EN, "Adamawa", "Bauchi", "Borno", "Gombe", "Taraba", "Yobe")
	replace	 zone = 3 if inlist(ADM1_EN, "Jigawa", "Kaduna", "Kano", "Katsina", "Kebbi", "Sokoto", "Zamfara")
	replace	 zone = 4 if inlist(ADM1_EN, "Abia", "Anambra", "Ebonyi", "Enugu", "Imo")
	replace	 zone = 5 if inlist(ADM1_EN, "Akwa Ibom", "Bayelsa", "Cross River", "Delta", "Edo", "Rivers")
	replace	 zone = 6 if inlist(ADM1_EN, "Ekiti", "Lagos", "Ogun", "Ondo", "Osun", "Oyo")
	
	foreach var of varlist LEB_all LGE_ahat_50 LGE_ahat_60 LGE_ahat_65 LGE_ahat_70 LGE_ahat_80 {
		cap drop need*
		gen 	 need1 = `var' * Population
		bysort   zone: egen need2 = total(Population)
		gen 	 need3 = need1/need2
		cap drop `var'_zone
	    bysort 	 zone: egen `var'_zone = total(need3)
	}
	replace LEB_all_zone = round(LEB_all_zone)
	drop 	need*
	
  	save "$projectfolder/output/Data/LGE_ByState.dta", replace   
  

  *| Recoding state to match NLSS data
  
  	replace _ID = 38 if _ID == 15
	forval i = 16/37 {
		replace _ID = `i'-1 if _ID == `i'
	}
  	replace _ID = 37 if _ID == 38
	
	ren 	 _ID state
	tempfile tmp
	save 	 `tmp'
	
	
	*| Merging and other cleaning
  
	use "$projectfolder/output/Data/ind_all_thresholds.dta", clear
	merge m:1 state using `tmp', nogen
	
	
	*| Available dimensions
	
	global dimensions ""
	foreach var of varlist *Ext {
		local 	name =  subinstr("`var'","Ext","",1) 
		global 	dimensions: list global(dimensions) | local(name) 
	}
	macro list dimensions   
	
	
   * ******************************************************************** *
   *       SECT 2: PROGRAMS DEFINITION
   * ******************************************************************** *
	
   **** MULTIDIMENSIONAL POVERTY STATUS: Program definition
  *----------------------------------------------------------------------*   
	
	cap prog drop 	MDP
	prog define 	MDP, rclass
		
		syntax ,VARlist(namelist max=5) ///
				POVMOD(integer) ///
				[EXTreme	///
				EXTMETH(name) ///
				POVEXT(integer 2) ///
				noMONetary] //not to add monetary dimension
		

		*| Arguments validity checking		
		
		* POVMOD maximal value should be n_varlist
		local n_varlist: word count `varlist'
		if `povmod' > `n_varlist'  {
			display as error "POVMOD is incorrect" in red
			exit
		}
		
		* EXTMETH should be filled in if EXTreme on
		if !missing("`extreme'")  & missing("`extmeth'")  {
			display as error "EXTMETH must be filled in" in red
			exit
		}
		
		* EXTMETH should be on of ext(extremors), cum(cumulators), both(both)
		if !missing("`extreme'") & !inlist("`extmeth'", "ext", "cum", "both") {
			display as error "EXTMETH is incorrect, type ext, cum or both" in red
			exit
		}
		
		*POVEXT should be filled in if extreme method chosen is either cum or both
		if !missing("`extreme'") & inlist("`extmeth'", "cum", "both") & missing("`povext'") {
			display as error "POVEXT must be filled in" in red
			exit
		}
		
		* POVEXT should be greater than POVMOD and lower than n_varlist
		if !missing("`extreme'") & !missing("`povext'") & (`povext' > `n_varlist' | `povext' <= `povmod')  {
			display as error "POVEXT is incorrect" in red
			exit
		}
		
		*| Muldimensionnal poverty status definition
		cap drop MDPStatus
			
		* Number of dimensions individual is poor
		cap drop need_*
		
		if !missing("`monetary'"){
			local need Monetary1 Monetary2
			local varlist: list varlist - need
		}
		
		foreach dim of local varlist {
		    gen need_`dim' = (`= "`dim'" + "Ext"' == 1 | `= "`dim'" + "Mod"' == 1) if !missing(`= "`dim'" + "Ext"') | !missing(`= "`dim'" + "Mod"')
		}
		tempvar nDimPoor
		egen 	`nDimPoor' = rowtotal(need_*),mi
		drop need_*
		
		* MDP status when extreme MDpoverty ignored
		if missing("`extreme'") {
			gen 	MDPStatus = (`nDimPoor' >= `povmod')  if !missing(`nDimPoor')
			
			foreach dim of local varlist {
				replace MDPStatus = 1 if `= "`dim'" + "Ext"' == 1 // extremors are MD poors
			}
			
// 			if missing("`monetary'") replace MDPStatus = 1 if MonetaryExt == 1 // All monetary poors are MD poors --> repetition of previous lines
		}
		
// 		* MDP status when extreme MDpoverty taken into account --> to be removed or reviewed
// 		else { // !missing("`extreme'")
// 		    if "`extmeth'" == "ext" {
// 				gen 	MDPStatus = (`nDimPoor' >= `povmod')  if !missing(`nDimPoor')
// 				foreach dim of local varlist {
// 				    replace MDPStatus = 2 if `= "`dim'" + "Ext"' == 1
// 				}
// 				if missing("`monetary'") replace MDPStatus = 1 if MonetaryExt == 1 // All monetary poors are MD poors
// 			}
// 			else if "`extmeth'" == "cum" {
// 				gen 	MDPStatus = (`nDimPoor' >= `povmod')  if !missing(`nDimPoor')
// 				replace MDPStatus = 2 if `nDimPoor' >= `povext' & !missing(`nDimPoor')
// 				if missing("`monetary'") replace MDPStatus = 1 if MonetaryExt == 1 // All monetary poors are MD poors
// 			}
// 			else { // "`extmeth'" == "both"
// 				gen 	MDPStatus = (`nDimPoor' >= `povmod')  if !missing(`nDimPoor')
// 				replace MDPStatus = 2 if `nDimPoor' >= `povext' & !missing(`nDimPoor')
// 				foreach dim of varlist varlist {
// 				    replace MDPStatus = 2 if `= "`dim'" + "Ext"' == 1
// 				}
// 				if missing("`monetary'") replace MDPStatus = 1 if MonetaryExt == 1 // All monetary poors are MD poors
// 			}
// 		}
		
		lab def MDPStatus 0 "Non poor" 1 "Moderate poor" 2 "Extreme poor", modify
		lab val MDPStatus MDPStatus
		
		tab MDPStatus, matcell(freq)
		mat freq = 100*freq/r(N)
		
		if rowsof(freq) == 2 matrix rownames freq = "Non poor" "Moderate poor"
		else				 matrix rownames freq = "Non poor" "Moderate poor" "Extreme poor"		
		
		return mat MDPStatus = freq  
	end
	
	
   **** Decomposition on MDP (ONMP + OMP + B)
  *----------------------------------------------------------------------*  
  
	cap prog drop MDPDecomp 
	prog def MDPDecomp

		syntax ,VARlist(namelist max=5) ///
				POVMOD(integer) ///
				[EXTreme	///
				EMDPDecomp ///
				EXTMETH(name) ///
				POVEXT(integer 2)]
				
		*| Arguments validity checking		
		
		* Consistency between EMDPDecomp and EXTreme
		
		*| Overall MDP
		if missing("`extreme'") 	MDP , varlist(`varlist') povmod(`povmod')
		else						MDP , varlist(`varlist') povmod(`povmod') ext extmeth("`extmeth'") povext(`povext')
		
		if missing("`emdpdecomp'") {
			tempvar MDP1
			gen 	`MDP1' = MDPStatus
			replace `MDP1' = 1 if MDPStatus == 2
		}
		else {
			tempvar MDP1
			gen 	`MDP1' 	= MDPStatus
			replace `MDP1' = 0 if MDPStatus == 1
			replace `MDP1' 	= 1 if MDPStatus == 2
		}		
		
	  *| ONMP 
		local name :word 1 of `varlist'
		local name = "`name'" + "Ext"
		tempvar MonetaryExt
		gen `MonetaryExt' = `name'
				
		tab `MonetaryExt' `MDP1'
		tempvar tag1
		gen 	`tag1' = 1 if `MDP1' == 1 & `MonetaryExt' == 0 
	  
	  
	  *| OMP 
		if missing("`extreme'") 	MDP , varlist(`varlist') povmod(`povmod') nomon
		else						MDP , varlist(`varlist') povmod(`povmod') ext extmeth("`extmeth'") povext(`povext') nomon
		
		if missing("`emdpdecomp'") {
			tempvar MDP2
			gen 	`MDP2' = MDPStatus
			replace `MDP2' = 1 if MDPStatus == 2
		}
		else {
			tempvar MDP2
			gen 	`MDP2' 	= MDPStatus
			replace `MDP2' = 0 if MDPStatus == 1
			replace `MDP2' 	= 1 if MDPStatus == 2
		}		
				
		tab 	`MDP1' `MDP2'
		tempvar tag2	
		gen 	`tag2' = 1 if `MDP1' == 1 & `MDP2' == 0 
		
		tab `tag1' `tag2' // good
		
		*| Decomposition
		cap drop MDPDecomp
		gen 	MDPDecomp = 3 if `MDP1' == 1
		replace MDPDecomp = 1 if `tag1' == 1
		replace MDPDecomp = 2 if `tag2' == 1
		
		replace MDPDecomp = 1 if MDPDecomp  == 2 & `MonetaryExt' == 0 // adjustment asked by Benoit
		
		lab def MDPDecomp 1 "Only non-monetary poor" 2 "Only monetary poor" 3 "Both", modify
		lab val MDPDecomp MDPDecomp
		
		tab `MDP1' MDPDecomp

	end
  
	//	Test of two previous programs
// 	local varlist Monetary1 Education1 Health1 Housing5 Security1
// 	local povmod 2
//	
// 	MDPDecomp 	, varlist(`varlist') povmod(`povmod')	
// 	MDP 		, varlist(`varlist') povmod(`povmod')	
// 	tab MDPStatus MDPDecomp,m  // good
	
	
	
   **** Decomposition on MDP (Extremor - Cumulator)
  *----------------------------------------------------------------------*  
	cap prog drop MDPDecomp2
	prog define MDPDecomp2
					
		syntax ,MDPStatus(varname numeric) ///
				MDPDecomp(varname numeric) ///
				VARlist(namelist max=5)
				
		local monetary Monetary1 Monetary2
		local varlist_nomo: list varlist - monetary
		
		local name :word 1 of `varlist'
		local name = "`name'" + "Ext"
		tempvar MonetaryExt
		gen `MonetaryExt' = `name'
	
		cap drop MDPDecomp__*
		tab `mdpdecomp', gen(MDPDecomp__)
		recode MDPDecomp__* (. = 0)
	
		cap drop MDPDecomp2
		
		* Extremor - non monetary
		gen MDPDecomp2 = 0 if `mdpstatus' == 0		
		foreach dim of local varlist_nomo {
			replace MDPDecomp2 = 4 if `mdpstatus' == 1 & `= "`dim'" + "Ext"' == 1
		}
		
		* Extremor - monetary poor
		replace MDPDecomp2 = 1 if `mdpstatus' == 1 & `MonetaryExt' == 1 & MDPDecomp__2 == 1 //OMP
		foreach dim of local varlist_nomo {
			replace MDPDecomp2 = 2 if `mdpstatus' == 1 & `MonetaryExt' == 1 & MDPDecomp__2 == 0 &  `= "`dim'" + "Ext"' == 1
		}
		replace MDPDecomp2 = 3 if `mdpstatus' == 1 & `MonetaryExt' == 1 & !inlist(MDPDecomp2,1,2)
		
		* Cumulator
		replace MDPDecomp2 = 5 if missing(MDPDecomp2) & `mdpstatus' == 1
		
		lab def MDPDecomp2 	0 "Non poor" 1 "Monetary extremor – only monetary poor"  2 "Monetary extremor – other dimension extremor" ///
							3 "Monetary extremor – other dimension cumulator" 4 "Extremor – non-monetary poor" 5 "Cumulator", replace
		lab val MDPDecomp2 MDPDecomp2
		
	end	
	
	// Test
// 	local varlist Monetary1 Education1 Health1 Housing5 Security1
// 	local povmod 2
//	
// 	MDPDecomp 	, varlist(`varlist') povmod(`povmod')	
// 	MDP 		, varlist(`varlist') povmod(`povmod')	
// 	MDPDecomp2 	, mdpstatus(MDPStatus) mdpdecomp(MDPDecomp) varlist(`varlist') 	
	
   
   **** POVERTY ADJUSTED LIFE EXPECTANCY: Program definition
  *----------------------------------------------------------------------*  
    global LE_nat = 49
  
	cap prog drop PALE
 	prog define PALE, rclass
					
		syntax ,MDPStatus(varname numeric) ///
				LEVEL(name) ///
				[THETA(real 1.0) ///
				EPALE]
				
		*| Arguments validity checking

		* LEVEL should be on of nat(national), sta(state), zon(zone)
		if !inlist("`level'", "nat", "sta", "zon") {
			display as error "LEVEL is incorrect, type nat, sta or zon" in red
			exit
		}
		
		*| MDP status computation
		if missing("`epale'") {
			tempvar 	MDP 
			gen 		`MDP' = `mdpstatus'
			replace		`MDP' = 1 if `mdpstatus' == 2
		}
		else {
			tempvar 	MDP 
			gen 		`MDP' = `mdpstatus'
			replace 	`MDP' = 0 if `mdpstatus' == 1
			replace 	`MDP' = 1 if `mdpstatus' == 2
		}		
		
		*| PALE computation
		if "`level'" ==  "nat" {
			* Days out
		    mean daysout [iw = wt_final]
			local daysout_nat = e(b)[1,1]/30
			
			* MDP headcount
			mean `MDP' [iw = wt_final]
			local MDP_HC_nat = e(b)[1,1]
			
			*PALE
			mat PALE = $LE_nat * (1-`daysout_nat') * (1 - `theta' * `MDP_HC_nat')
			matrix rownames PALE = "National"
		}
		
		else if "`level'" ==  "sta" {
		    elabel list (state)
			local n_state	= r(k)
			local state_value `r(values)'
			local state_label `r(labels)'
			
			mat PALE = J(`n_state', 1, .)
			
			forval i = 1/`n_state' {
			    * LEB
				mean LEB_all if state == `:word `i' of `state_value'' // constant
				local LE = e(b)[1,1]
				
				* Days out
				mean daysout [iw = wt_final] if state == `:word `i' of `state_value'' 
				local daysout = e(b)[1,1]/30
				
				* MDP headcount
				mean `MDP' [iw = wt_final] if state == `:word `i' of `state_value'' 
				local MDP_HC = e(b)[1,1]
				
				*PALE
				mat PALE[`i', 1] = `LE' * (1-`daysout') * (1 - `theta' * `MDP_HC')
			}
			matrix rownames PALE = "`state_label'"
			
		}
		else { // "`level'" ==  "zon"
		    elabel list ( zone)
			local 	n_zone	 = r(k)
			local  	zone_value `r(values)'
			local  	zone_label `r(labels)'
			
			mat PALE = J(`n_zone', 1, .)
			
			forval i = 1/`n_zone' {
			    * LEB
				mean LEB_all_zone if  zone == `:word `i' of  `zone_value'' // constant
				local LE = e(b)[1,1]
				
				* Days out
				mean daysout [iw = wt_final] if  zone == `:word `i' of  `zone_value'' 
				local daysout = e(b)[1,1]/30
				
				* MDP headcount
				mean `MDP' [iw = wt_final] if  zone == `:word `i' of  `zone_value'' 
				local MDP_HC = e(b)[1,1]
				
				*PALE
				mat PALE[`i', 1] = `LE' * (1-`daysout') * (1 - `theta' * `MDP_HC')
			}
			matrix rownames PALE = "`zone_label'"
		}
		
		return mat PALE = PALE  
		
   end
     
	 //Test program
// 	PALE, mdps(MDPStatus) level(nat) theta(0.5) // good
// 	PALE, mdps(MDPStatus) level(sta) // good
// 	PALE, mdps(MDPStatus) level(zon) // good
	 
	 
   **** WELL BEING LOSS: Program definition
  *----------------------------------------------------------------------* 
	mat list NGA_LGE_ahat
  
	cap prog drop WBL
	prog def WBL, rclass
		
		syntax ,MDPStatus(varname numeric) ///
				MDPDecomp (varname numeric) ///
				LEVEL(name) ///
				AHAT (integer) ///
				[THETA (real 1)]
// 				[EWBL]
				
		*| Arguments validity checking

		* LEVEL should be on of nat(national), sta(state), zon(zone)
		if !inlist("`level'", "nat", "sta", "zon") {
			display as error "LEVEL is incorrect, type nat, sta or zon" in red
			exit
		}
		
		*| WBL Computation // a revoir en fonction de la valeur de ewbl
		tempvar 	MDP 
		gen 		`MDP' = `mdpstatus'
		replace		`MDP' = 1 if `mdpstatus' == 2
		
		if "$varlist" != "Monetary1" {
			cap drop 	`mdpdecomp'__*
			tab 		`mdpdecomp', gen(`mdpdecomp'__)
			forval i = 1/3 {
				replace `mdpdecomp'__`i' = 0 if `mdpstatus' == 0
			}
		}
		
		if "`level'" == "nat" {
			mat WBL = J(1, 9, .)
			mat colnames WBL =  WBL LGE DAYSOUT_X_LE ONMPHC_X_LE OMPHC_X_LE BHC_X_LE ONMPHC OMPHC BHC 
			
			* Total WBL
			local LGE_ahat = NGA_LGE_ahat[rownumb(NGA_LGE_ahat, "`ahat'"),1]
			
		    mean daysout [iw = wt_final]
			local daysout_nat = e(b)[1,1]/30
			
			mean 		`MDP' [iw = wt_final]
			local 		MDP_HC_nat = e(b)[1,1]
			
			mat WBL[1,1] = (1/`theta')*`LGE_ahat' + `daysout_nat' * $LE_nat + `MDP_HC_nat' * $LE_nat  
			mat WBL[1,2] = (1/`theta')*`LGE_ahat'
			mat WBL[1,3] = `daysout_nat' * $LE_nat 
			
			* Decomposition of WBL
			forval i = 1/3 {
				mean 	`mdpdecomp'__`i' [iw = wt_final]
				mat WBL[1,`i' + 3] = e(b)[1,1] * $LE_nat 
				mat WBL[1,`i' + 6] = e(b)[1,1]
			}
		} 
		else if "`level'" == "sta" {
		    
		    elabel list (state)
			local n_state	= r(k)
			local state_value `r(values)'
			local state_label `r(labels)'
			
			mat WBL = J(`n_state', 9, .)
			mat colnames WBL =  WBL LGE DAYSOUT_X_LE ONMPHC_X_LE OMPHC_X_LE BHC_X_LE ONMPHC OMPHC BHC 
			
			forval i = 1/`n_state' {
			    
				* Total WBL
				mean 	LGE_ahat_`ahat' if state == `:word `i' of `state_value'' // constant
				local 	LGE_ahat = e(b)[1,1]
				
				mean 	LEB_all if state == `:word `i' of `state_value'' // constant
				local 	LE = e(b)[1,1]
				
				mean 	daysout [iw = wt_final] if state == `:word `i' of `state_value''
				local 	daysout = e(b)[1,1]/30
				
				mean 	`MDP' [iw = wt_final] if state == `:word `i' of `state_value''
				local 	 MDP_HC = e(b)[1,1]
				
				mat WBL[`i',1] = (1/`theta')*`LGE_ahat' + `daysout' * `LE' + `MDP_HC' * `LE' 
				mat WBL[`i',2] = (1/`theta')*`LGE_ahat'
				mat WBL[`i',3] =  `daysout' * `LE'
				
				* Decomposition of WBL
				forval j = 1/3 {
					mean 	`mdpdecomp'__`j' [iw = wt_final] if state == `:word `i' of `state_value''
					mat WBL[`i',`j' + 3] = e(b)[1,1] * `LE'
					mat WBL[`i',`j' + 6] = e(b)[1,1]
				}			    
			}
			matrix rownames WBL = "`state_label'"
		}
		else { // "`level'" == "zon"

		    elabel list (zone)
			local n_zone	= r(k)
			local zone_value `r(values)'
			local zone_label `r(labels)'
			
			mat WBL = J(`n_zone', 9, .)
			mat colnames WBL =  WBL LGE DAYSOUT_X_LE ONMPHC_X_LE OMPHC_X_LE BHC_X_LE ONMPHC OMPHC BHC 
			
			forval i = 1/`n_zone' {
			    
				* Total WBL
				mean 	LGE_ahat_`ahat'_zone if zone == `:word `i' of `zone_value'' // constant
				local 	LGE_ahat = e(b)[1,1]
				
				mean 	LEB_all_zone if zone == `:word `i' of `zone_value'' // constant
				local 	LE = e(b)[1,1]
				
				mean 	daysout [iw = wt_final] if zone == `:word `i' of `zone_value''
				local 	daysout = e(b)[1,1]/30
				
				mean 	`MDP' [iw = wt_final] if zone == `:word `i' of `zone_value''
				local 	 MDP_HC = e(b)[1,1]
				
				mat WBL[`i',1] = (1/`theta')*`LGE_ahat' + `daysout' * `LE' + `MDP_HC' * `LE' 
				mat WBL[`i',2] = (1/`theta')*`LGE_ahat'
				mat WBL[`i',3] =  `daysout' * `LE'
				
				* Decomposition of WBL
				forval j = 1/3 {
					mean 	`mdpdecomp'__`j' [iw = wt_final] if zone == `:word `i' of `zone_value''
					mat WBL[`i',`j' + 3] = e(b)[1,1] * `LE'
					mat WBL[`i',`j' + 6] = e(b)[1,1]
				}			    
			}
			matrix rownames WBL = "`zone_label'"
		}
		return mat WBL = WBL  

	end
   
	
	
	// Test program
// 	WBL, mdps(MDPStatus) mdpd(MDPDecomp) level(nat) ahat(50) // good
// 	WBL, mdps(MDPStatus) mdpd(MDPDecomp) level(sta) ahat(50) // good
// 	WBL, mdps(MDPStatus) mdpd(MDPDecomp) level(zon) ahat(50) // good
   
