   * ******************************************************************** *
   *                                                                      *
   *          IMPROVED MULTIDIMENSIONNAL POVERTY MEASUREMENT IN NIGERIA   *
   *                		FINAL DATA ANALYSIS -  CHARTS                 *
   *                                                                      *
   * ******************************************************************** *
   * ******************************************************************** *

       /*
       ** PURPOSE:      COMPUTE FINAL OUTPUTS - CHARTS

       ** OUTLINE:      SECT 1: DEFINITION OF FUNCTIONS
						SECT 2: DEFINITION OF SCENARIOS
                        SECT 3: FINAL ANALYSIS OUTPUT
       */
	   
	global output 	"$projectfolder/Output"
	
// 	include 		"$programs/1_1_DataConstruction_DHS_NLSS.do"
// 	include 		"$programs/1_2_DataConstruction_Thresolds.do"
// 	include 		"$programs/2_1_DataAnalysis_Preliminary.do"
	

   * ******************************************************************** *
   *       SECT 1: DEFINITION OF FUNCTIONS
   * ******************************************************************** *
	
	include  "$programs/2_2_DataAnalysis_Commands.do"

	
   * ******************************************************************** *
   *       SECT 2: DEFINITION OF SCENARIOS
   * ******************************************************************** *
	// In this section we fixed the parameters that may change according to the chosen scenario

	graph set window fontface "Arial Narrow"
	
// 	global sc "p4" // To be filled accordingly: st, er, m1, m2, bl, p1, p2, p3, p4
	
	
	* Scenario listing
	*----------------------------------------------------------------------*  
	*| Standard
	if "$sc" == "st" {
		global 	varlist Monetary1 Education1 Health1 Housing5 Security1 
		local 	theta 	1
		local 	povmod  2
		local 	ahat 	50
		
		cap cd	"$output/Scenarii/Standard"
		if _rc {
			mkdir 		"$output/Scenarii/Standard"
			mkdir 		"$output/Scenarii/Standard/Data"		
			mkdir 		"$output/Scenarii/Standard/Graphics"
		}

		global output 	"$output/Scenarii/Standard"
	}
	
	*| Education Removed
	if "$sc" == "er" {
		global 	varlist Monetary1 Education1 Health1 Housing5 Security1 
		local 	theta 	1
		local 	povmod  2
		local 	ahat 	50
		
		cap cd	"$output/Scenarii/Education_Removed"
		if _rc {
			mkdir 		"$output/Scenarii/Education_Removed"
			mkdir 		"$output/Scenarii/Education_Removed/Data"		
			mkdir 		"$output/Scenarii/Education_Removed/Graphics"
		}
		
		global output 	"$output/Scenarii/Education_Removed"
	}

	*| Monetary-Mortality 1
	if "$sc" == "m1" {
		global 	varlist Monetary1
		local 	theta 	1
		local 	povmod  2
		local 	ahat 	50

		replace  daysout = 0
		
		cap drop MDPStatus
		gen 	 MDPStatus = Monetary1Ext
		
		cap drop MDPDecomp*
		gen 	 MDPDecomp = . 
		forval i = 1/3 {
			gen MDPDecomp__`i' = 0 
			if `i' == 2 replace MDPDecomp__`i' = 1 if MDPStatus == 1
		}	
		
		local leg_daysoutR1 	order(5 "Only monetary poor" 1 "Premature mortality")
		local leg_daysoutR6 	order(2 "PALE" 1 "LE")
		local leg_daysoutR6b 	order(2 "PALE" 1 "LE")
		local col_daysoutR6		cranberry%0
		
		cap cd	"$output/Scenarii/MonetaryMortality1"
		if _rc {
			mkdir 		"$output/Scenarii/MonetaryMortality1"
			mkdir 		"$output/Scenarii/MonetaryMortality1/Data"		
			mkdir 		"$output/Scenarii/MonetaryMortality1/Graphics"
		}
		
		global output 	"$output/Scenarii/MonetaryMortality1"
	}
	
	*| Monetary-Mortality 2
	if "$sc" == "m2" {
		global 	varlist Monetary1
		local 	theta 	0.5
		local 	povmod  2
		local 	ahat 	50

		replace daysout = 0
		
		cap drop MDPStatus
		gen 	 MDPStatus = Monetary1Ext
		
		cap drop MDPDecomp*
		gen 	 MDPDecomp = . 
		forval i = 1/3 {
			gen MDPDecomp__`i' = 0 
			if `i' == 2 replace MDPDecomp__`i' = 1 if MDPStatus == 1
		}	
		
		local leg_daysoutR1 	order(5 "Only monetary poor" 1 "Premature mortality")
		local leg_daysoutR6 	order(2 "PALE" 1 "LE")
		local leg_daysoutR6b 	order(2 "PALE" 1 "LE")
		local col_daysoutR6		cranberry%0
		
		cap cd	"$output/Scenarii/MonetaryMortality2"
		if _rc {
			mkdir 		"$output/Scenarii/MonetaryMortality2"
			mkdir 		"$output/Scenarii/MonetaryMortality2/Data"		
			mkdir 		"$output/Scenarii/MonetaryMortality2/Graphics"
		}
		
		global output 	"$output/Scenarii/MonetaryMortality2"
	}	
	
	
	*| Baseline
	if "$sc" == "bl" {
		global 	varlist Monetary1 Health2 Housing5 Security2
		local 	theta 	1
		local 	povmod  2
		local 	ahat 	50
		
	    replace daysout = 0
		
		local leg_daysoutR1 	order(5 "Only monetary poor"  4 "Consistently poor" 3 "Omitted poor" 1 "Premature mortality")
		local leg_daysoutR4 	order(1 "Life expanctancy" 3 "Others dimensions deprivation" 4 "Monetary Poverty" 5 "Overlap")
		local leg_daysoutR4b 	order(5 "Coefficient overlap" 4 "Monetary poverty" 3 "Other-dimensions poverty" 1 "LE")
		local leg_daysoutR6 	order(5 "PALE" 4 "OPALE" 3 "MPALE" 1 "LE")
		local leg_daysoutR6b 	order(3 "PALE" 1 "LE")
		local col_daysoutR6		cranberry%0
		
		cap cd	"$output/Scenarii/Baseline"
		if _rc {
			mkdir 		"$output/Scenarii/Baseline"
			mkdir 		"$output/Scenarii/Baseline/Data"		
			mkdir 		"$output/Scenarii/Baseline/Graphics"
		}
				
	    global output 	"$output/Scenarii/Baseline"
	}

	*| Prefered 1
	if "$sc" == "p1" {
		global 	varlist Monetary2 Education1 Health2 Housing5 Security2
		local 	theta 	1
		local 	povmod  2
		local 	ahat 	50
		
		cap cd	"$output/Scenarii/Prefered1"
		if _rc {
			mkdir 		"$output/Scenarii/Prefered1"
			mkdir 		"$output/Scenarii/Prefered1/Data"		
			mkdir 		"$output/Scenarii/Prefered1/Graphics"
		}
				
		global output 	"$output/Scenarii/Prefered1"
	}

	*| Prefered 2
	if "$sc" == "p2" {
		global 	varlist Monetary2 Education2 Health2 Housing5 Security2
		local 	theta 	1
		local 	povmod  2
		local 	ahat 	50
		
		cap cd	"$output/Scenarii/Prefered2"
		if _rc {
			mkdir 		"$output/Scenarii/Prefered2"
			mkdir 		"$output/Scenarii/Prefered2/Data"		
			mkdir 		"$output/Scenarii/Prefered2/Graphics"
		}
		
		global output 	"$output/Scenarii/Prefered2"
	}
	
	*| Prefered 3
	if "$sc" == "p3" {
		global 	varlist Monetary2 Education3 Health2 Housing5 Security2
		local 	theta 	1
		local 	povmod  2
		local 	ahat 	50
		
		cap cd	"$output/Scenarii/Prefered3"
		if _rc {
			mkdir 		"$output/Scenarii/Prefered3"
			mkdir 		"$output/Scenarii/Prefered3/Data"		
			mkdir 		"$output/Scenarii/Prefered3/Graphics"
		}
		
		
		global output	"$output/Scenarii/Prefered3"
	}

	*| Prefered 4
	if "$sc" == "p4" {
		global 	varlist Monetary2 Education3 Health2 Housing5 Security2
		local 	theta 	0.5
		local 	povmod  2
		local 	ahat 	65
		
	    replace daysout = 0
		
		local leg_daysoutR1 	order(5 "Only monetary poor"  4 "Consistently poor" 3 "Omitted poor" 1 "Premature mortality")
		local leg_daysoutR4 	order(1 "Life expanctancy" 3 "Others dimensions deprivation" 4 "Monetary Poverty" 5 "Overlap")
		local leg_daysoutR4b 	order(5 "Coefficient overlap" 4 "Monetary poverty" 3 "Other-dimensions poverty" 1 "LE")
		local leg_daysoutR6 	order(5 "PALE" 4 "OPALE" 3 "MPALE" 1 "LE")
		local leg_daysoutR6b 	order(3 "PALE" 1 "LE")
		local col_daysoutR6		cranberry%0
		
		cap cd	"$output/Scenarii/Prefered4"
		if _rc {
			mkdir 		"$output/Scenarii/Prefered4"
			mkdir 		"$output/Scenarii/Prefered4/Data"		
			mkdir 		"$output/Scenarii/Prefered4/Graphics"
		}
		
				
		global output 	"$output/Scenarii/Prefered4"
	}

	
	save "$projectfolder/Output/Data/main.dta", replace
	
	
   * ******************************************************************** *
   *       SECT 3: FINAL ANALYSIS OUTPUT
   * ******************************************************************** *
	
   **** 0)	 Deprived people per dimensions chosen
  *----------------------------------------------------------------------*  
   
  if "$varlist" != "Monetary1" {
  
		lab def poor 1 "Extreme poors" 2 "Moderate poors" 3 "Non-poors", modify
	 
		foreach dim of global varlist {
			gen 	Pov_`dim' = 1 if `= "`dim'" + "Ext"' == 1
			cap replace Pov_`dim' = 2 if `= "`dim'" + "Mod"' == 1
			cap replace Pov_`dim' = 3 if `= "`dim'" + "Ext"' == 0 & `= "`dim'" + "Mod"' == 0
			lab val Pov_`dim' poor
		}
		
		keep hhid indiv Pov*
		reshape long Pov_, i(hhid indiv) j(Dimension) string
		replace Dimension = substr(Dimension, 1, length(Dimension)-1)
		tab Pov_, gen(Pov__)
		merge m:1  hhid indiv using "$projectfolder/Output/Data/ind_all_thresholds.dta", keepusing(wt_final state zone) // adding sample weights

	   // Graph
		graph hbar Pov__* [pw = wt_final] ///
			, ///
			stack over(Dimension) nofill ///
			legend(order(1 "Extremely deprived" ///
						 2 "Moderately deprived" ///
						 3 "Not deprived") ///
				   c(1) pos(3) ///
				   symxsize(small) symysize(small) size(small)) /// 
			blabel(bar, format(%9.2f) pos(center)) ///
			bar(3, color(ebblue)) ///
			bar(2,color(dkorange)) ///
			bar(1, color(dkgreen)) ///
			title("Deprivation headcount per dimension", color(black)) ///
			graphregion(color(white)) bgcolor(white) 
		
		graph export "$output/Graphics/R0_DimensionsChosen.png", as(png) name("Graph")	replace   
   }
  
  
   **** 0.a) Deprived people per dimensions chosen: Spatial(state) representation
  *----------------------------------------------------------------------*  
	 
	if "$varlist" != "Monetary1" {

	  *| Deprivation share per dimensions
		use "$projectfolder/Output/Data/main.dta", clear    

	   * Recoding state to match shape file order
		forval i = 1/23 {
			local 	x = 38 - `i'
			replace state = `x'+1 if state == `x'
		}
		replace state = 15 if state == 38
		lab val state
		
	  
	   * Deprivation by dimension by state
		lab def poor 1 "Poor" 0 "Non poor", replace
	 
		foreach dim of global varlist {
			gen 		Pov_`dim' = 100 if `= "`dim'" + "Ext"' == 1
			cap replace Pov_`dim' = 100 if `= "`dim'" + "Mod"' == 1
			cap replace Pov_`dim' = 0 if `= "`dim'" + "Ext"' == 0 & `= "`dim'" + "Mod"' == 0
			lab val 	Pov_`dim' poor
		}
		replace `= "`:word 1 of $varlist'" + "Ext"' = 100 if `= "`:word 1 of $varlist'" + "Ext"' == 1
		
		tempfile tmp
		save `tmp'
		
		collapse (mean) Pov_* [iw = wt_final], by(state)
		format Pov_* %9.1f
		ren state _ID
		merge 1:1 _ID using "$projectfolder/Output/Data/LEB_ByState.dta", keepusing(LEB_all)
		merge 1:1 _ID using "$data/nga_adm_osgof_20190417/NGAAdm1", nogen
		
		tempfile tmp1
		save `tmp1'
		
		
	   * Deprivation by dimension by zone
	   
		use "$projectfolder/Output/Data/LGE_ByState.dta", clear 
		merge 1:1 _ID using "$data/nga_adm_osgof_20190417/NGAAdm1", nogen
		
		gen 	zone_string = "North Central" 	if zone == 1
		replace zone_string = "North East" 		if zone == 2
		replace zone_string = "North West" 		if zone == 3
		replace zone_string = "South East" 		if zone == 4
		replace zone_string = "South South" 	if zone == 5
		replace zone_string = "South West" 		if zone == 6
			
		collapse (mean) _CX _CY, by(zone zone_string)
		
		gen  labtyp = 2
		save "$data/nga_adm_osgof_20190417/spmaplabels_zone.dta", replace
		
		ren 	zone_string state
		append 	using "$data/nga_adm_osgof_20190417/spmaplabels.dta"
		save 		 "$data/nga_adm_osgof_20190417/spmaplabels_statezone.dta", replace
	   
	   
		use `tmp', clear
		
		collapse (mean) Pov_* `= "`:word 1 of $varlist'" + "Ext"' [iw = wt_final], by(zone)
		format Pov_* `= "`:word 1 of $varlist'" + "Ext"'  %9.1f
		merge 1:m zone using "$projectfolder/Output/Data/LGE_ByState.dta", keepusing(_ID LEB_all)
		merge 1:1 _ID using "$data/nga_adm_osgof_20190417/NGAAdm1", nogen		
		
		tempfile tmp2
		save `tmp2'
	  
	  
	  *| Designing Graph
	  
		// By state
		use `tmp1', clear
		
		colorpalette hcl, viridis n(10) nograph reverse 
		local colors `r(p)'	
		local k = 0
		
		foreach dim of global varlist {
			local k = `k' + 1
			
			qui spmap Pov_`dim' using "$data/nga_adm_osgof_20190417/NGAAdm1_shp", ///
				id(_ID) cln(5)  fcolor("`colors'") ///
				ocolor(gs10 ..) osize(0.04 ..) ///
				polygon(data("$data/nga_adm_osgof_20190417/NGAAdm0_shp") ocolor(black) osize(0.1)) ///		
				label(data("$data/nga_adm_osgof_20190417/spmaplabels") x(_CX) y(_CY) lab(state) size(vsmall) pos(12 0)) ///
				legend(pos(5) size(1.5) symx(2.5) symy(1.5) ) legtitle("Deprivation rate (%)") legstyle(2) ///
				subtitle("{fontface Arial Bold: `=substr("`dim'",1,length("`dim'")-1)'}", size(small)) ///
				name(g`k', replace) 
			
			local need g`k'
			local gname: list gname | need
		}
	 
		colorpalette hcl, viridis n(10) nograph reverse 
		local colors `r(p)'
			
		qui spmap LEB_all using "$data/nga_adm_osgof_20190417/NGAAdm1_shp", ///
			id(_ID) cln(5)  fcolor("`colors'") ///
			ocolor(gs10 ..) osize(0.04 ..) ///
			polygon(data("$data/nga_adm_osgof_20190417/NGAAdm0_shp") ocolor(black) osize(0.1)) ///		
			label(data("$data/nga_adm_osgof_20190417/spmaplabels") x(_CX) y(_CY) lab(state) size(vsmall) pos(12 0)) ///
			legend(pos(5) size(1.5) symx(2.5) symy(1.5) ) legtitle("LEB") legstyle(2) ///
			subtitle("{fontface Arial Bold: Life expanctancy at birth}", size(small)) ///
			name(g6, replace) 
		
		graph combine `gname' g6, col(2) xsize(8) ysize(5) iscale(*1) ///
		graphregion(color(white)) ///
		title("{fontface Arial Bold : State deprivation rates per dimension (%)}", size(medsmall))
		graph export "$output/Graphics/R0_DimensionsDeprivationState.png", as(png) height(1000) name("Graph") replace
		
		// By zone
		use `tmp2', clear
		
		colorpalette hcl, viridis n(10) nograph reverse 
		local colors `r(p)'	

		qui spmap `= "`:word 1 of $varlist'" + "Ext"' using "$data/nga_adm_osgof_20190417/NGAAdm1_shp", ///
			id(_ID) cln(5)  fcolor("`colors'") ///
			ocolor(gs10 ..) osize(0.04 ..) ///
			polygon(data("$data/nga_adm_osgof_20190417/NGAAdm0_shp") ocolor(black) osize(0.1)) 	///	
			label(data("$data/nga_adm_osgof_20190417/spmaplabels_statezone") x(_CX) y(_CY) by(labtyp) lab(state) size(tiny) pos(12 0)) ///
			legend(pos(5) size(1.5) symx(2.5) symy(1.5) ) legtitle("Poverty headcount (%)") legstyle(2) ///
			title("{fontface Arial Bold:Extreme Monetary Poverty Headcount}", size(medium))
		graph export "$output/Graphics/MonetaryPovertyZone.png", as(png) height(1000) name("Graph") replace
 
	}

	
   **** 0.b) Deprived people per dimensions chosen: Spatial(zone) variability
  *----------------------------------------------------------------------*  
	 
	if "$varlist" != "Monetary1" {
		
	  *| Deprivation share per dimensions
	  	use "$projectfolder/Output/Data/main.dta", clear    
	
		local liste
		
		foreach dim of global varlist {
			cap replace `dim'Ext = 100 * `dim'Ext
			cap replace `dim'Mod = 100 * `dim'Mod
			local need  `dim'Ext `dim'Mod
			local liste: list liste | need
		}
		collapse (mean) `liste' [iw = wt_final], by(zone)
		egen Pov_Monetary = rowtotal(Monetary*)
		format *Ext *Mod  %9.0f
	
		
	  *| Designing Graph
		local k = 0
		local gname
		
		foreach dim of global varlist {
			local k = `k' + 1
			if `k' < `:word count $varlist' 	local legend "off"
			else 								local legend "on"
			
			graph bar (asis) `dim'Ext `dim'Mod  ///
				, ///
				stack over(zone, sort(Pov_Monetary) lab(labsize(vsmall) angle(vertical))) ///
				bargap(15) ///
				nofill ///
				blabel(bar, format(%9.0f) size(tiny) pos(center)) ///
				bar(1 , color(dkgreen)) ///
				bar(2 , color(dkorange)) ///
				ylabel(0(20)100, labsize(vsmall)) ///
				legend(`legend' order(1 "Extremely deprived" ///
									  2 "Moderately deprived") ///
					   c(1) pos(6) rows(1) symxsize(small) symysize(small) size(small)) ///
				ytitle("Deprivation (%)") ///
				subtitle("{fontface Arial Bold: `=substr("`dim'",1,length("`dim'")-1)'}", size(small) ///				   
					placement(bottom) ///
					justification(center)) ///
				name(g`k', replace) 
			
			local need g`k'
			local gname: list gname | need
		}		   
					   
		graph combine `gname' , col(2) xsize(8) ysize(8) iscale(*1) ///
		graphregion(color(white)) ///
		title("{fontface Arial Bold : Zone deprivation rates per dimension (%)}", size(medsmall))
		graph export "$output/Graphics/R0_DimensionsDeprivationZone.png", as(png) height(1000) name("Graph") replace
	}
   
   
   **** 1)	Share of well-being loss coming from each source   
  *----------------------------------------------------------------------*  

   *| Preparing data
	use "$projectfolder/Output/Data/main.dta", clear
	
	gen national = 1
	lab def national 1 "National"
	lab val national national 

	save "$projectfolder/Output/Data/main.dta", replace
	
	local i = 0
	foreach lev in national state zone {
    preserve
	    local level = substr("`lev'",1,3)
		local i = `i' + 1
		
		tempfile label
		elabel save (`lev') using `label'.do, replace
		elabel list (`lev')
		local label_name `r(name)' 
		
		* Monetary HC
		local name :word 1 of $varlist
		
// 		tempvar MonetaryPoor
// 		gen 	`MonetaryPoor' = (`= "`name'" + "Ext"' == 1 | `= "`name'" + "Mod"' == 1) ///
// 									if !missing(`= "`name'" + "Ext"') | !missing(`= "`name'" + "Mod"')
//									
// 		tabstat `MonetaryPoor' [aw = wt_final], stat(mean) by(`lev') save 

		tabstat `= "`name'" + "Ext"' [aw = wt_final], stat(mean) by(`lev') save 
		tabstatmat monetaryHC 
		mat monetaryHC = monetaryHC[1..`=rowsof(monetaryHC)-1',1]
		mat colnames monetaryHC = monetaryHC 
		
		* WBL
		if "$varlist" != "Monetary1" {
			MDPDecomp 	, varlist($varlist) povmod(`povmod')	
			MDP 		, varlist($varlist) povmod(`povmod')
		}
		WBL			, mdps(MDPStatus) mdpd(MDPDecomp) level(`level') ahat(`ahat') theta(`theta')

		mat WBL 			= r(WBL)
		mat monetaryHC_WBL 	= monetaryHC, WBL
		
		clear
		svmat monetaryHC_WBL, names(col)
		
		gen level = `i'
		
		gen level_namee = _n
		do `label'.do
		lab val level_namee `label_name'
		decode level_namee, gen(level_name)
		drop level_namee
		
		if `i' == 1 save "$output/Data/LevelsIndicators", replace
		else {
		    append using "$output/Data/LevelsIndicators"
			save "$output/Data/LevelsIndicators", replace
		}
		
	restore
	}
	
	use "$output/Data/LevelsIndicators", clear
	foreach var of varlist LGE DAYSOUT_X_LE ONMPHC_X_LE OMPHC_X_LE BHC_X_LE {
	    gen `var'_pc = 100*`var'/WBL
	}
	
	
   *| Designing Graph = 
   * ONMPHC_X_LE = OOPHC_X_LE //Non Monetary = Others dimensions
   
   gen MPHC_X_LE 	= BHC_X_LE + OMPHC_X_LE
   gen NMPHC_X_LE	= BHC_X_LE + ONMPHC_X_LE
   
   tabstat 		LGE MPHC_X_LE NMPHC_X_LE if level == 2, stat(cv) save
   tabstatmat 	cv
   
	graph bar LGE DAYSOUT_X_LE ONMPHC_X_LE BHC_X_LE OMPHC_X_LE ///
		if inlist(level, 1,3 ) ///
		, ///
		stack over(level_name, sort(monetaryHC) lab(labsize(medsmall) angle(vertical))) ///
		nofill ///
		legend(`leg_daysoutR1' ///
			   c(1) pos(3) ///
			   symxsize(medsmall) symysize(medsmall) size(vsmall)) ///
		blabel(bar, format(%9.0f) pos(center) size(vsmall)) ///
		bar(5, color(white) lc(black) lp(solid) lw(thin)) ///
		bar(4, color(cranberry)) ///
		bar(3, color(ebblue)) ///
		bar(2,color(dkorange)) ///
		bar(1, color(dkgreen)) ///
		title("Decomposition of well-being loss from different sources") ///
        graphregion(color(white)) bgcolor(white) ///
		note("Variances across states: (% of mean)" ///
			"Mortality losses `=round(100*cv[1,1],0.1)'" ///
			"Monetary losses `=round(100*cv[1,2],0.1)'" ///
			"Others dimensions losses `=round(100*cv[1,3],0.1)'" )
	graph export "$output/Graphics/R1_zone.png", as(png) height(800) name("Graph")	replace	
	
	
	graph bar LGE_pc DAYSOUT_X_LE_pc ONMPHC_X_LE_pc BHC_X_LE_pc OMPHC_X_LE_pc ///
		if inlist(level, 1,3 ) ///
		, ///
		stack over(level_name, sort(monetaryHC) lab(labsize(medsmall) angle(vertical))) ///
		nofill ///
		legend(`leg_daysoutR1' ///
			   c(1) pos(3) ///
			   symxsize(medsmall) symysize(medsmall) size(vsmall)) ///
		blabel(bar, format(%9.0f) pos(center) size(vsmall)) ///
		bar(5, color(white) lc(black) lp(solid) lw(thin)) ///
		bar(4, color(cranberry)) ///
		bar(3, color(ebblue)) ///
		bar(2,color(dkorange)) ///
		bar(1, color(dkgreen)) ///
		title("Decomposition of well-being loss from different sources") ///
        graphregion(color(white)) bgcolor(white) 
	graph export "$output/Graphics/R1_zone_pc.png", as(png) height(800) name("Graph")	replace	

	
	graph bar LGE DAYSOUT_X_LE ONMPHC_X_LE BHC_X_LE OMPHC_X_LE ///
		if inlist(level, 1,2 ) ///
		, ///
		stack over(level_name, sort(monetaryHC) lab(labsize(vsmall) angle(vertical))) ///
		nofill ///
		legend(`leg_daysoutR1' ///
			   c(1) pos(4) ///
			   symxsize(medsmall) symysize(medsmall) size(vsmall)) ///
		bar(5, color(white) lc(black) lp(solid) lw(thin)) ///
		bar(4, color(cranberry)) ///
		bar(3, color(ebblue)) ///
		bar(2,color(dkorange)) ///
		bar(1, color(dkgreen)) ///
		title("Decomposition of well-being loss from different sources") ///
        graphregion(color(white)) bgcolor(white) ///
		note("Variances across states: (% of mean)" ///
			"Mortality losses `=round(100*cv[1,1],0.1)'" ///
			"Monetary losses `=round(100*cv[1,2],0.1)'" ///
			"Others dimensions losses `=round(100*cv[1,3],0.1)'" )
	graph export "$output/Graphics/R1_state.png", as(png) height(800) name("Graph")	replace	
 
 
	graph bar  LGE_pc DAYSOUT_X_LE_pc ONMPHC_X_LE_pc BHC_X_LE_pc OMPHC_X_LE_pc ///
		if inlist(level, 1,2 ) ///
		, ///
		stack over(level_name, sort(monetaryHC) lab(labsize(vsmall) angle(vertical))) ///
		nofill ///
		legend(`leg_daysoutR1' ///
			   c(1) pos(4) ///
			   symxsize(medsmall) symysize(medsmall) size(vsmall)) ///
		bar(5, color(white) lc(black) lp(solid) lw(thin)) ///
		bar(4, color(cranberry)) ///
		bar(3, color(ebblue)) ///
		bar(2,color(dkorange)) ///
		bar(1, color(dkgreen)) ///
		title("Decomposition of well-being loss from different sources") ///
        graphregion(color(white)) bgcolor(white) 
	graph export "$output/Graphics/R1_state_pc.png", as(png) height(800) name("Graph")	replace	
 

  
 
   **** 2.a) Correlation between monetary and non-monetary
  *----------------------------------------------------------------------*  
   *| Preparing data
   use "$projectfolder/Output/Data/main.dta", clear
   
// 	local varlist Monetary Education Health1 Housing5 Security
// 	local povmod 2
   
	tempfile monetaryHC_PALE
 
	local i = 0
	foreach lev in national state zone {
    preserve
	    local level = substr("`lev'",1,3)
		local i = `i' + 1
		
		tempfile label
		elabel save (`lev') using `label'.do, replace
		elabel list (`lev')
		local label_name `r(name)' 
		
		* Average consumption expenditure (annual pc)
		tabstat totcons_adj [aw = wt_final], stat(mean) by(`lev') save 
		tabstatmat AverageConso
		mat AverageConso = AverageConso[1..`=rowsof(AverageConso)-1',1]
		
		* PALE
		if "$varlist" != "Monetary1"  MDP  , varlist($varlist) povmod(`povmod')
		PALE , mdps(MDPStatus) level(`level') theta(`theta')
		mat monetaryHC_PALE = AverageConso, r(PALE)
		
		if "$varlist" != "Monetary1" {
			* Non Monetary PALE 
			MDP  , varlist($varlist) povmod(`povmod')	nomon
			PALE , mdps(MDPStatus) level(`level') theta(`theta')
			mat monetaryHC_PALE = monetaryHC_PALE, r(PALE)
			
			* Additional info PALE
			MDPDecomp 	, varlist($varlist) povmod(`povmod')	
			MDP  		, varlist($varlist) povmod(`povmod')
			recode 	MDPDecomp ( 2 3 = 0 ), gen(ONMP)
			replace ONMP = 0 if MDPStatus == 0
			
			PALE , mdps(ONMP) level(`level') theta(`theta')
			mat monetaryHC_PALE = monetaryHC_PALE, r(PALE)
		
			mat colnames monetaryHC_PALE = AverageConso_anpc PALE NMPALE AIPALE
		}
		else mat colnames monetaryHC_PALE = AverageConso_anpc PALE
		
		clear
		svmat monetaryHC_PALE, names(col)
		
		gen level = `i'
		
		gen level_namee = _n
		do `label'.do
		lab val level_namee `label_name'
		decode level_namee, gen(level_name)
		drop level_namee
		
		if `i' == 1 save `monetaryHC_PALE', replace
		else {
		    append using `monetaryHC_PALE'
			save `monetaryHC_PALE', replace
		}
		
	restore
	}

	use `monetaryHC_PALE', clear
	merge 1:1 level_name using "$output/Data/LevelsIndicators", nogen 
	save "$output/Data/LevelsIndicators", replace

	
   *| Designing Graph 2 
	use "$output/Data/LevelsIndicators", clear
	
	gen 	split = 1 if monetaryHC < 0.5
	replace split = 2 if monetaryHC >= 0.5
	
	local cond "1,2 1 2"
	local m = 0
	
	foreach c of local cond {
		local m = `m' + 1

		* Monetary HC vs PALE
		correlate PALE monetaryHC if inlist(split, `c')
		local r = round(100* r(C)[1,2], 1) // < 0 
		
			// Number of reverse pairwise states
			{
			levelsof level_name if level == 2 & inlist(split, `c'), local(states)
			local nb_states :word count `states'

			local count  = 0
			forval i = 1/`=`nb_states'-1' {
				forval n = 1/`= c(N)' {
					if level_name[`n'] == "`:word `i' of `states''" {
						local k = `n'
						continue, break
					}
				}
				
				forval j = `=`i'+1'/`nb_states' {
					forval n = 1/`= c(N)' {
						if level_name[`n'] == "`:word `j' of `states''" {
							local l = `n'
							continue, break
						}
					}
					
					if (PALE[`k'] > PALE[`l'] & monetaryHC[`k'] > monetaryHC[`l'] )  | (PALE[`k'] < PALE[`l'] & monetaryHC[`k'] < monetaryHC[`l'] )  {
						local count = `count' + 1
					}
				}
			}

			local count = round(100 * `count' / (0.5 * `nb_states' * (`nb_states' -1)), 1)
			di `count'	
			}
		
			// Average difference in indicator's ratio to median
			{
			_pctile monetaryHC if  level == 2 & inlist(split, `c'), nq(2)
			local H_med = r(r1)
			
			_pctile PALE if  level == 2 & inlist(split, `c'), nq(2)
			local PALE_med = r(r1)
				
			levelsof level_name if level == 2 & inlist(split, `c') , local(states)
			local nb_states :word count `states'

			local index  = 0
			forval i = 1/`=`nb_states'-1' {
				forval n = 1/`= c(N)' {
					if level_name[`n'] == "`:word `i' of `states''" {
						local k = `n'
						continue, break
					}
				}
				
				local index = `index' + abs([(1 - monetaryHC[`k']) / (1 - `H_med')] - [PALE[`k'] / `PALE_med'])
			}

			local index = `index' / `nb_states'
			local index : display %4.2f `index'
			di `index'	
			}
		
		
		twoway ///
			(lfitci  PALE monetaryHC) ///
			(scatter PALE monetaryHC if level == 1, mcolor(ebblue) m(T) )  ///
			(scatter PALE monetaryHC if level == 2, mcolor(cranberry) m(O) )  ///
			(scatter PALE monetaryHC if level == 3, mcolor(dkgreen) m(D) ) ///
			if inlist(split, `c') ///
		  ,  ///
			xtitle("Monetary poverty headcount", axis(1)) ///
			xlabel(`=0 + 0.5*(`m'==3)' (0.1) `=1 - 0.5*(`m'==2)')          ///
			ylabel(0(10)50) ///
			ytitle("PALE" ) ///
			legend(order(3 4 5 ) label(3 "National") label(4 "States") label(5 "Zones")  ///
			ring(0) position(1)) ///
			text(0 `=0.1 + (`m'== 3)*0.5' "Correlation = `r'%", place(ne) size(.25cm)) ///
			text(10 `=0.1 + (`m'== 3)*0.5' "Reverse state pairwises = `count'%", place(ne) size(.25cm)) ///
			text(50 `=0.1 + (`m'== 3)*0.5' "Average diff. in ratio to median = `index'", place(ne) size(.25cm)) ///
			graphregion(color(white)) bgcolor(white) ///
			name(g1, replace) 
		 
		if "$varlist" != "Monetary1" {
		* Monetary HC vs NMPALE
		correlate NMPALE monetaryHC if inlist(split, `c') 
		local r = round(100* r(C)[1,2], 1)
		
			// Number of reverse pairwise states
			{
			levelsof level_name if level == 2 & inlist(split, `c') , local(states)
			local nb_states :word count `states'

			local count  = 0
			forval i = 1/`=`nb_states'-1' {
				forval n = 1/`= c(N)' {
					if level_name[`n'] == "`:word `i' of `states''" {
						local k = `n'
						continue, break
					}
				}
				
				forval j = `=`i'+1'/`nb_states' {
					forval n = 1/`= c(N)' {
						if level_name[`n'] == "`:word `j' of `states''" {
							local l = `n'
							continue, break
						}
					}
					
					if (NMPALE[`k'] > NMPALE[`l'] & monetaryHC[`k'] > monetaryHC[`l']) | (NMPALE[`k'] < NMPALE[`l'] & monetaryHC[`k'] < monetaryHC[`l'])  {
						local count = `count' + 1
					}
				}
			}

			local count = round(100 * `count' / (0.5 * `nb_states' * (`nb_states' -1)), 1)
			di `count'	
			}
		
			// Average difference in indicator's ratio to median
			{
			_pctile monetaryHC if  level == 2 & inlist(split, `c'), nq(2)
			local H_med = r(r1)
			
			_pctile NMPALE if  level == 2 & inlist(split, `c'), nq(2)
			local NMPALE_med = r(r1)
				
			levelsof level_name if level == 2 & inlist(split, `c') , local(states)
			local nb_states :word count `states'

			local index  = 0
			forval i = 1/`=`nb_states'-1' {
				forval n = 1/`= c(N)' {
					if level_name[`n'] == "`:word `i' of `states''" {
						local k = `n'
						continue, break
					}
				}
				
				local index = `index' + abs([(1 - monetaryHC[`k']) / (1 - `H_med')] - [NMPALE[`k'] / `NMPALE_med'])
			}

			local index = `index' / `nb_states'
			local index : display %4.2f `index'
			di `index'	
			}
		
		
		twoway ///
			(lfitci  NMPALE monetaryHC) ///
			(scatter NMPALE monetaryHC if level == 1, mcolor(ebblue) m(T) )  ///
			(scatter NMPALE monetaryHC if level == 2, mcolor(cranberry) m(O) )  ///
			(scatter NMPALE monetaryHC if level == 3, mcolor(dkgreen) m(D) ) ///
			if inlist(split, `c') ///
		  ,  ///
			xtitle("Monetary poverty headcount", axis(1)) ///
			xlabel(`=0 + 0.5*(`m'==3)' (0.1) `=1 - 0.5*(`m'==2)')         ///
			ylabel(0(10)50) ///
			ytitle("Others dimensions PALE" ) ///
			legend(order(3 4 5 ) label(3 "National") label(4 "States") label(5 "Zones")  ///
			ring(0) position(1)) ///
			text(0 `=0.1 + (`m'== 3)*0.5' "Correlation = `r'%", place(ne) size(.25cm)) ///
			text(10 `=0.1 + (`m'== 3)*0.5' "Reverse state pairwises = `count'%", place(ne) size(.25cm)) ///
			text(50 `=0.1 + (`m'== 3)*0.5' "Average diff. in ratio to median = `index'", place(ne) size(.25cm)) ///
			graphregion(color(white)) bgcolor(white) ///
			name(g2, replace) 
		 }
		 
		 
		* Monetary HC vs mean consumption  agregate
		sum AverageConso_anpc if inlist(split, `c') 
		local min = r(min)
		correlate AverageConso_anpc monetaryHC if inlist(split, `c') 
		local r = round(100* r(C)[1,2], 1)
		
			// Number of reverse pairwise states
			{
			levelsof level_name if level == 2 & inlist(split, `c') , local(states)
			local nb_states :word count `states'

			local count  = 0
			forval i = 1/`=`nb_states'-1' {
				forval n = 1/`= c(N)' {
					if level_name[`n'] == "`:word `i' of `states''" {
						local k = `n'
						continue, break
					}
				}
				
				forval j = `=`i'+1'/`nb_states' {
					forval n = 1/`= c(N)' {
						if level_name[`n'] == "`:word `j' of `states''" {
							local l = `n'
							continue, break
						}
					}
					
					if (AverageConso_anpc[`k'] > AverageConso_anpc[`l'] & monetaryHC[`k'] > monetaryHC[`l']) | ///
					   (AverageConso_anpc[`k'] < AverageConso_anpc[`l'] & monetaryHC[`k'] < monetaryHC[`l'])  {
						local count = `count' + 1
					}
				}
			}

			local count = round(100 * `count' / (0.5 * `nb_states' * (`nb_states' -1)), 1)
			di `count'	
			}
		
			// Average difference in indicator's ratio to median
			{
			_pctile monetaryHC if  level == 2 & inlist(split, `c'), nq(2)
			local H_med = r(r1)
			
			_pctile AverageConso_anpc if  level == 2 & inlist(split, `c'), nq(2)
			local AverageConso_anpc_med = r(r1)
				
			levelsof level_name if level == 2 & inlist(split, `c') , local(states)
			local nb_states :word count `states'

			local index  = 0
			forval i = 1/`=`nb_states'-1' {
				forval n = 1/`= c(N)' {
					if level_name[`n'] == "`:word `i' of `states''" {
						local k = `n'
						continue, break
					}
				}
				
				local index = `index' + abs([(1 - monetaryHC[`k']) / (1 - `H_med')] - [AverageConso_anpc[`k'] / `AverageConso_anpc_med'])
			}

			local index = `index' / `nb_states'
			local index : display %4.2f `index'
			di `index'	
			}
		
		
		twoway ///
			(lfitci  AverageConso_anpc monetaryHC) ///
			(scatter AverageConso_anpc monetaryHC if level == 1, mcolor(ebblue) m(T) )  ///
			(scatter AverageConso_anpc monetaryHC if level == 2, mcolor(cranberry) m(O) )  ///
			(scatter AverageConso_anpc monetaryHC if level == 3, mcolor(dkgreen) m(D) ) ///
			if inlist(split, `c') ///
		  ,  ///
			xlabel(`=0 + 0.5*(`m'==3)' (0.1) `=1 - 0.5*(`m'==2)')           ///
			xtitle("Monetary poverty headcount", axis(1)) ///
			ytitle("Average annual consumption per capita" ) ///
			legend(order(3 4 5 ) label(3 "National") label(4 "States") label(5 "Zones")  ///
			ring(0) position(1)) ///
			text(`=`min' - 20000' `=0.1 + (`m'== 3)*0.5' "Correlation = `r'%", place(ne) size(.25cm)) ///
			text(`=`min' + 10000' `=0.1 + (`m'== 3)*0.5' "Reverse state pairwises = `count'%", place(ne) size(.25cm)) ///
			text(`=350000 -(`m'== 3)*170000' `=0.1 + (`m'== 3)*0.5' "Average diff. in ratio to median = `index'", place(ne) size(.25cm)) ///
			graphregion(color(white)) bgcolor(white) /// 
			name(g3, replace) 
			
			
		* Average consumption vs PALE
		sum AverageConso_anpc if inlist(split, `c') 
		local min = r(min)
		correlate AverageConso_anpc PALE if inlist(split, `c') 
		local r = round(100* r(C)[1,2], 1)
		
			// Number of reverse pairwise states
			{
			levelsof level_name if level == 2 & inlist(split, `c') , local(states)
			local nb_states :word count `states'

			local count  = 0
			forval i = 1/`=`nb_states'-1' {
				forval n = 1/`= c(N)' {
					if level_name[`n'] == "`:word `i' of `states''" {
						local k = `n'
						continue, break
					}
				}
				
				forval j = `=`i'+1'/`nb_states' {
					forval n = 1/`= c(N)' {
						if level_name[`n'] == "`:word `j' of `states''" {
							local l = `n'
							continue, break
						}
					}
					
					if (AverageConso_anpc[`k'] > AverageConso_anpc[`l'] & PALE[`k'] < PALE[`l']) | ///
					   (AverageConso_anpc[`k'] < AverageConso_anpc[`l'] & PALE[`k'] > PALE[`l'])  {
						local count = `count' + 1
					}
				}
			}

			local count = round(100 * `count' / (0.5 * `nb_states' * (`nb_states' -1)), 1)
			di `count'	
			}
		
			// Average difference in indicator's ratio to median
			{
			_pctile PALE if  level == 2 & inlist(split, `c'), nq(2)
			local H_med = r(r1)
			
			_pctile AverageConso_anpc if  level == 2 & inlist(split, `c'), nq(2)
			local AverageConso_anpc_med = r(r1)
				
			levelsof level_name if level == 2 & inlist(split, `c') , local(states)
			local nb_states :word count `states'

			local index  = 0
			forval i = 1/`=`nb_states'-1' {
				forval n = 1/`= c(N)' {
					if level_name[`n'] == "`:word `i' of `states''" {
						local k = `n'
						continue, break
					}
				}
				
				local index = `index' + abs([(1 - PALE[`k']) / (1 - `H_med')] - [AverageConso_anpc[`k'] / `AverageConso_anpc_med'])
			}

			local index = `index' / `nb_states'
			local index : display %4.2f `index'
			di `index'	
			}
		
		
		twoway ///
			(lfitci  AverageConso_anpc PALE) ///
			(scatter AverageConso_anpc PALE if level == 1, mcolor(ebblue) m(T) )  ///
			(scatter AverageConso_anpc PALE if level == 2, mcolor(cranberry) m(O) )  ///
			(scatter AverageConso_anpc PALE if level == 3, mcolor(dkgreen) m(D) ) ///
			if inlist(split, `c') ///
		  ,  ///
			xtitle("PALE", axis(1)) ///
			ytitle("Average annual consumption per capita" ) ///
			legend(order(3 4 5 ) label(3 "National") label(4 "States") label(5 "Zones")  ///
			ring(0) position(1)) ///
			text(`=`min' - 20000' `=0.1 + (`m'== 2)*20' "Correlation = `r'%", place(ne) size(.25cm)) ///
			text(`=`min' + 10000' `=0.1 + (`m'== 2)*20' "Reverse state pairwises = `count'%", place(ne) size(.25cm)) ///
			text(`=350000 -(`m'== 3)*170000' `=0.1 + (`m'== 2)*20' "Average diff. in ratio to median = `index'", place(ne) size(.25cm)) ///
			graphregion(color(white)) bgcolor(white) /// 
			name(g4, replace) 
	  
		if "$varlist" != "Monetary1" 	local graphs g1 g2 g3 g4
		else							local graphs g1 g3 g4
		graph combine `graphs', col(2) xsize(10) ysize(5) iscale(*1)  ///
		title("Monetary poverty headcount and Others poverty measures: Correlation") ///
		graphregion(color(white)) 
		graph export "$output/Graphics/R2a_cnso_`m'.png", as(png) height(1000) name("Graph")	replace	
		
}	
	
	
   **** 2.b) Correlation between monetary and non-monetary
  *----------------------------------------------------------------------* 
	 
	if "$varlist" != "Monetary1" {
		
	   *| Preparing data
		use "$output/Data/LevelsIndicators", clear
		
		gen monetaryHC_compl 	 = 1 - monetaryHC
		gen monetaryHC_compl_rel = monetaryHC_compl/monetaryHC_compl[44]
		gen PALE_rel 			 = PALE/PALE[44]
		

		*| Designing Graph
		
		* Scatter plot version
		correlate monetaryHC_compl_rel PALE_rel
		local r = round(100* r(C)[1,2], 1)
		
		twoway ///
			(lfitci PALE_rel monetaryHC_compl_rel ) ///
			(scatter PALE_rel monetaryHC_compl_rel if level == 2, mcolor(cranberry) m(O) )  ///
			(scatter PALE_rel monetaryHC_compl_rel if level == 3,   mcolor(dkgreen) m(D) ) ///
		  ,  ///
			xlabel(0(0.4)2)         ///
			xtitle("National relative Monetary non poors (%)", axis(1)) ///
			ylabel(0(0.4)2) ///
			ytitle("National relative Poverty Adjusted Life Expectancy" ) ///
			legend(order(3 4) label(3 "States") label(4 "Zones")  ///
			ring(0) position(4)) ///
			title("Monetary non poors and Poverty Adjusted Life Expectancy" "Correlation")  ///
			   text(1.6 1.6 "Correlation = `r'%", place(e) size(.3cm)) ///
			graphregion(color(white)) bgcolor(white)	 
		 
		graph export "$output/Graphics/R2b.png", as(png) name("Graph")	replace	
		
		
		* Bar plot version
		graph bar (asis) monetaryHC_compl_rel PALE_rel ///
			if level == 2 ///
			, ///
			  over(level_name, sort(monetaryHC) lab(labsize(vsmall) angle(vertical))) ///
			  bargap(20) ///
			  nofill ///
			  legend(order(1 2) label(1 "National relative Monetary non poors") label(2 "National relative PALE")) ///
			  ytit("National relative indicators values", ///
				   placement(center) ///
				   justification(center) ///
				   size(medsmall)) ///
			graphregion(color(white)) bgcolor(white)
			
		graph export "$output/Graphics/R2b_BarStates.png", as(png) height(700) name("Graph") replace	
		
		
		graph bar (asis) monetaryHC_compl_rel PALE_rel ///
			if level == 3 ///
			, ///
			  over(level_name, sort(monetaryHC) lab(labsize(vsmall) angle(vertical))) ///
			  bargap(20) ///
			  nofill ///
			  blabel(bar, format(%9.1f) size(vsmall) orientation(vertical)) ///
			  legend(order(1 2) label(1 "National relative Monetary non poors") label(2 "National relative PALE")) ///
			  ytit("National relative indicators values", ///
				   placement(center) ///
				   justification(center) ///
				   size(medsmall)) ///
			graphregion(color(white)) bgcolor(white)
		graph export "$output/Graphics/R2b_BarZones.png", as(png) height(700) name("Graph") replace	
	}		 
	 
	 
   **** 2.c) Which fraction of non-monetary MDP poor is new?
  *----------------------------------------------------------------------* 
	 
	if "$varlist" != "Monetary1" {

	*| Preparing data
	 
		use "$projectfolder/Output/Data/main.dta", clear
		
		MDPDecomp 	, varlist($varlist) povmod(`povmod')	
		MDP  		, varlist($varlist) povmod(`povmod')	
		
		cap drop MDPDecomp__*
		tab MDPStatus MDPDecomp	
		tab MDPDecomp, gen(MDPDecomp__)
		recode MDPDecomp__* (. = 0)
		
		tempfile Ratio_ONMP_Both
		 
		local i = 0
		foreach lev in national state zone {
		preserve
			local i = `i' + 1
			
			tempfile label
			elabel save (`lev') using `label'.do, replace
			elabel list (`lev')
			local label_name `r(name)' 
			
			tabstat MDPDecomp__1 [aw = wt_final], stat(mean) by(`lev') save 
			tabstatmat ONMP
			mat ONMP = ONMP[1..`=rowsof(ONMP)-1',1]

			tabstat MDPDecomp__3 [aw = wt_final], stat(mean) by(`lev') save 
			tabstatmat B
			mat B = B[1..`=rowsof(B)-1',1]
			
			mata: st_matrix("Ratio_new", st_matrix("ONMP"):/st_matrix("B"))
			mat colnames Ratio_new = Ratio_ONMP_Both

			clear
			svmat Ratio_new, names(col)
			
			gen level = `i'
			
			gen level_namee = _n
			do `label'.do
			lab val level_namee `label_name'
			decode level_namee, gen(level_name)
			drop level_namee
			
			if `i' == 1 save `Ratio_ONMP_Both', replace
			else {
				append using `Ratio_ONMP_Both'
				save `Ratio_ONMP_Both', replace
			}
			
		restore
		}
		use `Ratio_ONMP_Both', clear
		merge 1:1 level_name using "$output/Data/LevelsIndicators", nogen 
		save "$output/Data/LevelsIndicators", replace
	  
	  
	   *| Designing Graphs
		forval i = 2/3 {
		preserve
			keep if inlist(level, 1, `i')
			separate Ratio_ONMP_Both, by(level == 1)
			
			graph bar (asis) Ratio_ONMP_Both0 Ratio_ONMP_Both1 ///
				, ///
				  over(level_name, sort(1) lab(labsize(vsmall) angle(vertical))) ///
				  bargap(15) ///
				  nofill ///
				  blabel(bar, format(%9.1f) size(vsmall) orientation(vertical)) ///
				  legend(order(1 2) label(1 "Subnational") label(2 "National")) ///
				  ytit("Ratio of Others dimensions poors by Both Monetary and Others dimensions poors", ///
					   placement(bottom) ///
					   justification(center) ///
					   size(small)) ///
				graphregion(color(white)) bgcolor(white)
				
			graph export "$output/Graphics/R2c_Ratio_ONMP_Both`=`i'-1'.png", as(png) height(700) name("Graph") replace	
		restore
		}	
	}
			   
		
   **** 3) Should we better trust monetary poverty or non-monetary poverty
  *-----------------------------------------------------------------------* 
	 
	if "$varlist" != "Monetary1" {
  
	// 	local varlist Monetary Education Health1 Housing5 Security
	// 	local povmod 2
	   
		correlate monetaryHC PALE
		local r = round(100* r(C)[1,2], 1)
		
		twoway ///
			(lfitci PALE monetaryHC ) ///
			(scatter PALE monetaryHC  if level == 2, mcolor(cranberry) m(O) )  ///
			(scatter PALE monetaryHC if level == 3,   mcolor(dkgreen) m(D) ) ///
		  ,  ///
			xlabel(0(0.2)1)         ///
			xtitle("Monetary non poors", axis(1)) ///
			ylabel(0(10)50) ///
			ytitle("Poverty Adjusted Life Expectancy" ) ///
			legend(order(3 4) label(3 "States") label(4 "Zones")  ///
			ring(0) position(1)) ///
			title("Monetary non poors and Poverty Adjusted Life Expectancy" "Correlation")  ///
			text(0 0.2 "Correlation = `r'%", place(ne) size(.3cm)) ///
			graphregion(color(white)) bgcolor(white) ///
			name(g1, replace) 
			
			
		correlate PALE NMPALE
		local r = round(100* r(C)[1,2], 1)
		
		twoway ///
			(lfitci PALE NMPALE ) ///
			(scatter PALE NMPALE  if level == 2, mcolor(cranberry) m(O) )  ///
			(scatter PALE NMPALE if level == 3,   mcolor(dkgreen) m(D) ) ///
		  ,  ///
			xlabel(0(10)50)         ///
			xtitle("Others dimensions Poverty Adjusted Life Expectancy", axis(1)) ///
			ylabel(0(10)50) ///
			ytitle("Poverty Adjusted Life Expectancy" ) ///
			legend(order(3 4) label(3 "States") label(4 "Zones")  ///
			ring(0) position(1)) ///
			title("Others dimensions PALE and Poverty Adjusted Life Expectancy" "Correlation")  ///
			text(0 10 "Correlation = `r'%", place(ne) size(.3cm)) ///
			graphregion(color(white)) bgcolor(white) ///
			name(g2, replace) 
	  
		graph combine g1 g2, col(2) xsize(10) ysize(5) iscale(*1)  ///
		title("Which is best correlated to PALE: Monetary HC or Others dimensions PALE?") ///
		graphregion(color(white)) 
		graph export "$output/Graphics/R3.png", as(png) height(800) name("Graph")	replace	
	}
   
   
   **** 4)	Decomposition of PALE differences between two states or two zones
  *--------------------------------------------------------------------------* 
  	 
	if "$varlist" != "Monetary1" {

		*| Permutations
		local nb_param = 5
		local nb_combi = round(exp(lnfactorial(`nb_param')),1)
		
		drop _all
		input str20 param
		"LE"
		"daysout"
		"H_O"
		"H_M"
		"C"
		end
		permin param, k(`nb_param')
		
		foreach par in LE daysout H_O H_M C {
			gen DELTA_PALE_`par' = .
		}
		save "$output/Data/PermutationsShorrocks.dta", replace
		
	  
	   *| Preparing data
		use "$projectfolder/Output/Data/main.dta", clear
		
	// 	local varlist Monetary1 Health1 Housing5 Security2
	// 	local povmod 2
		
		qui do "$programs/2_2_DataAnalysis_Commands.do" // I don't understand why at this stage all my programs disapear
		MDPDecomp 	, varlist($varlist) povmod(`povmod')	
		MDP  		, varlist($varlist) povmod(`povmod')	
		
		tab MDPStatus MDPDecomp	
		cap drop MDPDecomp__*
		tab MDPDecomp, gen(MDPDecomp__)
		recode MDPDecomp__* (. = 0)
		  
		  
		*| Shorrocks program
		cap prog drop Shorrocks1
		prog def Shorrocks1 , rclass
			
			syntax ,LEV(name) ///
					LEVELID(numlist min =2 max =2 integer)
					
			local nb_param = 5
			local nb_combi = round(exp(lnfactorial(`nb_param')),1)
			
			// PALE parameters computing for each compared state
			mat VAR = J(5,2, .)
			local k = 0
			foreach j in `levelid' {
				local k = `k' + 1
				
				* LE
				qui mean LEB_all if `lev' == `j' // constant
				local LE_`k' = e(b)[1,1]
				di "LE_`k' = `LE_`k''"
				mat VAR[1,`k'] = `LE_`k''
				
				* Days out
				qui mean daysout [iw = wt_final] if `lev' == `j'
				local daysout_`k' = e(b)[1,1]/30
				di "daysout_`k' = `daysout_`k''"
				mat VAR[2,`k'] = 100 * `daysout_`k''
				
				* ONMP headcount
				qui mean MDPDecomp__1 [iw = wt_final] if `lev' == `j'
				local ONMP_HC_`k' = e(b)[1,1]
				di "ONMP_HC_`k' = `ONMP_HC_`k''"
				mat VAR[3,`k'] = 100 * `ONMP_HC_`k''
				
				* OMP headcount
				qui mean MDPDecomp__2 [iw = wt_final] if `lev' == `j'
				local OMP_HC_`k' = e(b)[1,1]
				di "OMP_HC_`k' = `OMP_HC_`k''"
				mat VAR[4,`k'] = 100 * `OMP_HC_`k''
				
				* BOTH headcount
				qui mean MDPDecomp__3 [iw = wt_final] if `lev' == `j'
				local B_HC_`k' = e(b)[1,1]
				di "B_HC_`k' = `B_HC_`k''"
				mat VAR[5,`k'] = 100 * `B_HC_`k''
			}
			
			// Deltas PALE for each possible permutations 
			 forval perm = 1/ `nb_combi' { 
				 local PALE_ini = `LE_1' * (1-`daysout_1') *(1-`ONMP_HC_1'- `OMP_HC_1' - `B_HC_1')
				 
				 forval i = 1/`nb_param' {
					preserve
						use "$output/Data/PermutationsShorrocks.dta", clear
							foreach par in LE daysout ONMP_HC OMP_HC B_HC {
								local x_`par' = 1
								forval l = 1/`i' {
								   if param_`l'[`perm'] == "`par'"  local x_`par' = 2
								}
							}
					restore
					
					if `i' > 1 local PALE_ini = `PALE_fin'
					local PALE_fin = `LE_`x_LE'' * (1-`daysout_`x_daysout'') *(1-`ONMP_HC_`x_ONMP_HC''- `OMP_HC_`x_OMP_HC'' - `B_HC_`x_B_HC'')
					local Delta_PALE = `PALE_fin' -`PALE_ini'
					
					preserve
						use "$output/Data/PermutationsShorrocks.dta", clear
						qui replace DELTA_PALE_`=param_`i'[`perm']' = `Delta_PALE' if _n == `perm'
						qui save "$output/Data/PermutationsShorrocks.dta", replace
	// 					sleep 3000
					restore
				 }
			 }
			 
			 // Contribution of each parameter to change in PALE
			 mat CONTRIB = J(1,`nb_param', .)
			 
			 local PALE_ini = `LE_1' * (1-`daysout_1') *(1-`ONMP_HC_1'- `OMP_HC_1' - `B_HC_1')
			 local PALE_fin = `LE_2' * (1-`daysout_2') *(1-`ONMP_HC_2'- `OMP_HC_2' - `B_HC_2')
			 local Delta_PALE_Total = `PALE_fin' - `PALE_ini'
			 di `PALE_ini'
			 di `PALE_fin'
			 di `Delta_PALE_Total'
			 
			 local k = 0
			 foreach par in LE daysout ONMP_HC OMP_HC B_HC {
				 local k = `k' + 1
				 preserve
					 use "$output/Data/PermutationsShorrocks.dta", clear
					 qui mean DELTA_PALE_`par'
					 mat CONTRIB[1,`k'] = 100* e(b)[1,1]/`Delta_PALE_Total'
				restore
			 }
			 mat colnames CONTRIB = LE daysout ONMP_HC OMP_HC B_HC
			 
			 return mat CONTRIB = CONTRIB
			 return mat VAR = VAR 
		end

		cap prog drop Shorrocks2
		prog def Shorrocks2 , rclass
			
			syntax ,LEV(name) ///
					LEVELID(numlist min =2 max =2 integer)
					
			local nb_param = 5
			local nb_combi = round(exp(lnfactorial(`nb_param')),1)
			
			// PALE parameters computing for each compared state
			mat VAR = J(5,2, .)
			local k = 0
			foreach j in `levelid' {
				local k = `k' + 1
				
				* LE
				qui mean LEB_all if `lev' == `j' // constant
				local LE_`k' = e(b)[1,1]
				di "LE_`k' = `LE_`k''"
				mat VAR[1,`k'] = `LE_`k''
				
				* Days out
				qui mean daysout [iw = wt_final] if `lev' == `j'
				local daysout_`k' = e(b)[1,1]/30
				di "daysout_`k' = `daysout_`k''"
				mat VAR[2,`k'] = 100 * `daysout_`k''
				
				* H_O headcount
				qui mean MDPDecomp__1 [iw = wt_final] if `lev' == `j'
				local H_O_`k' = e(b)[1,1]
				qui mean MDPDecomp__3 [iw = wt_final] if `lev' == `j'
				local H_O_`k' = `H_O_`k'' + e(b)[1,1]
				di "H_O_`k' = `H_O_`k''"
				mat VAR[3,`k'] = 100 * `H_O_`k''
				
				* H_M headcount
				qui mean MDPDecomp__2 [iw = wt_final] if `lev' == `j'
				local H_M_`k' = e(b)[1,1]
				qui mean MDPDecomp__3 [iw = wt_final] if `lev' == `j'
				local H_M_`k' = `H_M_`k'' + e(b)[1,1]
				di "H_M_`k' = `H_M_`k''"
				mat VAR[4,`k'] = 100 * `H_M_`k''
				
				* C Overlap
				qui mean MDPStatus [iw = wt_final] if `lev' == `j'
				local H_`k' = e(b)[1,1]
				local C_`k' = [	(1 - `H_M_`k'') / `H_M_`k'' ]  * [(`H_M_`k'' + `H_O_`k'' - `H_`k'' ) / ( `H_`k'' - `H_M_`k'' )]
				di "C_`k' = `C_`k''"
				mat VAR[5,`k'] = 100 * `C_`k''
			}
			
			// Deltas PALE for each possible permutations 
			 forval perm = 1/ `nb_combi' { 
				 local PALE_ini = `LE_1' * (1-`daysout_1') *(1- [`C_1' * `H_M_1'^2 + (1 - `H_M_1') * (`H_M_1' + `H_O_1')] / [`H_M_1' * (`C_1' -1) + 1])
				 
				 forval i = 1/`nb_param' {
					preserve
						use "$output/Data/PermutationsShorrocks.dta", clear
							foreach par in LE daysout H_O H_M C {
								local x_`par' = 1
								forval l = 1/`i' {
								   if param_`l'[`perm'] == "`par'"  local x_`par' = 2
								}
							}
					restore
					
					if `i' > 1 local PALE_ini = `PALE_fin'
					local PALE_fin = `LE_`x_LE'' * (1-`daysout_`x_daysout'') *(1- [`C_`x_C'' * `H_M_`x_H_M''^2 + (1 - `H_M_`x_H_M'') * (`H_M_`x_H_M'' + `H_O_`x_H_O'')] / [`H_M_`x_H_M'' * (`C_`x_C'' - 1) +1])
					local Delta_PALE = `PALE_fin' -`PALE_ini'
					
					preserve
						use "$output/Data/PermutationsShorrocks.dta", clear
						qui replace DELTA_PALE_`=param_`i'[`perm']' = `Delta_PALE' if _n == `perm'
						qui save "$output/Data/PermutationsShorrocks.dta", replace
	// 					sleep 3000
					restore
				 }
			 }
			 
			 // Contribution of each parameter to change in PALE
			 mat CONTRIB = J(1,`nb_param', .)
			 
			 local PALE_ini = `LE_1' * (1-`daysout_1') *(1 - [`C_1' * `H_M_1'^2 + (1 - `H_M_1') * (`H_M_1' + `H_O_1')] / [`H_M_1' * (`C_1' - 1) + 1])
			 local PALE_fin = `LE_2' * (1-`daysout_2') *(1 - [`C_2' * `H_M_2'^2 + (1 - `H_M_2') * (`H_M_2' + `H_O_2')] / [`H_M_2' * (`C_2' - 1) + 1])
			 local Delta_PALE_Total = `PALE_fin' - `PALE_ini'
			 di `PALE_ini'
			 di `PALE_fin'
			 di `Delta_PALE_Total'
			 
			 local k = 0
			 foreach par in LE daysout H_O H_M C {
				 local k = `k' + 1
				 preserve
					 use "$output/Data/PermutationsShorrocks.dta", clear
					 qui mean DELTA_PALE_`par'
					 mat CONTRIB[1,`k'] = 100* e(b)[1,1]/`Delta_PALE_Total'
				restore
			 }
			 mat colnames CONTRIB = LE daysout H_O H_M C
			 
			 return mat CONTRIB = CONTRIB
			 return mat VAR = VAR 
		end


		*| Test of Shorrocks program
	// 	Shorrocks1, lev(state) levelid(1 2) //good
	// 	Shorrocks1, lev(zone) levelid(3 4) //good
		
	// 	Shorrocks2, lev(state) levelid(1 2) //good
	// 	Shorrocks2, lev(zone) levelid(3 4) //good
		
		
		*| Output graphic	
	// 	elabel list (state)
	// 	local n_state	= r(k)
	// 	local state_value `r(values)'
	// 	local state_label `r(labels)'
	//	
	// 	forval i = 1/`=`n_state'-1' {
	// 	    forval j = `=`i'+1'/`n_state' {
	// 		    di  "State_`i'_X_`j'"
	// 			di "*------------------------------*"
	// 		    Shorrocks2, lev(state) levelid(`i' `j') 
	// 			mat tampon = r(CONTRIB)
	// 			mat rownames tampon = State_`i'_X_`j'
	// 			if `i'==1 & `j'==2  mat CONTRIB_AllStates = tampon
	// 			else				mat CONTRIB_AllStates = CONTRIB_AllStates / tampon
	//			
	// 		}
	// 	}
	//	
	// 	clear
	// 	svmat CONTRIB_AllStates, names(col)
	// 	save "$output/Data/CONTRIB_DeltaPALE_AllStates.dta", replace
	//		
	//     twoway  (kdensity LE if LE >-250 & LE < 250 , color(gs10)) ///
	// 			(kdensity daysout if daysout >-250 & daysout < 250, color(emerald)) ///
	// 			(kdensity H_O if H_O >-250 & H_O < 250, color(ebblue)) ///
	// 			(kdensity H_M if H_M >-250 & H_M < 250, color(dkgreen)) ///
	// 			(kdensity C if C >-250 & C < 250, color(dkorange)) ///
	// 			, ///
	// 			legend(`leg_daysoutR4') ///
	// 			xlabel(-250(50)250)         ///
	// 			xtitle("Contribution to change in PALE") ///
	// 			ytitle(Density) ///
	// 			bgcolor (white) graphregion(color(white))	
	//
	// 	graph export "$output/Graphics/R4.png", as(png) name("Graph")	replace	
	}
	
	
   **** 4.b)	Decomposition of PALE differences between targeted zones
  *--------------------------------------------------------------------------* 
	 
	if "$varlist" != "Monetary1" {
		
// 		o	South East VS North Central
// 		o	South West VS North Central
// 		o	North East VS North West
// 		o	South West VS South East
// 		o	South East VS South South
	  
		*| Data Preparation
		use "$projectfolder/Output/Data/main.dta", clear
		putexcel set "$output/Graphics/Shorrocks_Zones.xlsx", modify

// 		local varlist Monetary Health1 Housing5 Security
// 		local povmod 2

		MDPDecomp 	, varlist($varlist) povmod(`povmod')	
		MDP  		, varlist($varlist) povmod(`povmod')	

		tab MDPStatus MDPDecomp	
		cap drop MDPDecomp__*
		tab MDPDecomp, gen(MDPDecomp__)
		recode MDPDecomp__* (. = 0)
		
		cap mat drop zon
		mat input zon = (4,1\ 6, 1\ 2 ,3\6, 4\4, 5)
		
		forval i = 1/`=rowsof(zon)' {
			Shorrocks2, lev(zone) levelid(`=zon[`i',1]' `=zon[`i',2]')
			
			putexcel `=char(66 + 3*(`i'-1))'2 = mat(r(VAR))

			mat tampon = r(CONTRIB)
			if `i'==1 	mat CONTRIB_TargetZones = tampon
			else		mat CONTRIB_TargetZones = CONTRIB_TargetZones \ tampon
		}
	   
		clear
		svmat CONTRIB_TargetZones, names(col)
		input str40 crossed_zones
		"South East VS North Central"
		"South West VS North Central"
		"North East VS North West"
		"South West VS South East"
		"South East VS South South"
		
	   
		*| Graph Designing
		graph hbar LE daysout H_O H_M C ///
			, ///
			stack over(crossed_zones, lab(labsize(small) angle(horizontal))) ///
			nofill ///
			bargap(60) ///
			legend(`leg_daysoutR4b' ///
				   c(1) pos(3) ///
				   symxsize(medsmall) symysize(medsmall) size(vsmall)) ///
			blabel(bar, format(%9.0f) pos(outside) size(vsmall)) ///
			bar(5, color(white) lc(black) lp(solid) lw(thin)) ///
			bar(4, color(cranberry)) ///
			bar(3, color(ebblue)) ///
			bar(2,color(dkorange)) ///
			bar(1, color(dkgreen)) ///
			title("{fontface Arial Bold : Decomposition of PALE difference between targeted zones}", size(medsmall)) ///
			graphregion(color(white)) bgcolor(white) 
		graph export "$output/Graphics/R4b.png", as(png) height(700) name("Graph")	replace	
	}
   
   
   **** 5) Impact of each dimension on poverty measurement
  *--------------------------------------------------------------------------* 
	 
	if "$varlist" != "Monetary1" {
		
		// All dimensions kept: differenciation by zones 

		*| Data Preparation
		use "$projectfolder/Output/Data/main.dta", clear

	// 	local varlist Monetary1 Education1 Health1 Housing5 Security1
		local povmod 2
		local monetary Monetary1 Monetary2
		local varlist_nomo: list global(varlist) - monetary
		
		MDPDecomp 	, varlist($varlist) povmod(`povmod')
		MDP  		, varlist($varlist) povmod(`povmod')	
		MDPDecomp2	, mdpstatus(MDPStatus) mdpdecomp(MDPDecomp)  varlist($varlist)	
		
		tempfile addIndicators
		global i = 0
		
		foreach lev in national state zone {
			preserve
				global i = $i + 1 
				
				tempfile label
				elabel save (`lev') using `label'.do, replace

				elabel list (`lev')
				local lev_lname `r(name)'
				local n_lev	= r(k)
				local lev_value `r(values)'
				
				mat ExtCum = J(`n_lev', 7, .) //  
				mat colnames ExtCum  = Non_poor Monetary_extr_OMP Monetary_extr_othdim_ext Monetary_extr_othdim_cum Extremor_othdim_poor Cumulator Overlap_C
				
				tempfile label
				elabel save (`lev') using `label'.do, replace
				
				local k = 0
				forval z = 1/`n_lev'  { 
					local k = `k' + 1
					
					tab MDPDecomp2[iw = wt_final] if `lev' == `:word `z' of `lev_value'', matcell(freq)
					forval i = 1/`=rowsof(freq)' {
						mat ExtCum[`k', `i'] = 100* freq[`i', 1]/r(N)
					}
					
					* Overlap C
					qui mean MDPDecomp__1 [iw = wt_final] if `lev' == `:word `z' of `lev_value''
					local H_O = e(b)[1,1]
					qui mean MDPDecomp__3 [iw = wt_final] if `lev' == `:word `z' of `lev_value''
					local H_O = `H_O' + e(b)[1,1]
					
					qui mean MDPDecomp__2 [iw = wt_final] if `lev' == `:word `z' of `lev_value''
					local H_M = e(b)[1,1]
					qui mean MDPDecomp__3 [iw = wt_final] if `lev' == `:word `z' of `lev_value''
					local H_M = `H_M' + e(b)[1,1]

					qui mean MDPStatus [iw = wt_final] if `lev' == `:word `z' of `lev_value''
					local H = e(b)[1,1]
					local C = [	(1 - `H_M') / `H_M' ]  * [(`H_M' + `H_O' - `H' ) / ( `H' - `H_M' )]
					mat ExtCum[`k', 7] = `C'
				}
				
				clear
				svmat ExtCum, names(col)
				
				gen level = $i
				
				gen level_namee = _n
				do `label'.do
				lab val level_namee `lev_lname'
				decode level_namee, gen(level_name)
				drop level_namee
				
				if $i == 1 save `addIndicators', replace
				else {
					append using `addIndicators'
					save `addIndicators', replace
				}
			restore
		}
		
		use `addIndicators', clear
		merge 1:1 level_name using "$output/Data/LevelsIndicators", nogen 
		save "$output/Data/LevelsIndicators", replace	
		
		keep if inlist(level, 1,3)
		
		local need 
		foreach var of varlist Monetary_extr_OMP Monetary_extr_othdim_ext Monetary_extr_othdim_cum Extremor_othdim_poor Cumulator {
			local need1 `var'
			local need: list need1 | need
			egen `var'_plus = rowtotal(`need')
		}

		egen MonetaryExt = rowtotal(Monetary_extr_OMP Monetary_extr_othdim_ext Monetary_extr_othdim_cum)
		sort MonetaryExt
		gen order = _n	
		gen base = 0
		
		*| Graph Designing
		twoway ///
			(rbar base Monetary_extr_OMP_plus order, color(white) lc(black) lp(solid) lw(thin) barwidth(0.65) yaxis(1)) ///
			(rbar Monetary_extr_OMP_plus Monetary_extr_othdim_ext_plus order, color(ebblue) barwidth(0.65) yaxis(1)) ///
			(rbar Monetary_extr_othdim_ext_plus Monetary_extr_othdim_cum_plus order, color(dkorange) barwidth(0.65) yaxis(1)) ///
			(rbar Monetary_extr_othdim_cum_plus Extremor_othdim_poor_plus order, color(dkgreen) barwidth(0.65) yaxis(1)) ///
			(rbar Extremor_othdim_poor_plus Cumulator_plus order, color(cranberry) barwidth(0.65) yaxis(1)) ///
			(scatter Overlap_C order, color(black) msize(large) mlabel(Overlap_C) mlabformat(%9.1f) yaxis(2)) ///
			, ///
			legend(order(6 "Overlap" ///
						 5 "Cumulator" ///
						 4 "Extremor_othdim_poor" ///
						 3 "Monetary_extr_othdim_cum" ///
						 2 "Monetary_extr_othdim_ext" ///
						 1 "Monetary_extr_OMP") ///
				   c(1) pos(3) ///
				   symxsize(medsmall) symysize(medsmall) size(vsmall)) ///
			xtitle(, size(zero)) ///
			xlabel(1 "`=level_name[1]'" 2 "`=level_name[2]'" 3 "`=level_name[3]'" 4 "`=level_name[4]'" 5 "`=level_name[5]'" 6 "`=level_name[6]'" 7 "`=level_name[7]'", labsize(small) angle(vertical) labgap(small) noticks) ///
			ytitle("Headcount(%)", axis(1)) ///
			ytitle("Overlap", axis(2)) ///
			ylabel(0(1)3, axis(2)) ///
			title("{fontface Arial Bold : Muldimensionnal poverty decomposition by zones}", size(medsmall)) ///
			graphregion(color(white)) bgcolor(white) 
		graph export "$output/Graphics/R5_a.png", as(png)  height(700) name("Graph")	replace	
		
		
		// Repeated previous graph with National bar only
		twoway ///
			(rbar base Monetary_extr_OMP_plus order, color(white) lc(black) lp(solid) lw(thin) barwidth(0.3) yaxis(1)) ///
			(rbar Monetary_extr_OMP_plus Monetary_extr_othdim_ext_plus order, color(ebblue) barwidth(0.3) yaxis(1)) ///
			(rbar Monetary_extr_othdim_ext_plus Monetary_extr_othdim_cum_plus order, color(dkorange) barwidth(0.3) yaxis(1)) ///
			(bar MonetaryExt order, fcolor(white%0) lc(red) lp(dash_dot) lw(thin) barwidth(0.32) yaxis(1)) ///
			(rbar Monetary_extr_othdim_cum_plus Extremor_othdim_poor_plus order, color(dkgreen) barwidth(0.3) yaxis(1)) ///
			(rbar Extremor_othdim_poor_plus Cumulator_plus order, color(cranberry) barwidth(0.3) yaxis(1)) ///
			(scatter Overlap_C order, color(black) msize(large) mlabel(Overlap_C) mlabformat(%9.1f) yaxis(2)) ///
			if level_name == "National" ///
			, ///
			legend(order(7 "Overlap" ///
						 6 "OD cumulator" ///
						 5 "OD extremor" ///
						 4 "Monet. extr. All" ///
						 3 "Monet. extr. & OD cum." ///
						 2 "Monet. extr. & OD extr." ///
						 1 "Monet. extr. O") ///
				   c(1) pos(3) ///
				   symxsize(medsmall) symysize(medsmall) size(vsmall)) ///
			xtitle(, size(zero)) ///
			xlabel( 3 " " 4 "`=level_name[4]'" 5 " " ,  labsize(small) angle(vertical) labgap(small) noticks) ///
			ytitle("Headcount(%)", axis(1)) ///
			ytitle("Overlap", axis(2)) ///
			ylabel(0(1)3, axis(2)) ///
			title("{fontface Arial Bold : Muldimensionnal poverty decomposition: Nigeria}", size(medsmall)) ///
			graphregion(color(white)) bgcolor(white) ysize(4) xsize(4.5) 
		graph export "$output/Graphics/R5_aNat.png", as(png)  height(500) name("Graph")	replace			
		
		
		// One by one dimensions removed: National level
		use "$projectfolder/Output/Data/main.dta", clear
		
	// 	global varlist Monetary1 Health2 Housing5 Security2 
		local povmod 2
		local monetary Monetary1 Monetary2
		local varlist_nomo: list global(varlist) - monetary
				
		mat ExtCum = J(`:word count $varlist', 7, .)
		mat colnames ExtCum  = Non_poor Monetary_extr_OMP Monetary_extr_othdim_ext Monetary_extr_othdim_cum Extremor_othdim_poor Cumulator Overlap_C
		
		MDPDecomp 	, varlist($varlist) povmod(`povmod')
		MDP  		, varlist($varlist) povmod(`povmod')	
		MDPDecomp2	, mdpstatus(MDPStatus) mdpdecomp(MDPDecomp)  varlist($varlist)
		
		tab MDPDecomp2[iw = wt_final] , matcell(freq) 
		forval i = 1/`=rowsof(freq)' {
			mat ExtCum[1, `i'] = 100* freq[`i', 1]/r(N)
		}
		
		* Overlap C
			qui mean MDPDecomp__1 [iw = wt_final] 
			local H_O = e(b)[1,1]
			qui mean MDPDecomp__3 [iw = wt_final] 
			local H_O = `H_O' + e(b)[1,1]
			
			qui mean MDPDecomp__2 [iw = wt_final] 
			local H_M = e(b)[1,1]
			qui mean MDPDecomp__3 [iw = wt_final] 
			local H_M = `H_M' + e(b)[1,1]

			qui mean MDPStatus [iw = wt_final] 
			local H = e(b)[1,1]
			local C = [	(1 - `H_M') / `H_M' ]  * [(`H_M' + `H_O' - `H' ) / ( `H' - `H_M' )]
			mat ExtCum[1, 7] = `C'
		
		local k = 1
		foreach dim of local varlist_nomo  { 
			local k = `k' + 1
			local removed `dim'
			local varlist_reduced: list global(varlist) - removed
			
			MDPDecomp 	, varlist(`varlist_reduced') povmod(`povmod')
			MDP  		, varlist(`varlist_reduced') povmod(`povmod')	
			MDPDecomp2	, mdpstatus(MDPStatus) mdpdecomp(MDPDecomp) varlist(`varlist_reduced')
			
			tab MDPDecomp2[iw = wt_final] , matcell(freq) 
			forval i = 1/`=rowsof(freq)' {
				mat ExtCum[`k', `i'] = 100* freq[`i', 1]/r(N)
			}
			
		* Overlap C
			qui mean MDPDecomp__1 [iw = wt_final] 
			local H_O = e(b)[1,1]
			qui mean MDPDecomp__3 [iw = wt_final] 
			local H_O = `H_O' + e(b)[1,1]
			
			qui mean MDPDecomp__2 [iw = wt_final] 
			local H_M = e(b)[1,1]
			qui mean MDPDecomp__3 [iw = wt_final] 
			local H_M = `H_M' + e(b)[1,1]

			qui mean MDPStatus [iw = wt_final] 
			local H = e(b)[1,1]
			local C = [	(1 - `H_M') / `H_M' ]  * [(`H_M' + `H_O' - `H' ) / ( `H' - `H_M' )]
			mat ExtCum[`k', 7] = `C'
			
		}
		
		clear
		svmat ExtCum, names(col)
		
		gen dimension_removed = "All dimensions kept" if _n == 1
		local  k = 1
		foreach dim of local varlist_nomo {
			local k = `k' + 1
			replace dimension_removed = "`dim' removed" if _n == `k'
		}
		
		local need 
		foreach var of varlist Monetary_extr_OMP Monetary_extr_othdim_ext Monetary_extr_othdim_cum Extremor_othdim_poor Cumulator {
			local need1 `var'
			local need: list need1 | need
			egen `var'_plus = rowtotal(`need')
		}
		gen order = _n
		
		save "$output/Data/DimensionsRemovedNat.dta", replace
		
		
		*| Graph Designing
		twoway ///
			(bar Monetary_extr_OMP_plus order, color(white) lc(black) lp(solid) lw(thin) barwidth(0.65) yaxis(1)) ///
			(rbar Monetary_extr_OMP_plus Monetary_extr_othdim_ext_plus order, color(ebblue) barwidth(0.65) yaxis(1)) ///
			(rbar Monetary_extr_othdim_ext_plus Monetary_extr_othdim_cum_plus order, color(dkorange) barwidth(0.65) yaxis(1)) ///
			(line Monetary_extr_othdim_cum_plus order, lc(red) lp(dash_dot) lw(thin) yaxis(1)) ///
			(rbar Monetary_extr_othdim_cum_plus Extremor_othdim_poor_plus order, color(dkgreen) barwidth(0.65) yaxis(1)) ///
			(rbar Extremor_othdim_poor_plus Cumulator_plus order, color(cranberry) barwidth(0.65) yaxis(1)) ///
			(scatter Overlap_C order, color(black) msize(large) mlabel(Overlap_C) mlabformat(%9.1f) yaxis(2)) ///
			, ///
		legend(order(7 "Overlap" ///
					 6 "OD cumulator" ///
					 5 "OD extremor" ///
					 4 "Monet. extr. All" ///
					 3 "Monet. extr. & OD cum." ///
					 2 "Monet. extr. & OD extr." ///
					 1 "Monet. extr. O") ///
				   c(1) pos(3) ///
				   symxsize(medsmall) symysize(medsmall) size(vsmall)) ///
			xtitle(, size(zero)) ///
			xlabel(	 1 "`=dimension_removed[1]'" 2 "`=dimension_removed[2]'" 3 "`=dimension_removed[3]'" 4 "`=dimension_removed[4]'" ///
					5 "`=dimension_removed[5]'", labsize(vsmall) angle(vertical) labgap(small) noticks) ///
			ytitle("Headcount(%)", axis(1)) ///
			ytitle("Overlap", axis(2)) ///
			ylabel(0(1)3, axis(2)) ///
			title("{fontface Arial Bold : Impact of non monetary dimensions on multi-dimensional poverty headcount}", size(medsmall)) ///
			graphregion(color(white)) bgcolor(white) 
		graph export "$output/Graphics/R5_bNat.png", as(png)  height(500) name("Graph")	replace	
		
		
		// One by one dimensions removed: for each zone
		use "$projectfolder/Output/Data/main.dta", clear
		
		elabel list     (zone)
		local n_zone 	 = r(k)
		local zone_lname `r(name)'
		local zone_value `r(values)'
		
		forval z = 1/`n_zone'  { 
			
			*| Data Preparation
			use "$projectfolder/Output/Data/main.dta", clear
			
			elabel list `zone_lname' iff # == `:word `z' of `zone_value''
			local zone_name `r(labels)'
			
			mat ExtCum = J(`:word count $varlist', 7, .)
			mat colnames ExtCum  = Non_poor Monetary_extr_OMP Monetary_extr_othdim_ext Monetary_extr_othdim_cum Extremor_othdim_poor Cumulator Overlap_C
			
			MDPDecomp 	, varlist($varlist) povmod(`povmod')
			MDP  		, varlist($varlist) povmod(`povmod')	
			MDPDecomp2	, mdpstatus(MDPStatus) mdpdecomp(MDPDecomp)  varlist($varlist)
			
			tab MDPDecomp2[iw = wt_final] if zone == `:word `z' of `zone_value'', matcell(freq)
			forval i = 1/`=rowsof(freq)' {
				mat ExtCum[1, `i'] = 100* freq[`i', 1]/r(N)
			}
			
			* Overlap C
				qui mean MDPDecomp__1 [iw = wt_final] if zone == `:word `z' of `zone_value''
				local H_O = e(b)[1,1]
				qui mean MDPDecomp__3 [iw = wt_final] if zone == `:word `z' of `zone_value''
				local H_O = `H_O' + e(b)[1,1]
				
				qui mean MDPDecomp__2 [iw = wt_final] if zone == `:word `z' of `zone_value''
				local H_M = e(b)[1,1]
				qui mean MDPDecomp__3 [iw = wt_final] if zone == `:word `z' of `zone_value''
				local H_M = `H_M' + e(b)[1,1]

				qui mean MDPStatus [iw = wt_final] if zone == `:word `z' of `zone_value''
				local H = e(b)[1,1]
				local C = [	(1 - `H_M') / `H_M' ]  * [(`H_M' + `H_O' - `H' ) / ( `H' - `H_M' )]
				mat ExtCum[1, 7] = `C'
			
			local k = 1
			foreach dim of local varlist_nomo  { 
				local k = `k' + 1
				local removed `dim'
				local varlist_reduced: list global(varlist) - removed
				
				MDPDecomp 	, varlist(`varlist_reduced') povmod(`povmod')
				MDP  		, varlist(`varlist_reduced') povmod(`povmod')	
				MDPDecomp2	, mdpstatus(MDPStatus) mdpdecomp(MDPDecomp) varlist(`varlist_reduced')
				
				tab MDPDecomp2[iw = wt_final] if zone == `:word `z' of `zone_value'', matcell(freq)
				forval i = 1/`=rowsof(freq)' {
					mat ExtCum[`k', `i'] = 100* freq[`i', 1]/r(N)
				}
				
			* Overlap C
				qui mean MDPDecomp__1 [iw = wt_final] if zone == `:word `z' of `zone_value''
				local H_O = e(b)[1,1]
				qui mean MDPDecomp__3 [iw = wt_final] if zone == `:word `z' of `zone_value''
				local H_O = `H_O' + e(b)[1,1]
				
				qui mean MDPDecomp__2 [iw = wt_final] if zone == `:word `z' of `zone_value''
				local H_M = e(b)[1,1]
				qui mean MDPDecomp__3 [iw = wt_final] if zone == `:word `z' of `zone_value''
				local H_M = `H_M' + e(b)[1,1]

				qui mean MDPStatus [iw = wt_final] if zone == `:word `z' of `zone_value''
				local H = e(b)[1,1]
				local C = [	(1 - `H_M') / `H_M' ]  * [(`H_M' + `H_O' - `H' ) / ( `H' - `H_M' )]
				mat ExtCum[`k', 7] = `C'
				
			}
			
			clear
			svmat ExtCum, names(col)
			
			gen dimension_removed = "All dimensions kept" if _n == 1
			local  k = 1
			foreach dim of local varlist_nomo {
				local k = `k' + 1
				replace dimension_removed = "`dim' removed" if _n == `k'
			}
			
			local need 
			foreach var of varlist Monetary_extr_OMP Monetary_extr_othdim_ext Monetary_extr_othdim_cum Extremor_othdim_poor Cumulator {
				local need1 `var'
				local need: list need1 | need
				egen `var'_plus = rowtotal(`need')
			}
			gen order = _n
			
			
			*| Graph Designing
			twoway ///
				(bar Monetary_extr_OMP_plus order, color(white) lc(black) lp(solid) lw(thin) barwidth(0.65) yaxis(1)) ///
				(rbar Monetary_extr_OMP_plus Monetary_extr_othdim_ext_plus order, color(ebblue) barwidth(0.65) yaxis(1)) ///
				(rbar Monetary_extr_othdim_ext_plus Monetary_extr_othdim_cum_plus order, color(dkorange) barwidth(0.65) yaxis(1)) ///
				(line Monetary_extr_othdim_cum_plus order, lc(red) lp(dash_dot) lw(thin) yaxis(1)) ///
				(rbar Monetary_extr_othdim_cum_plus Extremor_othdim_poor_plus order, color(dkgreen) barwidth(0.65) yaxis(1)) ///
				(rbar Extremor_othdim_poor_plus Cumulator_plus order, color(cranberry) barwidth(0.65) yaxis(1)) ///
				(scatter Overlap_C order, color(black) msize(large) mlabel(Overlap_C) mlabformat(%9.1f) yaxis(2)) ///
				, ///
				legend(order(7 "Overlap" ///
							 6 "OD cumulator" ///
							 5 "OD extremor" ///
							 4 "Monet. extr. All" ///
							 3 "Monet. extr. & OD cum." ///
							 2 "Monet. extr. & OD extr." ///
							 1 "Monet. extr. O") ///
					   c(1) pos(3) ///
					   symxsize(medsmall) symysize(medsmall) size(vsmall)) ///
				xtitle(, size(zero)) ///
				xlabel(	1 "`=dimension_removed[1]'" 2 "`=dimension_removed[2]'" 3 "`=dimension_removed[3]'" 4 "`=dimension_removed[4]'" ///
						5 "`=dimension_removed[5]'", labsize(vsmall) angle(vertical) labgap(small) noticks) ///
				ytitle("Headcount(%)", axis(1)) ///
				ytitle("Overlap", axis(2)) ///
				ylabel(0(1)3, axis(2)) ///
				title("{fontface Arial Bold : `zone_name' }", size(medsmall)) ///
				graphregion(color(white)) bgcolor(white) ///
				name(g`z', replace) 
				
			local need g`z'
			local gname: list gname | need
		}	
		
		graph combine `gname', col(2) xsize(8) ysize(5) iscale(*0.9) ///
		graphregion(color(white)) ///
		title("{fontface Arial Bold : Impact of non monetary dimensions on multi-dimensional poverty headcount}", size(medsmall))
		graph export "$output/Graphics/R5_b.png", as(png) height(1000) name("Graph") replace
	}
   
   
   **** 5) Venn diagram: Muldimensionnal poverty decomposition
  *--------------------------------------------------------------------------* 
	 
	if "$varlist" != "Monetary1" {
		
		use "$projectfolder/Output/Data/main.dta", clear

		*| Data Preparation
	// 	local varlist Monetary1 Education1 Health1 Housing5 Security1 	
	// 	local povmod 2
		
		MDPDecomp 	, varlist($varlist) povmod(`povmod')
		MDP  		, varlist($varlist) povmod(`povmod')	
		MDPDecomp2	, mdpstatus(MDPStatus) mdpdecomp(MDPDecomp)  varlist($varlist)
		
		gen 	Monetary_poor = inlist(MDPDecomp, 2,3) if !missing(MDPDecomp)
		replace Monetary_poor = 0 if MDPStatus == 0 // Non poor 
		
		gen 	Otherdim_poor = inlist(MDPDecomp, 1,3) if !missing(MDPDecomp)
		replace Otherdim_poor = 0 if MDPStatus == 0 // Non poor 
		
		gen 	Otherdim_poor_ext = Otherdim_poor == 1 & inlist(MDPDecomp2, 2,3,4) if !missing(Otherdim_poor) | !missing(MDPDecomp2)
		gen 	Otherdim_poor_cum = Otherdim_poor == 1 & inlist(MDPDecomp2, 5) if !missing(Otherdim_poor) | !missing(MDPDecomp2)
		
		gen 	extr			  = 0 // complementary to cumulators and non poors
		replace extr              = 1 if `= "`: word 1 of $varlist'" + "Ext"' == 1
		
		local keep 
		
		foreach dim of global varlist {
			if "`=substr("`dim'",1,3)'" != "Hea" & "`=substr("`dim'",1,3)'" != "Hou" & "`=substr("`dim'",1,3)'" != "Sec" continue
			
			gen 		Pov_`dim' = 1 if `= "`dim'" + "Ext"' == 1
			cap replace Pov_`dim' = 1 if `= "`dim'" + "Mod"' == 1
			cap replace Pov_`dim' = 0 if `= "`dim'" + "Ext"' == 0 & `= "`dim'" + "Mod"' == 0
			
			replace  	extr			  = 1 if `= "`dim'" + "Ext"' == 1 
			
			local 		need "`= "`dim'" + "Ext"' `= "`dim'" + "Mod"'"
			local  		keep: list keep | need
		}

		keep 	Otherdim_poor Otherdim_poor_ext Otherdim_poor_cum Monetary_poor Pov_Health Pov_Housing Pov_Security wt_final extr `keep'
		keep if !missing(wt_final)
		export delimited using "$output/Data/4Venn_in_R.csv", nolabel replace  
		
		
		*| Graph designing
		cap erase 	"$projectfolder/Output/Data/4Venn_in_R_current.csv"
		copy 		"$output/Data/4Venn_in_R.csv" "$projectfolder/Output/Data/4Venn_in_R_current.csv", replace	
		
		local 		projectfolder "$projectfolder"
		cap file 	close fh
		file 		open fh using "C:/Users/`c(username)'/Documents/RPaths.mk", write replace

		file write fh "setPath = " _char(34) %15s ("`projectfolder'") "/Output/Data" _char(34) _n
		file write fh "outPath = "  _char(34) %15s ("`projectfolder'") "/Output" _char(34) _n
		file close fh
		
		rsource using "$programs/VennDiagrams.R", lsource roptions(`"--vanilla"')
		
		copy 		"$projectfolder/Output/VD1_R.png" 		"$output/Graphics/VD1_R.png", replace	
		copy 		"$projectfolder/Output/VD2_R.png" 		"$output/Graphics/VD2_R.png", replace	
		copy 		"$projectfolder/Output/VD2_R_bis.png" 	"$output/Graphics/VD2_R_bis.png", replace
		
		cap erase 	"$projectfolder/Output/VD1_R.png" 
		cap erase 	"$projectfolder/Output/VD2_R.png"
		cap erase 	"$projectfolder/Output/VD2_R_bis.png"
		cap erase 	"C:/Users/`c(username)'/Documents/RPaths.mk"
	}
	
	
   **** 6)	Poverty indicators summary  
  *----------------------------------------------------------------------*  

   *| Preparing data
	use "$projectfolder/Output/Data/main.dta", clear
	
	tempfile addIndicators
 
	local i = 0
	foreach lev in national state zone {
    preserve
	    local level = substr("`lev'",1,3)
		local i = `i' + 1
		
		tempfile label
		elabel save (`lev') using `label'.do, replace
		elabel list (`lev')
		local label_name `r(name)' 
		
		* LE
		tabstat LEB_all, stat(mean) by(`lev') save 
		tabstatmat LE
		mat LE = LE[1..`=rowsof(LE)-1',1]

		* DAYSOUT
		tabstat daysout, stat(mean) by(`lev') save 
		tabstatmat daysout
		mat daysout = daysout/30
		mat daysout = daysout[1..`=rowsof(daysout)-1',1]
		
		mat addIndicators = LE, daysout
		mat colnames addIndicators = LE DAYSOUT
		
		clear
		svmat addIndicators, names(col)
		
		gen level = `i'
		
		gen level_namee = _n
		do `label'.do
		lab val level_namee `label_name'
		decode level_namee, gen(level_name)
		drop level_namee
		
		if `i' == 1 save `addIndicators', replace
		else {
		    append using `addIndicators'
			save `addIndicators', replace
		}
		
	restore
	}

	use `addIndicators', clear
	merge 1:1 level_name using "$output/Data/LevelsIndicators", nogen 
	
	gen LE_X_cDAYSOUT = LE * (1 - DAYSOUT)
	gen MPALE = LE * (1 - DAYSOUT) * (1 - monetaryHC)
	save "$output/Data/LevelsIndicators", replace	
	
	
	*| Graph 1 Designing
	keep if level ==2
	sort monetaryHC
	gen n_state = _n
	
	if "$varlist" != "Monetary1" {
		twoway ///
			(scatter LE 			n_state , mcolor(dkgreen) m(T)) ///
			(scatter LE_X_cDAYSOUT 	n_state , mcolor(`col_daysoutR6') m(O)) ///
			(scatter MPALE 			n_state , mcolor(ebblue) m(D) ) ///
			(scatter NMPALE 		n_state , mcolor(dkorange) m(T) ) ///
			(scatter PALE 			n_state , mcolor(black) m(D) ) ///
		  ,  ///
			legend(`leg_daysoutR6')        ///
			xlabel(0(40)40)         ///
			xtitle("State by ordered monetary poverty", axis(1)) ///
			ylabel(0(20)60) ///
			ytitle("Years" ) ///
			graphregion(color(white)) bgcolor(white) 
		graph export "$output/Graphics/R6.png", as(png) name("Graph") replace
	}
	else {
		twoway ///
			(scatter LE 			n_state , mcolor(dkgreen) m(T)) ///
			(scatter PALE 			n_state , mcolor(black) m(D) ) ///
		  ,  ///
			legend(`leg_daysoutR6')        ///
			xlabel(0(40)40)         ///
			xtitle("State by ordered monetary poverty", axis(1)) ///
			ylabel(0(20)60) ///
			ytitle("Years" ) ///
			graphregion(color(white)) bgcolor(white) 
		graph export "$output/Graphics/R6.png", as(png) name("Graph") replace
	}	
	
	*| Graph 2 Designing
	gen MDPHC = (OMPHC_X_LE + BHC_X_LE + ONMPHC_X_LE)/LE
	
	tabstat 	LE PALE MDPHC, stat(cv) save
	tabstatmat  cv

	twoway ///
        (scatter LE MDPHC , mcolor(dkgreen) m(T)) ///
        (scatter PALE MDPHC , mcolor(black) m(D) ) ///
      ,  ///
		legend(`leg_daysoutR6b')        ///
        xtitle("Multidimensional poverty headcount", axis(1)) ///
        ylabel(0(20)60) ///
        ytitle("Years" ) ///
        graphregion(color(white)) bgcolor(white) ///
		note("Variances across states (% of mean):" ///
			"Life expectancy `=round(100*cv[1,1],1)'" ///
			"PALE `=round(100*cv[1,2],0.1)'" ///
			"Multidimendionnal poverty headcount `=round(100*cv[1,3],0.1)'" )
	graph export "$output/Graphics/R6b.png", as(png) name("Graph") replace
	
	