   * ******************************************************************** *
   *                                                                      *
   *          IMPROVED MULTIDIMENSIONNAL POVERTY MEASUREMENT IN NIGERIA   *
   *                		FINAL DATA ANALYSIS -  TABLES                 *
   *                                                                      *
   * ******************************************************************** *
   * ******************************************************************** *

       /*
       ** PURPOSE:      COMPUTE FINAL OUTPUTS - TABLES

       ** OUTLINE:      
       */
	   
	global output 	"$projectfolder/Output"
	
// 	include 		"$programs/1_1_DataConstruction_DHS_NLSS.do"
// 	include 		"$programs/1_2_DataConstruction_Thresolds.do"
// 	include 		"$programs/2_1_DataAnalysis_Preliminary.do"
	
  
  **** Table: Impact of dimensions on poverty headcounts 
  *----------------------------------------------------------------------* 
	putexcel set "$output/Tables/Tables.xlsx", sheet("DimRemoved") modify

	// Baseline
  
	use "$output/Data/main.dta", clear
	
	global 	varlist Monetary1 Health2 Housing5 Security2
	local 	povmod 2
	
	local monetary Monetary1 Monetary2
	local varlist_nomo: list global(varlist) - monetary
			
	mat mymat = J(`:word count $varlist', 3, .)
	mat colnames mymat  = ODHC OD_add OD_tw 
	
	MDPDecomp 	, varlist($varlist) povmod(`povmod')
	MDP  		, varlist($varlist) povmod(`povmod')	
	
	tab MDPDecomp[iw = wt_final] , m matcell(freq) 
	mat mymat[1, 1] = 100* (freq[1, 1] + freq[3, 1] )/r(N)
	mat mymat[1, 2] = 100* freq[1, 1]/r(N)
	mat mymat[1, 3] = 100* freq[3, 1]/r(N)
			
	local k = 1
	foreach dim of local varlist_nomo  { 
		local k = `k' + 1
		local removed `dim'
		local varlist_reduced: list global(varlist) - removed
		
		MDPDecomp 	, varlist(`varlist_reduced') povmod(`povmod')
		MDP  		, varlist(`varlist_reduced') povmod(`povmod')	
		
		tab MDPDecomp[iw = wt_final] , m matcell(freq) 
		mat mymat[`k', 1] = 100* (freq[1, 1] + freq[3, 1] )/r(N)
		mat mymat[`k', 2] = 100* freq[1, 1]/r(N)
		mat mymat[`k', 3] = 100* freq[3, 1]/r(N)

	}
	
	putexcel C6 = mat(mymat)
	
  // Prefered
  
	use "$output/Data/main.dta", clear
	
	global 	varlist Monetary2 Education3 Health2 Housing5 Security2
	local 	povmod 2
	
	local monetary Monetary1 Monetary2
	local varlist_nomo: list global(varlist) - monetary
			
	mat mymat = J(`:word count $varlist', 3, .)
	mat colnames mymat  = ODHC OD_add OD_tw 
	
	MDPDecomp 	, varlist($varlist) povmod(`povmod')
	MDP  		, varlist($varlist) povmod(`povmod')	
	
	tab MDPDecomp[iw = wt_final] , m matcell(freq) 
	mat mymat[1, 1] = 100* (freq[1, 1] + freq[3, 1] )/r(N)
	mat mymat[1, 2] = 100* freq[1, 1]/r(N)
	mat mymat[1, 3] = 100* freq[3, 1]/r(N)
			
	local k = 1
	foreach dim of local varlist_nomo  { 
		local k = `k' + 1
		local removed `dim'
		local varlist_reduced: list global(varlist) - removed
		
		MDPDecomp 	, varlist(`varlist_reduced') povmod(`povmod')
		MDP  		, varlist(`varlist_reduced') povmod(`povmod')	
		
		tab MDPDecomp[iw = wt_final] , m matcell(freq) 
		mat mymat[`k', 1] = 100* (freq[1, 1] + freq[3, 1] )/r(N)
		mat mymat[`k', 2] = 100* freq[1, 1]/r(N)
		mat mymat[`k', 3] = 100* freq[3, 1]/r(N)

	}
	
	putexcel C15 = mat(mymat)	
	
	
	
  **** Table: Extreme deprivations impact on results
  *----------------------------------------------------------------------* 
	putexcel set "$output/Tables/Tables.xlsx", sheet("ExtremeDepImpct") modify
  
	// Baseline
	use 	"$output/Data/main.dta", clear
	replace daysout = 0
	
	global 	varlist Monetary1 Health2 Housing5 Security2  
	local  	povmod 2
	local 	theta 1
	local	ahat 50
	
	local 	monetary Monetary1 Monetary2
	local 	varlist_nomo: list global(varlist) - monetary	
		
	foreach dim of local varlist_nomo  {
		replace 	`dim'Mod = 1 if `dim'Ext == 1
		replace 	`dim'Ext = 0 if `dim'Ext == 1
	}
	
	tempfile 	tmp
	save 		`tmp'

	local i = 0
	foreach lev in national state zone {
    preserve
	    local level = substr("`lev'",1,3)
		local i 	= `i' + 1
		
		tempfile 	label
		elabel save (`lev') using `label'.do, replace
		elabel list (`lev')
		local 		label_name `r(name)' 
		
		MDPDecomp 	, varlist($varlist) povmod(`povmod')	
		MDP 		, varlist($varlist) povmod(`povmod')
		WBL			, mdps(MDPStatus) mdpd(MDPDecomp) level(`level') ahat(`ahat') theta(`theta')

		mat WBL = r(WBL)
		
		clear
		svmat 	WBL, names(col)
		
		gen 	level = `i'
		
		gen 	level_namee = _n
		do 		`label'.do
		lab val level_namee `label_name'
		decode 	level_namee, gen(level_name)
		drop 	level_namee
		
		if `i' == 1 save 	`tmp', replace
		else {
					append 	using `tmp'
					save 	`tmp', replace
		}
		
	restore
	}
	
	use `tmp', clear
	foreach var of varlist WBL LGE DAYSOUT_X_LE ONMPHC_X_LE OMPHC_X_LE BHC_X_LE ONMPHC OMPHC BHC {
		ren `var' `var'_ModOnly
	}	
	merge 1:1 level_name using "$output/Scenarii/Baseline/Data/LevelsIndicators.dta", nogen
  
  
	cap drop ODHC* OD_add* OD_tw*
	
	gen 	ODHC 				= (BHC + ONMPHC)
	gen 	OD_add 				= ONMPHC
	gen 	OD_tw				= BHC
	
	gen 	ODHC_ModOnly 		= (BHC_ModOnly + ONMPHC_ModOnly)
	gen 	OD_add_ModOnly		= ONMPHC_ModOnly
	gen 	OD_tw_ModOnly		= BHC_ModOnly
	
	save 	"$output/Scenarii/Baseline/Data/LevelsIndicators.dta", replace
	
	tabstat 	ODHC OD_add OD_tw if level == 1, stat(mean) save
	tabstatmat 	res1
	
	tabstat 	ODHC_ModOnly OD_add_ModOnly OD_tw_ModOnly if level == 1, stat(mean) save
	tabstatmat 	res2
	
	putexcel C6 = mat(100*res1) C7 = mat(100*res2)
  
  
	// Prefered
	use 	"$output/Data/main.dta", clear
	replace daysout = 0
	
	global 	varlist Monetary2 Education3 Health2 Housing5 Security2 
	local  	povmod 2
	local 	theta 0.5
	local	ahat 65
	
	local 	monetary Monetary1 Monetary2
	local 	varlist_nomo: list global(varlist) - monetary	
		
	foreach dim of local varlist_nomo  {
		replace 	`dim'Mod = 1 if `dim'Ext == 1
		replace 	`dim'Ext = 0 if `dim'Ext == 1
	}
	
	tempfile 	tmp
	save 		`tmp'

	local i = 0
	foreach lev in national state zone {
    preserve
	    local level = substr("`lev'",1,3)
		local i 	= `i' + 1
		
		tempfile 	label
		elabel save (`lev') using `label'.do, replace
		elabel list (`lev')
		local 		label_name `r(name)' 
		
		MDPDecomp 	, varlist($varlist) povmod(`povmod')	
		MDP 		, varlist($varlist) povmod(`povmod')
		WBL			, mdps(MDPStatus) mdpd(MDPDecomp) level(`level') ahat(`ahat') theta(`theta')

		mat WBL = r(WBL)
		
		clear
		svmat 	WBL, names(col)
		
		gen 	level = `i'
		
		gen 	level_namee = _n
		do 		`label'.do
		lab val level_namee `label_name'
		decode 	level_namee, gen(level_name)
		drop 	level_namee
		
		if `i' == 1 save 	`tmp', replace
		else {
					append 	using `tmp'
					save 	`tmp', replace
		}
		
	restore
	}
	
	use `tmp', clear
	foreach var of varlist WBL LGE DAYSOUT_X_LE ONMPHC_X_LE OMPHC_X_LE BHC_X_LE ONMPHC OMPHC BHC {
		ren `var' `var'_ModOnly
	}	
	merge 1:1 level_name using "$output/Scenarii/Prefered4/Data/LevelsIndicators.dta", nogen
  
	cap drop ODHC* OD_add* OD_tw*

	gen 	ODHC 				= (BHC + ONMPHC)
	gen 	OD_add 				= ONMPHC
	gen 	OD_tw				= BHC
	
	gen 	ODHC_ModOnly 		= (BHC_ModOnly + ONMPHC_ModOnly)
	gen 	OD_add_ModOnly		= ONMPHC_ModOnly
	gen 	OD_tw_ModOnly		= BHC_ModOnly
	
	save 	"$output/Scenarii/Prefered4/Data/LevelsIndicators.dta", replace
	
	tabstat 	ODHC OD_add OD_tw if level == 1, stat(mean) save
	tabstatmat 	res1
	
	tabstat 	ODHC_ModOnly OD_add_ModOnly OD_tw_ModOnly if level == 1, stat(mean) save
	tabstatmat 	res2
	
	putexcel C13 = mat(100*res1) C14 = mat(100*res2)
	
	
	
	
  **** Table: Different types of poor per zone 
  *----------------------------------------------------------------------* 
	putexcel set "$output/Tables/Tables.xlsx", sheet("TypePoor") modify

	// Baseline
	use 	"$output/Scenarii/Baseline/Data/LevelsIndicators.dta", clear
	
	cap drop 	MDPHC 
	gen 		MDPHC 		= (OMPHC + BHC + ONMPHC)
	
	save 	"$output/Scenarii/Baseline/Data/LevelsIndicators.dta", replace
	
	tabstat 	MDPHC monetaryHC ODHC OD_add OD_tw Overlap_C LE if level == 1, stat(mean) save
	tabstatmat 	res
	mat 		res = res'
	
	foreach z in "6. South West" "5. South South" "4. South East" ///
					"1. North Central" "3. North West" "2. North East" {
							tabstat 	MDPHC monetaryHC ODHC OD_add OD_tw Overlap_C LE if level_name == "`z'", stat(mean) save
							tabstatmat 	need
							mat 		need = need'
							mat 		res = res, need
					}
					
	tabstat 	MDPHC monetaryHC ODHC OD_add OD_tw Overlap_C LE if level == 2, stat(cv) save
	tabstatmat 	need
	mat 		need = need'
	mat 		res = res, need
	
	putexcel C6 = mat(res)

  
	// Prefered
	use 	"$output/Scenarii/Prefered4/Data/LevelsIndicators.dta", clear
	
	cap drop 	MDPHC 
	gen 		MDPHC 		= (OMPHC + BHC + ONMPHC)
	
	save 	"$output/Scenarii/Prefered4/Data/LevelsIndicators.dta", replace
	
	tabstat 	MDPHC monetaryHC ODHC OD_add OD_tw Overlap_C LE if level == 1, stat(mean) save
	tabstatmat 	res
	mat 		res = res'
	
	foreach z in "6. South West" "5. South South" "4. South East" ///
					"1. North Central" "3. North West" "2. North East" {
							tabstat 	MDPHC monetaryHC ODHC OD_add OD_tw Overlap_C LE if level_name == "`z'", stat(mean) save
							tabstatmat 	need
							mat 		need = need'
							mat 		res = res, need
					}
					
	tabstat 	MDPHC monetaryHC ODHC OD_add OD_tw Overlap_C LE if level == 2, stat(cv) save
	tabstatmat 	need
	mat 		need = need'
	mat 		res = res, need
	
	putexcel C18 = mat(res)	
	
	
  **** Table: Different types of poor per state 
  *----------------------------------------------------------------------* 
	putexcel set "$output/Tables/Tables.xlsx", sheet("TypePoor2") modify

	// Baseline
	use 	"$output/Scenarii/Baseline/Data/LevelsIndicators.dta", clear
	
	cap drop 	MDPHC 
	gen 		MDPHC 		= (OMPHC + BHC + ONMPHC)
	
	save 	"$output/Scenarii/Baseline/Data/LevelsIndicators.dta", replace
	
	tabstat 	MDPHC monetaryHC ODHC OD_add OD_tw Overlap_C LE if level == 1, stat(mean) save
	tabstatmat 	res
	mat 		res = res'
	mat 		colnames res = National
	
	preserve
		keep if level == 2
		sort	monetaryHC
		forval i = 1/`=c(N)' {
								tabstat 	MDPHC monetaryHC ODHC OD_add OD_tw Overlap_C LE if level_name == level_name[`i'], stat(mean) save
								tabstatmat 	need
								mat 		need = need'
								
								local 		name = subinstr(subinstr(level_name[`i'], " ", "",.), ".", "",.)
								forval n = 0/9 {
											local name = subinstr("`name'", "`n'", "",.)
								}

								mat 		colnames need = `name'
								mat 		res = res, need
						}
	restore
										
	tabstat 	MDPHC monetaryHC ODHC OD_add OD_tw Overlap_C LE if level == 2, stat(cv) save
	tabstatmat 	need
	mat 		need = need'
	mat 		res = res, need
	
	putexcel C5 = mat(res), colnames

  
	// Prefered
	use 	"$output/Scenarii/Prefered4/Data/LevelsIndicators.dta", clear
	
	cap drop 	MDPHC 
	gen 		MDPHC 		= (OMPHC + BHC + ONMPHC)
	
	save 	"$output/Scenarii/Prefered4/Data/LevelsIndicators.dta", replace
	
	tabstat 	MDPHC monetaryHC ODHC OD_add OD_tw Overlap_C LE if level == 1, stat(mean) save
	tabstatmat 	res
	mat 		res = res'
	mat 		colnames res = National
	
	preserve
		keep if level == 2
		sort	monetaryHC
		forval i = 1/`=c(N)' {
								tabstat 	MDPHC monetaryHC ODHC OD_add OD_tw Overlap_C LE if level_name == level_name[`i'], stat(mean) save
								tabstatmat 	need
								mat 		need = need'
								
								local 		name = subinstr(subinstr(level_name[`i'], " ", "",.), ".", "",.)
								forval n = 0/9 {
											local name = subinstr("`name'", "`n'", "",.)
								}

								mat 		colnames need = `name'
								mat 		res = res, need
						}
	restore
					
	tabstat 	MDPHC monetaryHC ODHC OD_add OD_tw Overlap_C LE if level == 2, stat(cv) save
	tabstatmat 	need
	mat 		need = need'
	mat 		res = res, need
	
	putexcel C17 = mat(res)	, colnames
	
	
	
  **** Table: Quantifying re-rankings between all pairwise state comparisons 
  *----------------------------------------------------------------------* 
  
  *| User - defined re-rankings function
  
	cap prog drop ReRank
	prog define ReRank, rclass
		
		syntax ,IND (varlist numeric min=2 max=2) ///
				SPLIT(integer) // 1 all - 2 <50 - 3 >50
	
		if `split' == 1 local c "1,2"
		if `split' == 2 local c "1"
		if `split' == 3 local c "2"
		
		qui: correlate `:word 1 of `ind'' `:word 2 of `ind'' if inlist(split, `c')
		if r(C)[1,2] < 0 	local sign ">"
		else 				local sign "<"

		qui: levelsof level_name if level == 2 & inlist(split, `c'), local(states)
		local nb_states :word count `states'

		local count  = 0
		forval i = 1/`=`nb_states'-1' {
			forval n = 1/`= c(N)' {
				if level_name[`n'] == "`:word `i' of `states''" {
					local k = `n'
					continue, break
				}
			}
			
			forval j = `=`i'+1'/`nb_states' {
				forval n = 1/`= c(N)' {
					if level_name[`n'] == "`:word `j' of `states''" {
						local l = `n'
						continue, break
					}
				}
				
				
				if (`:word 1 of `ind''[`k'] - `:word 1 of `ind''[`l']) * (`:word 2 of `ind''[`k'] - `:word 2 of `ind''[`l']) `sign' 0   {
					local count = `count' + 1
				}
			}
		}

		local 	count = round(100 * `count' / (0.5 * `nb_states' * (`nb_states' -1)), 1)
		di 		`count'
		
		return local rerank = `count'
  end
  
  
  *| Table construction
	putexcel set "$output/Tables/Tables.xlsx", sheet("Rerankings") modify

	// Baseline
	use 	"$output/Scenarii/Baseline/Data/LevelsIndicators.dta", clear
	
	gen 	split = 1 if monetaryHC < 0.5
	replace split = 2 if monetaryHC >= 0.5
	
	mat 	res = J(10, 3, 0)
	local 	j = 0
	
	foreach s in 1 2 3 {
		local j = `j' + 1
		local i = 0
		foreach ind in "AverageConso_anpc monetaryHC" "AverageConso_anpc MDPHC" "AverageConso_anpc MPALE" ///
						"AverageConso_anpc PALE" "monetaryHC MDPHC" "monetaryHC MPALE" "monetaryHC PALE" ///
						"MPALE PALE" "MDPHC PALE" "ODHC ODHC_ModOnly" {
							local 	i = `i' + 1
							ReRank, ind(`ind') split(`s')
							mat 	res[`i', `j'] = `r(rerank)'
						}
	}
	putexcel C5 = mat(res)

	// Prefered
	use 		"$output/Scenarii/Prefered4/Data/LevelsIndicators.dta", clear	

	gen 	split = 1 if monetaryHC < 0.5
	replace split = 2 if monetaryHC >= 0.5
	
	mat 	res = J(10, 3, 0)
	local 	j = 0
	
	foreach s in 1 2 3 {
		local j = `j' + 1
		local i = 0
		foreach ind in "AverageConso_anpc monetaryHC" "AverageConso_anpc MDPHC" "AverageConso_anpc MPALE" ///
						"AverageConso_anpc PALE" "monetaryHC MDPHC" "monetaryHC MPALE" "monetaryHC PALE" ///
						"MPALE PALE" "MDPHC PALE" "ODHC ODHC_ModOnly"  {
							local 	i = `i' + 1
							ReRank, ind(`ind') split(`s')
							mat 	res[`i', `j'] = `r(rerank)'
						}
	}
	putexcel F5 = mat(res)	
	
	
	
  **** Table: Quantifying policy implications for transfers 
  *----------------------------------------------------------------------* 

  *| User - defined average distrubution impact function
  
	cap prog drop AvgRedImp
	prog define AvgRedImp, rclass
		
		syntax ,IND (varlist numeric min=2 max=2) ///
				[THETA1 (real 1)  ///
				THETA2 (real 1)  ///
				PALE1 ///
				PALE2]
		
		forval j = 1/2 {
			tempvar LE`j'
			if "`pale`j''" == "" 	gen `LE`j'' = 1
			else 					gen `LE`j'' = LE
			
			local sumTerms`j' 	= 0
			mat Terms`j'    	= J(1,`=c(N)', 0)
			
			forval i = 1/`=c(N)' {
				mat Terms`j'[1,`i'] = Population[`i'] * `LE`j''[`i'] * (1 - `theta`j'' * `:word `j' of `ind''[`i'])
				local sumTerms`j' 	= `sumTerms`j'' + Terms`j'[1, `i']
			}
		}
			
		local out = 0
		
		forval i = 1/`=c(N)' {
			local out = `out' + abs(Terms1[1,`i'] / `sumTerms1' - Terms2[1,`i'] / `sumTerms2') 
		}
		local out = `out'/ `=c(N)' 
		
		return local AvgRedImp = `out'
	end
	
	
  *| Data Preparation
  
	use "$output/Data/LGE_ByState.dta", clear
  
  * Recoding state to match NLSS data
  
  	replace _ID = 38 if _ID == 15
	forval i = 16/37 {
		replace _ID = `i'-1 if _ID == `i'
	}
  	replace _ID = 37 if _ID == 38
	
	ren 	_ID state
	
	tempfile 	tmp
	save 		`tmp'
	
  	
  *| Table construction
	putexcel set "$output/Tables/Tables.xlsx", sheet("PolicyImplications") modify

	// Baseline
	local 		theta = 1
	
	use 		"$output/Scenarii/Baseline/Data/LevelsIndicators.dta", clear

	keep if 	level == 2
	gen 		state = real(substr(level_name, 1, strpos(level_name, ".") -1))
	merge 		1:1 state using `tmp', nogen	
			
	AvgRedImp, 	ind(monetaryHC MDPHC) theta1(`theta') theta2(`theta') 
	mat out 	= `r(AvgRedImp)'
	
	AvgRedImp, 	ind(monetaryHC monetaryHC) theta1(`theta') theta2(`theta') pale2
	mat out 	= out, `r(AvgRedImp)'
  
	AvgRedImp, 	ind(monetaryHC MDPHC) theta1(`theta') theta2(`theta') pale2
	mat out 	= out, `r(AvgRedImp)'
  
	AvgRedImp, 	ind(MDPHC MDPHC) theta1(`theta') theta2(`theta') pale2
	mat out 	= out, `r(AvgRedImp)'  
  
	AvgRedImp, 	ind(monetaryHC MDPHC) theta1(`theta') theta2(`theta') pale1 pale2
	mat out 	= out, `r(AvgRedImp)'
	
	AvgRedImp, 	ind(ODHC ODHC_ModOnly) theta1(`theta') theta2(`theta') 
	mat out 	= out, `r(AvgRedImp)'
	
	putexcel C4 = mat(out')
  
  
	// Prefered  - all get theta
	local 		theta = 0.5
	
	use 		"$output/Scenarii/Prefered4/Data/LevelsIndicators.dta", clear

	keep if 	level == 2
	gen 		state = real(substr(level_name, 1, strpos(level_name, ".") -1))
	merge 		1:1 state using `tmp', nogen	
			
	AvgRedImp, 	ind(monetaryHC MDPHC) theta1(`theta') theta2(`theta') 
	mat out 	= `r(AvgRedImp)'
	
	AvgRedImp, 	ind(monetaryHC monetaryHC) theta1(`theta') theta2(`theta') pale2
	mat out 	= out, `r(AvgRedImp)'
  
	AvgRedImp, 	ind(monetaryHC MDPHC) theta1(`theta') theta2(`theta') pale2
	mat out 	= out, `r(AvgRedImp)'
  
	AvgRedImp, 	ind(MDPHC MDPHC) theta1(`theta') theta2(`theta') pale2
	mat out 	= out, `r(AvgRedImp)'  
  
	AvgRedImp, 	ind(monetaryHC MDPHC) theta1(`theta') theta2(`theta') pale1 pale2
	mat out 	= out, `r(AvgRedImp)'
	
	AvgRedImp, 	ind(ODHC ODHC_ModOnly) theta1(`theta') theta2(`theta') 
	mat out 	= out, `r(AvgRedImp)'
	
	putexcel D4 = mat(out')
  
  
	// Prefered - only PALE get theta
	AvgRedImp, 	ind(monetaryHC MDPHC) // default theta value = 1
	mat out 	= `r(AvgRedImp)'
	
	AvgRedImp, 	ind(monetaryHC monetaryHC) theta2(`theta') pale2
	mat out 	= out, `r(AvgRedImp)'
  
	AvgRedImp, 	ind(monetaryHC MDPHC) theta2(`theta') pale2
	mat out 	= out, `r(AvgRedImp)'
  
	AvgRedImp, 	ind(MDPHC MDPHC) theta2(`theta') pale2
	mat out 	= out, `r(AvgRedImp)'  
  
	AvgRedImp, 	ind(monetaryHC MDPHC) theta1(`theta') theta2(`theta') pale1 pale2
	mat out 	= out, `r(AvgRedImp)'
	
	AvgRedImp, 	ind(ODHC ODHC_ModOnly) // default theta value = 1
	mat out 	= out, `r(AvgRedImp)'
  
	putexcel E4 = mat(out')	
	
	