program define vdiagram

    version 9.2

	syntax varlist(min=3 max=3) [in] [aweight fweight iweight] ///
		[, c1(integer 1) c2(integer 1) c3(integer 1) a4(integer 1) ca(int 1) ///
		Missing condition(string) condition_user(string) *]


	if `"`condition_user'"'!="" {
		// remove "if " from the beginning of the condition string
		local condition_user = substr(`"`condition_user'"',4, length(`"`condition_user'"')-3)
		local if `"if `condition' & (`condition_user')"'
	}
	
	if "`weight'" != "" {
		local wgt "[`weight'`exp']"
	}

	if "`varlist'"!="`: list uniq varlist'" {
		display as error "Variables must be different"
		exit 198
	}

	if `ca' != 1 {
		local c1 = `ca'
		local c2 = `ca'
		local c3 = `ca'
		local c4 = `ca'
	}

	local i = 1
	foreach var of local varlist {
		if strpos("`: type `var''", "str") {
			display as error "Variables must be numeric"
			exit 198
		}
		local `=char(64+`i')'1 "(`var' == `c`i'')" // A1 B1 C1 D1
		local `=char(64+`i')'0 "(`var' != `c`i'')" // A0 B0 C0 D0
		local cs "`cs' `=char(64+`i')'"
		local ++i
	}
	local varno: word count `varlist'

	if `varno' == 2 local clist "A B AB --"
	if `varno' == 3 local clist "A B C AB AC BC ABC ---"
	if `varno' == 4 local clist "A B C D AB AC AD BC BD CD ABC ABD ACD BCD ABCD ----"

	if ~missing("`missing'") marksample touse, novarlist
	else marksample touse
	tempvar id
	generate `id' = _n
	tempname TMP total

	display as text _dup(70) "_" _newline
	display in yellow "Venn diagram of variables: " in green "`varlist'" _n

    local i=1
	scalar `total' = 0
	foreach c of local clist {
		foreach l of local cs {
			if (!missing(`"`cnd'"')) local cnd "`cnd' & ``l'`=strpos("`c'", "`l'") > 0''"
                  else local cnd "``l'`=strpos("`c'", "`l'") > 0''"              
		}
		summarize `id' `wgt' if `touse' & `cnd', meanonly
		local cnd`i' "`cnd'"
	      local i=`i'+1

		local cnd
		matrix `TMP' = nullmat(`TMP')  \ (r(sum_w), r(sum_w))
		scalar `total' = `total' + r(sum_w)
	}
	matrix `TMP'[1, 2] = `TMP'[...., 2] / `total' * 100
	matrix rownames `TMP' = `clist'

	display as text "Group" _col(13) "Freq." _col(20) "Percent" _col(30) "Group definition"
	forvalues i=1/8 {
		local valuelist "`valuelist' `=string(`TMP'[`i', 2], "%6.1f")'%"

            display as text `"`:word `i' of `:rownames(`TMP')''"' _col(10) as result %8.0f `TMP'[`i', 1] _col(20) as result %6.1f `TMP'[`i', 2] "%" _col(30) "`cnd`i''"
	}
	foreach var of local varlist {
		local lbl : variable label `var'
		// mata : mata_Translate("lbl", `"`lbl'"')
		if missing(`"`lbl'"') local lbl `"`var'"'
		local varlabs `"`varlabs' "`lbl'""'
	}

	Venndetta, values(`valuelist') scale(.7) varlabs(`"`varlabs'"') `options'

	capture macro drop VENN_I_NAME
	capture macro drop VENN_X_NAME
	capture macro drop VENN_Y_NAME
	capture macro drop VENN_delta
end

# delimit ;

program define FollowCurve, rclass;

          version 9.2;

	  syntax anything, from_point(string) to_point(string) storing(real) [clockwise] [cclockwise] id(real) [last];

	  local CurveID = `anything';

	  local x1=12000; local y1=20000; local r1=6000;   // First circle A  (top left)
	  local x2=20000; local y2=20000; local r2=6000;   // Second circle B (top right)
	  local x3=16000; local y3=12000; local r3=6000;   // Third circle C  (bottom center)

	  local A1=0.841069;  local A2=2.30052;    /* upper intersection point of A and B circles */
	  local B2=3.51901;   local B3=1.83688;    /* upper intersection point of B and C circles */
	  local C1=4.44631;   local C3=2.76417;    /* lower intersection point of A and C circles */
	  local D1=5.44212;   local D2=3.98266;    /* lower intersection point of A and B circles */
	  local E2=4.97847;   local E3=0.377421;   /* lower intersection point of B and C circles */
	  local F1=-0.377421; local F3=1.30472;    /* upper intersection point of A and C circles */

	  local start_angle=0; local end_angle=2*_pi;
	  if `"`from_point'"'!="Z" local start_angle = ``from_point'`CurveID'';
	  if `"`to_point'"'  !="Z" local end_angle   = ``to_point'`CurveID'';
	  if `"`clockwise'"' == "clockwise" local delta = -$VENN_delta;
                                   else local delta =  $VENN_delta;

	  if (`"`cclockwise'"'=="cclockwise") & (`start_angle'>`end_angle') local end_angle = `=`end_angle' + 2*_pi';
      if (`"`clockwise'"' =="clockwise" ) & (`start_angle'<`end_angle') local end_angle = `=`end_angle' - 2*_pi';

	  local i=`storing';
	  forvalues t=`start_angle'(`delta')`end_angle' {;

	    local i=`i'+1;
	    quietly replace $VENN_Y_NAME = `y`CurveID''+sin(`t')*`r`CurveID'' in `i';
	    quietly replace $VENN_X_NAME = `x`CurveID''+cos(`t')*`r`CurveID'' in `i';
	    quietly replace $VENN_I_NAME = `id' in `i';
	  };

	  if `"`last'"'=="last" {;
	    local i=`i'+1;
		quietly replace $VENN_Y_NAME = . in `i';
	    quietly replace $VENN_X_NAME = . in `i';
	    quietly replace $VENN_I_NAME = `id' in `i';
	  };

	  return local last_saved = `i';
	  return local total_saved = `i'-`storing';
end; // program FollowCurve

program define _Venndetta;
        
    version 9.2;

	syntax , values(string) [LColor(string)] [LWidth(string)] [varlabs(string)] 
	  [h(real 128)] [l(real 64)] [patterns(string)] [fills(string)] [*];

	local H=`h'; /*128 color intensity [0;255] */
	local L=`l'; /* 64 */
	local c_bg= "255 255 255";
	
	local gc1   ="`L' `H' `H'"; local gc2  = "`H' `L' `H'"; local gc3  = "`H' `H' `L'";
	local gc4  ="`L' `L' `H'"; local gc5 = "`L' `H' `L'"; local gc6 = "`H' `L' `L'";
	local gc7 ="`L' `L' `L'";
	
	if `"`lcolor'"'=="" local lcolor="black";
	if `"`lwidth'"'=="" local lwidth=0.1;
	if `"`patterns'"'=="" local patterns "5 8 4 9 6 3 1";
	
	forval i=1/7 {;
	  if (`:word `i' of `patterns''!=0) local p`i' "pattern(pattern`:word `i' of `patterns'')";
	  if (`:word `i' of `patterns''==0) {;
	    if (`"`fills'"'!="") local fc`i' `"fc(`:word `i' of `fills'')"'; 
	                   else  local fc`i' `"fc("`gc`i''")"';
		};
	  else local fc`i' "fc(black)";
	};

	if `:list sizeof values'!=8 {;
	  display as error "Expected 8 values";
	  error(101);
    };
	if `"`varlabs'"'!="" {;
	  if `:list sizeof varlabs'!=3 {;
	    display as error "Expected 3 labels";
	    error(101);
      };
	};
	else local varlabs = "A B C";

	local x1=12000; local y1=20000; local r1=6000;   // First circle A  (top left)
	local x2=20000; local y2=20000; local r2=6000;   // Second circle B (top right)
	local x3=16000; local y3=12000; local r3=6000;   // Third circle C  (bottom center)

	

	global VENN_delta=0.005;

	tempvar _Y _X _I;
	global VENN_Y_NAME = "`_Y'";
	global VENN_X_NAME = "`_X'";
	global VENN_I_NAME = "`_I'";

    quietly generate `_Y'=.;
    quietly generate `_X'=.;
    quietly generate `_I'=.;

	/* A */
	FollowCurve 1, cclockwise from_point("Z") to_point("Z") storing(1) id(1) last;
	/* B */
	FollowCurve 2, cclockwise from_point("Z") to_point("Z") storing(`=`r(last_saved)'+1') id(2) last;
	/* C */
	FollowCurve 3, cclockwise from_point("Z") to_point("Z") storing(`=`r(last_saved)'+1') id(3) last;
	/* AB */
	FollowCurve 2, cclockwise from_point("A") to_point("B") storing(`=`r(last_saved)'+1') id(4);
	FollowCurve 3,  clockwise from_point("B") to_point("F") storing(`=`r(last_saved)'+1') id(4);
	FollowCurve 1, cclockwise from_point("F") to_point("A") storing(`=`r(last_saved)'+1') id(4) last;
	/* AC */
	FollowCurve 3, cclockwise from_point("B") to_point("C") storing(`=`r(last_saved)'+1') id(5);
	FollowCurve 1, cclockwise from_point("C") to_point("D") storing(`=`r(last_saved)'+1') id(5);
	FollowCurve 2,  clockwise from_point("D") to_point("B") storing(`=`r(last_saved)'+1') id(5) last;
	/* BC */
	FollowCurve 3,  clockwise from_point("F") to_point("E") storing(`=`r(last_saved)'+1') id(6);
	FollowCurve 2,  clockwise from_point("E") to_point("D") storing(`=`r(last_saved)'+1') id(6);
	FollowCurve 1, cclockwise from_point("D") to_point("F") storing(`=`r(last_saved)'+1') id(6) last;
	/* ABC */
	FollowCurve 3,  clockwise from_point("B") to_point("F") storing(`=`r(last_saved)'+1') id(7);
	FollowCurve 1,  clockwise from_point("F") to_point("D") storing(`=`r(last_saved)'+1') id(7);
	FollowCurve 2,  clockwise from_point("D") to_point("B") storing(`=`r(last_saved)'+1') id(7) last;
	
	local cmnopts "cmiss(n) nodropb lwidth(`lwidth') lc(`lcolor') fi(100)";

	twoway
           parea `_Y' `_X' if `_I'==1, `p1' `cmnopts' `fc1' ||
	       parea `_Y' `_X' if `_I'==2, `p2' `cmnopts' `fc2' ||
	       parea `_Y' `_X' if `_I'==3, `p3' `cmnopts' `fc3' ||
	       parea `_Y' `_X' if `_I'==4, `p4' `cmnopts' `fc4' ||
	       parea `_Y' `_X' if `_I'==5, `p5' `cmnopts' `fc5' ||
	       parea `_Y' `_X' if `_I'==6, `p6' `cmnopts' `fc6' ||
	       parea `_Y' `_X' if `_I'==7, `p7' `cmnopts' `fc7'  

		   plotregion(fc(white)) graphregion(fc(white))
	       legend(pos(6) size(2.5) symxsize(4) ring(0) rows(1)
	              margin(zero) bmargin(zero) region(lc(white))
				  order(1 2 3)
	              label(1 `"`:word 1 of `varlabs''"')
                  label(2 `"`:word 2 of `varlabs''"')
                  label(3 `"`:word 3 of `varlabs''"')
           )
		   xsize(4) xscale(r(3000,28000) off) xlabel(none) xtitle("")
	       ysize(4) yscale(r(3000,28000) off) ylabel(none) ytitle("")
		   text(20000 10000 `"`:word 1 of `values''"', c(black)) /* A   */
	       text(20000 22000 `"`:word 2 of `values''"', c(black)) /* B   */
	       text(10000 16000 `"`:word 3 of `values''"', c(black)) /* C   */
		   text(20000 16000 `"`:word 4 of `values''"', c(black)) /* AB  */
	       text(16000 14000 `"`:word 5 of `values''"', c(black)) /* AC  */
		   text(16000 18000 `"`:word 6 of `values''"', c(black)) /* BC  */
		   text(17000 16000 `"`:word 7 of `values''"', c(black)) /* ABC */
		   text(10000  6000 `"`:word 8 of `values''"', c(black)) /* --- */
		   `options' ;
end; // program _Venndetta

program define Venndetta;

     version 9.2;

	 local min_obs=5639;   // <--- requires at least this many observations:
	 local original_count = `=_N';
	 if (`original_count'<`min_obs') quietly set obs `min_obs';
		 capture _Venndetta `0';
		 local r=_rc;
	 quietly keep if (_n <= `original_count');
	 error(`r');
end; // program Venndetta

*** END OF FILE ***
