#------------------------------------------------------------------------------#
# Prepare working environment 
#------------------------------------------------------------------------------#
rm(list = ls())

user = Sys.getenv("USERNAME")
readRenviron(paste("C:/Users/", user, "/Documents/RPaths.mk", sep = ""))


# Installing necessary packages
if (!require("pacman")) install.packages("pacman")
pacman::p_load("eulerr", "ggpubr", "stringr")

library(eulerr)
library(ggpubr)
library(stringr)

setwd(Sys.getenv("setPath"))
output = Sys.getenv("outPath")

set.seed(2) # for euler diagrams


#------------------------------------------------------------------------------#
# Venn diagrams ploting
#------------------------------------------------------------------------------#

data=read.csv("4Venn_in_R_current.csv",sep = ",",dec = ".",header = T)

# VD1
euler = euler(data[, 8:9], weights = data$wt_final, shape = "ellipse")
pl1   = plot(euler ,  quantities = round( 100*euler$original.values/sum(data$wt_final), digits = 1), 
                      fills = list(fill= c("white", "#338033"), alpha = 0.85),
                      labels = list(labels = c("Monetary poors", str_wrap("Others dimensions poors", width = 15)), fontsize = 10)) 
pl1   = plot(euler ,  quantities = round( 100*euler$original.values/sum(data$wt_final), digits = 1), 
             fills = list(fill= c("white", "#338033"), alpha = 0.85),
             legend = list(labels = c("Monetary poors", "Others dimensions poors"), fontsize = 10),
             main = list(labels = c("Panel A: General decomposition"), fontsize = 6, face = "bold")) 

pl1


# VD2
euler = euler(data[, c(8,10,11)], weights = data$wt_final, shape = "ellipse")
pl2   = plot(euler ,  quantities = round( 100*euler$original.values/sum(data$wt_final), digits = 1), 
                      fills = list(fill= c("white", "#338033", "#E99833"), alpha = 0.85),
                      labels = list(labels = c("Monetary poors", str_wrap("Others dimensions poors-Extremors", width = 15), 
                                 str_wrap("Others dimensions poors-Cumulators", width = 15)), fontsize = 10))
pl2   = plot(euler ,  quantities = round( 100*euler$original.values/sum(data$wt_final), digits = 1), 
             fills = list(fill= c("white", "#338033", "#E99833"), alpha = 0.85),
             legend = list(labels = c("Monetary poors", "Others dimensions poors-Extremors", 
                                      "Others dimensions poors-Cumulators"), fontsize = 10),
             main = list(labels = c("Panel B: Detailed decomposition accounting for extremors and cumulators"), fontsize = 6, face = "bold"))

pl2

fig   = ggarrange(plotlist = list(pl1, pl2), nrow = 2)
annotate_figure(fig, top = text_grob("Multidimensional poverty decomposition by type of poors", color = "black", face = "bold", size = 16))

ggsave(filename = "VD1_R.png",  path = output, scale = 2)


# VD3
euler = euler(data[, 13:15], weights = data$wt_final, shape = "ellipse")
pl3   = plot(euler ,  quantities = round( 100*euler$original.values/sum(data$wt_final), digits = 1), 
                      fills = list(fill= c("white", "#338033", "#E99833"), alpha = 0.85),
                      legend = list(labels = c("Health", "Housing", "Security"), fontsize = 10))
pl3

# VD4
euler = euler(data[data$Otherdim_poor_ext == 1 & data$Monetary_poor == 0, 13:15],
              weights = data[data$Otherdim_poor_ext == 1 & data$Monetary_poor == 0,"wt_final"],
              shape = "ellipse")
pl4   = plot(euler ,  quantities = round( 100*euler$original.values/sum(data$wt_final), digits = 1),
                      fills = list(fill= c("white", "#338033", "#E99833"), alpha = 0.85),
                      legend = list(labels = c("Health", "Housing", "Security"), fontsize = 10))
pl4

# VD4
euler = euler(data[data$Otherdim_poor_ext == 1 & data$Monetary_poor == 0, c(6,3,1)], 
              weights = data[data$Otherdim_poor_ext == 1 & data$Monetary_poor == 0,"wt_final"], 
              shape = "ellipse")
pl4_bis   = plot(euler ,  quantities = round( 100*euler$original.values/sum(data$wt_final), digits = 1), 
             fills = list(fill= c("white", "#338033", "#E99833"), alpha = 0.85),
             legend = list(labels = c("Health", "Housing", "Security"), fontsize = 10))
pl4_bis


# VD5
# euler = euler(data[data$Otherdim_poor_cum == 1, 7:9], weights = data[data$Otherdim_poor_cum == 1,"wt_final"],
#               shape = "ellipse")

euler = euler(data[data$extr != 1 & data$Monetary_poor == 0, 13:15], 
              weights = data[data$extr != 1 & data$Monetary_poor == 0,"wt_final"],
              shape = "ellipse")

pl5   = plot(euler ,  quantities = round( 100*euler$original.values/sum(data$wt_final), digits = 1), 
             fills = list(fill= c("white", "#338033", "#E99833"), alpha = 0.85),
             legend = list(labels = c("Health", "Housing", "Security"), fontsize = 10))
pl5

# fig2   = ggarrange(plotlist = list(pl3, pl4, pl5), nrow = 2, ncol = 2, 
#                    labels = c("Overall individuals", str_wrap("Non- monetary poors & Others dimensions poors-Extremors", width = 15), "Others dimensions poors-Cumulators"),
#                    font.label = list(size = 12, face  = "bold"))
fig2   = ggarrange(plotlist = list(pl3, pl4, pl5), nrow = 2, ncol = 2,
                   labels = c("Overall individuals", str_wrap("Non- monetary poors & Others dimensions poors-Extremors", width = 20),
                              str_wrap("Non- monetary poors & Non Extremors", width = 20)),
                   font.label = list(size = 12, face  = "bold"))
annotate_figure(fig2, top = text_grob("Per dimension share of deprived individuals", color = "black", face = "bold", size = 18))

ggsave(filename = "VD2_R.png",  path = output, scale = 2)



fig3   = ggarrange(plotlist = list(pl3, pl4_bis, pl5), nrow = 2, ncol = 2,
                   labels = c("Overall individuals", str_wrap("Non- monetary poors & Others dimensions poors-Extremors", width = 20),
                              str_wrap("Non- monetary poors & Non Extremors", width = 20)),
                   font.label = list(size = 12, face  = "bold"))
annotate_figure(fig3, top = text_grob("Per dimension share of deprived individuals", color = "black", face = "bold", size = 18))

ggsave(filename = "VD2_R_bis.png",  path = output, scale = 2)


